@@ -17,25 +17,23 @@ class InteractionContainer;
 
 #ifdef YADE_OPENMP
 #define YADE_PARALLEL_FOREACH_BODY_BEGIN(b_, bodies)                                                                                                           \
-	bodies->updateShortLists();                                                                                                                            \
+	bodies->updateRealBodies();                                                                                                                            \
 	const vector<Body::id_t>& realBodies = bodies->realBodies;                                                                                             \
 	const bool                redirect   = bodies->useRedirection;                                                                                         \
 	const Body::id_t          _sz(redirect ? realBodies.size() : bodies->size());                                                                          \
-	_Pragma("omp parallel for") for (int k = 0; k < _sz; k++)                                                                                              \
+	_Pragma("omp parallel for") for (int kParallelForeachIndexCounter = 0; kParallelForeachIndexCounter < _sz; kParallelForeachIndexCounter++)             \
 	{                                                                                                                                                      \
-		if (not redirect and not(*bodies)[k])                                                                                                          \
-			continue;                                                                                                                              \
-		b_((*bodies)[redirect ? realBodies[k] : k]);
+		if (not redirect and not(*bodies)[kParallelForeachIndexCounter]) continue;                                                                     \
+		b_((*bodies)[redirect ? realBodies[kParallelForeachIndexCounter] : kParallelForeachIndexCounter]);
 #else
 #define YADE_PARALLEL_FOREACH_BODY_BEGIN(b_, bodies)                                                                                                           \
-	bodies->updateShortLists();                                                                                                                            \
+	bodies->updateRealBodies();                                                                                                                            \
 	const vector<Body::id_t>& realBodies = bodies->realBodies;                                                                                             \
 	const bool                redirect   = bodies->useRedirection;                                                                                         \
 	const Body::id_t          _sz(redirect ? realBodies.size() : bodies->size());                                                                          \
-	for (int k = 0; k < _sz; k++) {                                                                                                                        \
-		if (not redirect and not(*bodies)[k])                                                                                                          \
-			continue;                                                                                                                              \
-		b_((*bodies)[redirect ? realBodies[k] : k]);
+	for (int kParallelForeachIndexCounter = 0; kParallelForeachIndexCounter < _sz; kParallelForeachIndexCounter++) {                                       \
+		if (not redirect and not(*bodies)[kParallelForeachIndexCounter]) continue;                                                                     \
+		b_((*bodies)[redirect ? realBodies[kParallelForeachIndexCounter] : kParallelForeachIndexCounter]);
 #endif
 #define YADE_PARALLEL_FOREACH_BODY_END() }
 
@@ -73,7 +71,7 @@ public:
 	bool exists(Body::id_t id) const;
 	bool erase(Body::id_t id, bool eraseClumpMembers);
 
-	void updateShortLists();
+	void updateRealBodies();
 
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(BodyContainer,Serializable,"Standard body container for a scene",
@@ -81,6 +79,7 @@ public:
 		((bool,dirty,true,(Attr::noSave|Attr::readonly|Attr::hidden),"true if after insertion/removal of bodies, used only if collider::keepListsShort=true"))
 		((bool,checkedByCollider,false,(Attr::noSave|Attr::readonly|Attr::hidden),""))
 		((vector<Body::id_t>,insertedBodies,vector<Body::id_t>(),Attr::readonly,"The list of newly bodies inserted, to be used and purged by collider"))
+		((vector<Body::id_t>,erasedBodies,vector<Body::id_t>(),Attr::readonly,"The list of erased bodies, to be used and purged by collider"))
 		((vector<Body::id_t>,realBodies,vector<Body::id_t>(),Attr::readonly,"Redirection vector to non-null bodies, used to optimize loops after numerous insertion/erase. In MPI runs the list is restricted to bodies and neighbors present in current subdomain."))
 		((bool,useRedirection,false,,"true if the scene uses up-to-date lists for boundedBodies and realBodies; turned true automatically 1/ after removal of bodies if :yref:`enableRedirection=True <BodyContainer.enableRedirection>`, and 2/ in MPI execution. |yupdate|"))
 		((bool,enableRedirection,true,,"let collider switch to optimized algorithm with body redirection when bodies are erased - true by default"))
@@ -88,11 +87,16 @@ public:
 		((vector<Body::id_t>,subdomainBodies,vector<Body::id_t>(),,"The list of bounded bodies in the subdomain"))
 		#endif
 		,/*ctor*/,
-		.def("updateShortLists",&BodyContainer::updateShortLists,"update lists realBodies and subdomainBodies. This function is called automatically by e.g. ForceContainer::reset(), it is safe to call multiple times from many places since if the lists are up-to-date he function will just return.")
+		.def("updateRealBodies",&BodyContainer::updateRealBodies,"update lists realBodies and subdomainBodies. This function is called automatically by e.g. ForceContainer::reset(), it is safe to call multiple times from many places since if the lists are up-to-date he function will just return.")
 		)
 	// clang-format on
 
 	DECLARE_LOGGER;
+
+	// mutual exclusion to avoid crashes in the rendering loop
+	std::mutex drawloopmutex;
+private:
+	bool eraseAlreadyLocked(Body::id_t id, bool eraseClumpMembers);
 };
 REGISTER_SERIALIZABLE(BodyContainer);
 
