@@ -6,9 +6,14 @@
 #include <core/BodyContainer.hpp>
 #include <core/Omega.hpp>
 #include <core/Scene.hpp>
-#include <mpi.h>
 #include <vector>
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#include <mpi.h>
+#pragma GCC diagnostic pop
+
 namespace yade { // Cannot have #include directive inside.
 
 class MPIBodyContainer : public Serializable {
@@ -28,14 +33,10 @@ public:
 		else {
 			int c = 0;
 			for (std::vector<shared_ptr<Body>>::iterator bodyIter = bContainer.begin(); bodyIter != bContainer.end(); ++bodyIter) {
-				const shared_ptr<Body>& inContainerBody = *(bodyIter);
-				if (inContainerBody->id == b->id) {
-					c += 1;
-				}
-			}
-			if (c == 0) {
-				bContainer.push_back(b);
+				const auto& inContainerBody = *(bodyIter);
+				if (inContainerBody->id == b->id) { c += 1; }
 			}
+			if (c == 0) { bContainer.push_back(b); }
 		}
 	}
 
@@ -60,16 +61,16 @@ public:
 		}
 	}
 
-	unsigned int getCount() { return bContainer.size(); }
+	unsigned int getCount() const { return bContainer.size(); }
 
-	shared_ptr<Body> getBodyat(int pos) { return bContainer[pos]; }
+	shared_ptr<Body> getBodyat(int pos) const { return bContainer[pos]; }
 
-	//     shared_ptr<Body> getBodybyId(int id ){
+	//     shared_ptr<Body> getBodybyId(int id ) const {
 	//
 	//     }
 
 
-	std::vector<Body::id_t> getIds()
+	std::vector<Body::id_t> getIds() const
 	{
 		std::vector<Body::id_t> ids;
 		for (unsigned int i = 0; i != bContainer.size(); ++i) {
