@@ -7,10 +7,11 @@
 #include <core/BodyContainer.hpp>
 #include <core/Interaction.hpp>
 #include <core/InteractionContainer.hpp>
+#include <core/InteractionLoop.hpp>
 #include <core/MPIBodyContainer.hpp>
 #include <core/State.hpp>
 #include <pkg/common/Sphere.hpp>
-#include <pkg/dem/Shop.hpp>
+#include <preprocessing/dem/Shop.hpp>
 #include <boost/iostreams/device/array.hpp>
 #include <boost/iostreams/device/back_inserter.hpp>
 #include <boost/iostreams/stream.hpp>
@@ -31,15 +32,13 @@ void Subdomain::setMinMax()
 	Real inf  = std::numeric_limits<Real>::infinity();
 	boundsMin = Vector3r(inf, inf, inf);
 	boundsMax = Vector3r(-inf, -inf, -inf);
-	if (ids.size() == 0)
-		LOG_WARN("empty subdomain!");
+	if (ids.size() == 0) LOG_WARN("empty subdomain!");
 	if (ids.size() > 0 and Body::byId(ids[0], scene)->subdomain != scene->subdomain)
 		LOG_WARN("setMinMax executed with deprecated data (body->subdomain != scene->subdomain)");
 
 	for (const auto& id : ids) {
 		const shared_ptr<Body>& b = Body::byId(id, scene);
-		if (!b or !b->bound)
-			continue;
+		if (!b or !b->bound) continue;
 		if (!scene->isPeriodic) {
 			boundsMax = boundsMax.cwiseMax(b->bound->max);
 			boundsMin = boundsMin.cwiseMin(b->bound->min);
@@ -115,7 +114,7 @@ boost::python::list Subdomain::mIntrs_get()
 
 void Subdomain::setSubdomainIds(std::vector<Body::id_t> subdIds) { subdomains = subdIds; }
 
-std::vector<Body::id_t> Subdomain::getSubdomainIds() { return subdomains; }
+std::vector<Body::id_t> Subdomain::getSubdomainIds() const { return subdomains; }
 
 void Subdomain::append(Body::id_t bId) { subdomains.push_back(bId); }
 void Subdomain::appendList(const boost::python::list& lst)
@@ -132,9 +131,7 @@ void Bo1_Subdomain_Aabb::go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv,
 	// 	LOG_WARN("Bo1_Subdomain_Aabb::go()")
 	scene             = Omega::instance().getScene().get();
 	Subdomain* domain = static_cast<Subdomain*>(cm.get());
-	if (!bv) {
-		bv = shared_ptr<Bound>(new Aabb);
-	}
+	if (!bv) { bv = shared_ptr<Bound>(new Aabb); }
 	Aabb* aabb = static_cast<Aabb*>(bv.get());
 	aabb->min  = domain->boundsMin;
 	aabb->max  = domain->boundsMax;
@@ -164,17 +161,17 @@ shared_ptr<MPIBodyContainer> Subdomain::deSerializeMPIBodyContainer(const char*
 }
 
 
-string Subdomain::fillContainerGetString(shared_ptr<MPIBodyContainer>& container, const std::vector<Body::id_t>& ids)
+string Subdomain::fillContainerGetString(shared_ptr<MPIBodyContainer>& container, const std::vector<Body::id_t>& ids2)
 {
-	container->insertBodyList(ids);
+	container->insertBodyList(ids2);
 	std::string containerString = serializeMPIBodyContainer(container);
 	return containerString;
 }
 
-string Subdomain::idsToSerializedMPIBodyContainer(const std::vector<Body::id_t>& ids)
+string Subdomain::idsToSerializedMPIBodyContainer(const std::vector<Body::id_t>& ids2)
 {
 	shared_ptr<MPIBodyContainer> container(shared_ptr<MPIBodyContainer>(new MPIBodyContainer()));
-	container->insertBodyList(ids);
+	container->insertBodyList(ids2);
 	return serializeMPIBodyContainer(container);
 }
 
@@ -225,16 +222,12 @@ void Subdomain::setCommunicationContainers()
 	//here, we setup the serialized MPIBodyContainer (MPIBodyContainer to string). it is std::vector<std::pair<container(string), sendRank/recvRank> >
 	// fill the send container based on the ids from the intersection(local) map
 	//Send container
-	if (subdomainRank == master) {
-		return;
-	}
+	if (subdomainRank == master) { return; }
 	recvRanks.clear();
 	sendContainer.clear();
 	unsigned int zero = 0;
 	for (unsigned int i = 1; i != intersections.size(); ++i) {
-		if ((intersections[i].size() == zero) || (i == (unsigned)subdomainRank)) {
-			continue;
-		} // exclude self or if no intersections with others)
+		if ((intersections[i].size() == zero) || (i == (unsigned)subdomainRank)) { continue; } // exclude self or if no intersections with others)
 		shared_ptr<MPIBodyContainer> container(shared_ptr<MPIBodyContainer>(new MPIBodyContainer()));
 		container->subdomainRank    = subdomainRank; // used to identify the origin rank at the reciever side. (maybe not needed?)
 		std::string containerString = fillContainerGetString(container, intersections[i]);
@@ -242,9 +235,7 @@ void Subdomain::setCommunicationContainers()
 	}
 	//Recv container, here we just need the ranks for now.
 	for (unsigned int i = 1; i != remoteCount.size(); ++i) {
-		if ((static_cast<unsigned int>(subdomainRank) == i) || (!remoteCount[i])) {
-			continue;
-		}
+		if ((static_cast<unsigned int>(subdomainRank) == i) || (!remoteCount[i])) { continue; }
 		recvRanks.push_back(i);
 	}
 	commContainer = true; //flag to check if the communicationContainers are set.
@@ -254,9 +245,7 @@ void Subdomain::setCommunicationContainers()
 void Subdomain::sendContainerString()
 {
 	//send the containers.
-	if (subdomainRank == master) {
-		return;
-	}
+	if (subdomainRank == master) { return; }
 	if (!commContainer) {
 		LOG_ERROR("communication containers are not set!");
 		return;
@@ -292,9 +281,7 @@ void Subdomain::sendAllBodiesToMaster()
 {
 	// send all bodies from this subdomain to the master. Can be used for merge.
 	// (note to self: this can be improved based on the bisection decomposition.)
-	if (subdomainRank == master) {
-		return;
-	}
+	if (subdomainRank == master) { return; }
 	shared_ptr<MPIBodyContainer> container(shared_ptr<MPIBodyContainer>(new MPIBodyContainer()));
 	std::string                  s = fillContainerGetString(container, ids);
 	sendStringBlocking(s, master, TAG_BODY + master);
@@ -334,9 +321,7 @@ void Subdomain::completeSendBodies()
 
 void Subdomain::initMasterContainer()
 {
-	if (subdomainRank != master) {
-		return;
-	}
+	if (subdomainRank != master) { return; }
 	recvRanks.resize(commSize - 1);
 	for (unsigned i = 0; i != recvRanks.size(); ++i) {
 		recvRanks[i] = i + 1;
@@ -379,16 +364,13 @@ void Subdomain::setBodiesToBodyContainer(Scene* scene, std::vector<shared_ptr<MP
 			const Body::id_t&                             idx        = newBody->id;
 			std::map<Body::id_t, shared_ptr<Interaction>> intrsToSet = newBody->intrs;
 			shared_ptr<Body>&                             b          = (*bodyContainer)[idx];
-			if (!b)
-				newBody->intrs.clear(); //we can clear here, interactions are stored in intrsToSet and will be reinserted
+			if (!b) newBody->intrs.clear(); //we can clear here, interactions are stored in intrsToSet and will be reinserted
 			else
 				newBody->intrs = b->intrs; //keep interactions generated in current subdomain as they may not exist on the sender's side
 
-			if (ifMerge)
-				newBody->material = scene->materials[newBody->material->id];
+			if (ifMerge) newBody->material = scene->materials[newBody->material->id];
 
-			if (!b)
-				bodyContainer->insertAtId(newBody, newBody->id);
+			if (!b) bodyContainer->insertAtId(newBody, newBody->id);
 			else if (overwriteBodies) {
 				b                                = newBody;
 				bodyContainer->dirty             = true;
@@ -422,9 +404,7 @@ void Subdomain::setBodiesToBodyContainer(Scene* scene, std::vector<shared_ptr<MP
 
 void Subdomain::splitBodiesToWorkers(const bool& eraseWorkerIds)
 {
-	if (!eraseWorkerIds) {
-		return;
-	}
+	if (!eraseWorkerIds) { return; }
 	shared_ptr<Scene>                    scene         = Omega::instance().getScene();
 	shared_ptr<BodyContainer>            bodyContainer = scene->bodies;
 	std::vector<std::vector<Body::id_t>> idsToSend;
@@ -433,9 +413,7 @@ void Subdomain::splitBodiesToWorkers(const bool& eraseWorkerIds)
 		idsToSend.resize(commSize - 1);
 		for (const auto& b : bodyContainer->body) {
 			if (!b->getIsSubdomain()) {
-				if (b->subdomain != master) {
-					idsToSend[b->subdomain - 1].push_back(b->id);
-				}
+				if (b->subdomain != master) { idsToSend[b->subdomain - 1].push_back(b->id); }
 				for (const auto& bIntrs : b->intrs) {
 					Body::id_t              otherId;
 					shared_ptr<Interaction> I = bIntrs.second;
@@ -445,9 +423,7 @@ void Subdomain::splitBodiesToWorkers(const bool& eraseWorkerIds)
 						otherId = I->getId1();
 					}
 					const shared_ptr<Body>& otherBody = (*bodyContainer)[otherId];
-					if (otherBody->getIsSubdomain()) {
-						idsToSend[otherBody->subdomain - 1].push_back(b->id);
-					}
+					if (otherBody->getIsSubdomain()) { idsToSend[otherBody->subdomain - 1].push_back(b->id); }
 				}
 			}
 		}
@@ -455,15 +431,9 @@ void Subdomain::splitBodiesToWorkers(const bool& eraseWorkerIds)
 
 	if ((subdomainRank != master) && (eraseWorkerIds)) {
 		for (const auto& b : bodyContainer->body) {
-			if (!b) {
-				continue;
-			}
-			if (b->subdomain == 0) {
-				continue;
-			}
-			if (!b->getIsSubdomain()) {
-				bodyContainer->erase(b->id, true);
-			}
+			if (!b) { continue; }
+			if (b->subdomain == 0) { continue; }
+			if (!b->getIsSubdomain()) { bodyContainer->erase(b->id, true); }
 		}
 		clearSubdomainIds();
 	}
@@ -481,13 +451,9 @@ void Subdomain::splitBodiesToWorkers(const bool& eraseWorkerIds)
 	if (subdomainRank != master) {
 		receiveBodies(master);
 		for (const auto& b : bodyContainer->body) {
-			if (!b) {
-				continue;
-			}
+			if (!b) { continue; }
 			if (!b->getIsSubdomain()) {
-				if (b->subdomain == subdomainRank) {
-					ids.push_back(b->id);
-				}
+				if (b->subdomain == subdomainRank) { ids.push_back(b->id); }
 			}
 		}
 	}
@@ -540,29 +506,28 @@ void Subdomain::recvBuff(char* cbuf, int cbufsZ, int sourceRank, MPI_Request& re
 	MPI_Irecv(cbuf, cbufsZ, MPI_CHAR, sourceRank, TAG_STRING + subdomainRank, selfComm(), &request);
 }
 
-void Subdomain::processReqs(std::vector<MPI_Request>& mpiReqs)
+void Subdomain::processReqs(std::vector<MPI_Request>& mpiReqs2)
 {
-	if (!mpiReqs.size()) {
-		return;
-	}
-	for (unsigned int i = 0; i != mpiReqs.size(); ++i) {
+	// mpiReqs shadows a member yade::Subdomain::mpiReqs
+	if (!mpiReqs2.size()) { return; }
+	for (unsigned int i = 0; i != mpiReqs2.size(); ++i) {
 		MPI_Status status;
-		MPI_Wait(&mpiReqs[i], &status);
+		MPI_Wait(&mpiReqs2[i], &status);
 	}
 
-	resetReqs(mpiReqs);
+	resetReqs(mpiReqs2);
 }
 
-void Subdomain::resetReqs(std::vector<MPI_Request>& mpiReqs) { mpiReqs.clear(); }
+void Subdomain::resetReqs(std::vector<MPI_Request>& mpiReqs2) { mpiReqs2.clear(); }
 
-void Subdomain::processReqsAll(std::vector<MPI_Request>& mpiReqs, std::vector<MPI_Status>& mpiStats)
+void Subdomain::processReqsAll(std::vector<MPI_Request>& mpiReqs2, std::vector<MPI_Status>& mpiStats)
 {
-	for (unsigned int i = 0; i != mpiReqs.size(); ++i) {
+	for (unsigned int i = 0; i != mpiReqs2.size(); ++i) {
 		//MPI_Status status;
-		MPI_Waitall(1, &mpiReqs[i], &mpiStats[i]);
+		MPI_Waitall(1, &mpiReqs2[i], &mpiStats[i]);
 	}
 	mpiStats.clear();
-	resetReqs(mpiReqs);
+	resetReqs(mpiReqs2);
 }
 
 
@@ -571,9 +536,7 @@ void Subdomain::clearRecvdCharBuff(std::vector<char*>& rcharBuff)
 	for (std::vector<char*>::iterator cIter = rcharBuff.begin(); cIter != rcharBuff.end(); ++cIter) {
 		delete[](*cIter);
 	}
-	if (subdomainRank != master) {
-		rcharBuff.clear();
-	} // assuming master alwasy recieves from workers, hence the size of this vector for master is fixed.
+	if (subdomainRank != master) { rcharBuff.clear(); } // assuming master alwasy recieves from workers, hence the size of this vector for master is fixed.
 }
 
 void Subdomain::getMirrorIntersections()
@@ -590,8 +553,7 @@ void Subdomain::getMirrorIntersections()
 		//get procs to communicate.
 		const auto& interProcs = intersections[subdomainRank];
 		for (const auto& proc : interProcs) {
-			if (proc == master)
-				continue;
+			if (proc == master) continue;
 			const auto& interVec = intersections[proc];
 			MPI_Request req;
 			//send the intersections
@@ -601,8 +563,7 @@ void Subdomain::getMirrorIntersections()
 
 		// probe size of incoming intersections :
 		for (const auto& proc : interProcs) {
-			if (proc == master)
-				continue;
+			if (proc == master) continue;
 			MPI_Status status;
 			MPI_Probe(proc, TAG_INTERSECTIONS, selfComm(), &status);
 			int sz;
@@ -613,8 +574,7 @@ void Subdomain::getMirrorIntersections()
 
 		// recv intersections..
 		for (const auto& proc : interProcs) {
-			if (proc == master)
-				continue;
+			if (proc == master) continue;
 			auto&      mirrorVec = mirrorIntersections[proc];
 			MPI_Status stat;
 			MPI_Recv(&mirrorVec.front(), (int)mirrorVec.size(), MPI_INT, proc, TAG_INTERSECTIONS, selfComm(), &stat);
@@ -653,8 +613,7 @@ void Subdomain::getMirrorIntersections()
 	if (subdomainRank != master) {
 		if (intrSzMaster[subdomainRank] > 0) {
 			const auto& it = std::find(intersections[subdomainRank].begin(), intersections[subdomainRank].end(), master);
-			if (it == intersections[subdomainRank].end())
-				intersections[subdomainRank].push_back(master);
+			if (it == intersections[subdomainRank].end()) intersections[subdomainRank].push_back(master);
 			auto& vecMaster = mirrorIntersections[0];
 			vecMaster.clear();
 			vecMaster.resize(intrSzMaster[subdomainRank]);
@@ -664,9 +623,7 @@ void Subdomain::getMirrorIntersections()
 		}
 	}
 	//complete the interactive send in master's side.
-	if (subdomainRank == master) {
-		processReqs(interReqs);
-	}
+	if (subdomainRank == master) { processReqs(interReqs); }
 }
 
 
@@ -679,8 +636,7 @@ Real Subdomain::boundOnAxis(Bound& b, const Vector3r& direction, bool min)
 	Real     extremum = 0;
 	for (unsigned k = 0; k < 3; k++)
 		extremum += math::abs(size[k] * direction[k]); // this is equivalent to taking the vertex maximizing projected length
-	if (min)
-		extremum = -extremum;
+	if (min) extremum = -extremum;
 	extremum
 	        += (b.max + b.min)
 	                   .dot(direction); // should be *0.5 to be center of the box, but since we use 'size' instead of half-size everything is doubled, neutral in terms of ordering the boxes
@@ -716,9 +672,7 @@ std::vector<projectedBoundElem> Subdomain::projectedBoundsCPP(int otherSD, const
 	// from intersections (bodies in this subdomain which has intersections with the other sd)
 	for (const auto& bId : intersections[otherSD]) {
 		const shared_ptr<Body>& b = (*scene->bodies)[bId];
-		if (!b or b->getIsSubdomain()) {
-			continue;
-		}
+		if (!b or b->getIsSubdomain()) { continue; }
 		Real               ps = boundOnAxis((*b->bound), axis, true);
 		projectedBoundElem pElem(ps, std::make_pair(subdomainRank, bId));
 		pos.push_back(pElem);
@@ -727,9 +681,7 @@ std::vector<projectedBoundElem> Subdomain::projectedBoundsCPP(int otherSD, const
 	// from mirror intersections (bodies from other subdomain which has intersections with this sd)
 	for (const auto& bId : mirrorIntersections[otherSD]) {
 		const shared_ptr<Body>& b = (*scene->bodies)[bId];
-		if (!b or b->getIsSubdomain()) {
-			continue;
-		}
+		if (!b or b->getIsSubdomain()) { continue; }
 		Real               ps = boundOnAxis((*b->bound), axis, false);
 		projectedBoundElem pElem(ps, std::make_pair(otherSD, bId));
 		pos.push_back(pElem);
@@ -740,21 +692,21 @@ std::vector<projectedBoundElem> Subdomain::projectedBoundsCPP(int otherSD, const
 	return pos;
 }
 
-std::vector<Body::id_t>
-Subdomain::medianFilterCPP(int otherSD, const Vector3r& otherSubDCM, const Vector3r& subDCM, int giveAway, bool useAABB)
+std::vector<Body::id_t> Subdomain::medianFilterCPP(int otherSD, const Vector3r& otherSubDCM, const Vector3r& subDCM, int giveAway, bool useAABB)
 {
 	std::vector<Body::id_t>         idsToSend;
 	std::vector<projectedBoundElem> pos = projectedBoundsCPP(otherSD, otherSubDCM, subDCM, useAABB);
 	if (!pos.size()) LOG_ERROR("ERROR IN CALCULATING PROJECTED BOUNDS WITH SUBDOMAIN = " << otherSD << "  from Subdomain = " << subdomainRank);
-	int firstJ = pos.size(); int lastI = 0;
-	for (int n=0; n< (int)pos.size() ; n++) {
-		if (pos[n].second.first != subdomainRank and n<firstJ) firstJ = n;
+	int firstJ = pos.size();
+	int lastI  = 0;
+	for (int n = 0; n < (int)pos.size(); n++) {
+		if (pos[n].second.first != subdomainRank and n < firstJ) firstJ = n;
 		if (pos[n].second.first == subdomainRank) lastI = n;
-	}	
+	}
 	int finalSize = std::max(0, (int)intersections[otherSD].size() - giveAway); // The desired final number on this side
-	if (finalSize > lastI) finalSize=lastI+1;
-	if (finalSize < firstJ) finalSize=firstJ+1;
-	for (int x=finalSize; x< (int)pos.size() ; x++) // whatever is on the other side is given away
+	if (finalSize > lastI) finalSize = lastI + 1;
+	if (finalSize < firstJ) finalSize = firstJ + 1;
+	for (int x = finalSize; x < (int)pos.size(); x++) // whatever is on the other side is given away
 		if (pos[x].second.first == subdomainRank) idsToSend.push_back(pos[x].second.second);
 	return idsToSend;
 }
@@ -766,11 +718,9 @@ void Subdomain::migrateBodiesSend(const std::vector<Body::id_t>& sendIds, int de
 	const auto&              thisSubd = subdomains[subdomainRank - 1];
 	for (const auto& bId : sendIds) {
 		const shared_ptr<Body>& bdy = (*scene->bodies)[bId];
-		if (!bdy) {
-			LOG_ERROR("reassignBodies failed " << bId << "  is not in subdomain " << subdomainRank << std::endl);
-		}
+		if (!bdy) { LOG_ERROR("reassignBodies failed " << bId << "  is not in subdomain " << subdomainRank << std::endl); }
 		bdy->subdomain = destination;
-		yade::Shop::createExplicitInteraction(thisSubd, bId, false, true);
+		InteractionLoop::createExplicitInteraction(thisSubd, bId, false, true);
 	}
 	sendBodies(destination, sendIds);
 }
@@ -784,20 +734,14 @@ void Subdomain::updateLocalIds(bool eraseRemoteMaster)
 		const shared_ptr<Scene>& scene = Omega::instance().getScene();
 		ids.clear();
 		for (const auto& b : (*scene->bodies)) {
-			if (!b) {
-				continue;
-			}
-			if ((b->subdomain == subdomainRank) && (!(b->getIsSubdomain()))) {
-				ids.push_back(b->id);
-			}
+			if (!b) { continue; }
+			if ((b->subdomain == subdomainRank) && (!(b->getIsSubdomain()))) { ids.push_back(b->id); }
 		}
 	}
 	if (!eraseRemoteMaster) {
 		MPI_Status  iSendstat;
 		MPI_Request iSendReq;
-		if (subdomainRank != master) {
-			MPI_Isend(&ids.front(), (int)ids.size(), MPI_INT, master, 500, selfComm(), &iSendReq);
-		}
+		if (subdomainRank != master) { MPI_Isend(&ids.front(), (int)ids.size(), MPI_INT, master, 500, selfComm(), &iSendReq); }
 
 		if (subdomainRank == master) {
 			std::vector<std::vector<Body::id_t>> workerIdsVec;
@@ -825,9 +769,7 @@ void Subdomain::updateLocalIds(bool eraseRemoteMaster)
 			}
 		}
 
-		if (subdomainRank != master) {
-			MPI_Wait(&iSendReq, &iSendstat);
-		}
+		if (subdomainRank != master) { MPI_Wait(&iSendReq, &iSendstat); }
 	}
 }
 
@@ -837,8 +779,7 @@ void Subdomain::cleanIntersections(int otherDomain)
 	const shared_ptr<Scene>& scene = Omega::instance().getScene();
 	for (const auto& bId : intersections[otherDomain]) {
 		const shared_ptr<Body>& b = (*scene->bodies)[bId];
-		if (b && (b->subdomain == subdomainRank))
-			ints.push_back(bId);
+		if (b && (b->subdomain == subdomainRank)) ints.push_back(bId);
 	}
 	intersections[otherDomain] = ints;
 }
@@ -850,7 +791,7 @@ void Subdomain::updateNewMirrorIntrs(int otherDomain, const std::vector<Body::id
 unsigned Subdomain::countIntsWith(Body::id_t body, Body::id_t someSubD, const shared_ptr<Scene>& scene) const
 {
 	if (not Body::byId(body, scene)) {
-		LOG_WARN("invalid body id: "<<body<<" vs. sd "<<someSubD<<", compared in "<<subdomainRank);
+		LOG_WARN("invalid body id: " << body << " vs. sd " << someSubD << ", compared in " << subdomainRank);
 		return 0;
 	}
 	const auto& intrs = Body::byId(body, scene)->intrs;
@@ -862,7 +803,7 @@ unsigned Subdomain::countIntsWith(Body::id_t body, Body::id_t someSubD, const sh
 
 vector<Body::id_t> Subdomain::filteredInts(Body::id_t someSubD, bool mirror) const
 {
-	auto&  intrs = mirror ? mirrorIntersections[someSubD] : intersections[someSubD];
+	auto&                    intrs = mirror ? mirrorIntersections[someSubD] : intersections[someSubD];
 	std::vector<Body::id_t>  filtered;
 	const shared_ptr<Scene>& scene = Omega::instance().getScene();
 	std::copy_if(intrs.begin(), intrs.end(), std::back_inserter(filtered), [&](auto i) {
@@ -883,8 +824,8 @@ double Subdomain::filterIntersections()
 			// PLEASE DON'T REMOVE THOSE COMMENTED DEBUG MESSAGES
 			// 			unsigned oldI(intersections[subd].size()), oldM(mirrorIntersections[subd].size());
 			oldNum += intersections[subd].size();
-			if (mirrorIntersections[subd].size()>0)	mirrorIntersections[subd] = filteredInts(subd, true);
-			if (intersections[subd].size()>0) 		intersections[subd]       = filteredInts(subd, false);
+			if (mirrorIntersections[subd].size() > 0) mirrorIntersections[subd] = filteredInts(subd, true);
+			if (intersections[subd].size() > 0) intersections[subd] = filteredInts(subd, false);
 			newNum += intersections[subd].size();
 			// 			LOG_WARN("SubD "<<scene->subdomain<<" suppressed "<<(oldI-intersections[subd].size())<<" / "<<oldI<<"  vs. "<<subd);
 			// 			LOG_WARN("SubD "<<scene->subdomain<<" suppressed "<<(oldM-mirrorIntersections[subd].size())<<" / "<<oldM<<" from "<<subd);
