@@ -1,6 +1,8 @@
 from __future__ import print_function
 print(30*'*'+' WARNING '+30*'*'+'\nFor hardware/driver/...? reasons related to 3d, this script might\nsometimes crash when the first snapshot is taken with message such as\n\n\tQGLContext::makeCurrent(): Failed.\n\nor\n\n\tFatal IO error 11 (Resource temporarily unavailable) on X server :0.0.\n\nA workaround is to open the 3d view by hand, rather than having it\nopen by SnapshotEngine automatically when the first snapshot is\nabout to be taken. Sometimes only the message is displayed,\nwithout crash.\n'+25*'*'+' This is a known bug. '+25*'*')
 TriaxialTest(noFiles=True).load()
+yade.qt.View()
+
 from yade import qt
 O.engines=O.engines+[
 	qt.SnapshotEngine(fileBase=O.tmpFilename(),label='snapshotter',iterPeriod=5,ignoreErrors=False),
@@ -20,7 +22,7 @@ def finito():
 	makeVideo(snapshotter.snapshots,out='/tmp/video.avi')
 	print("Video saved in /tmp/video.avi")
 	import sys
-	sys.exit(0)
+	os._exit(0)
 
 O.run()
 
