@@ -9,6 +9,7 @@
 #include <boost/date_time/posix_time/posix_time.hpp>
 #endif
 
+#include <QOpenGLWidget>
 #include <QGLViewer/constraint.h>
 #include <QGLViewer/manipulatedFrame.h>
 #include <QGLViewer/qglviewer.h>
@@ -37,7 +38,11 @@ namespace yade { // Cannot have #include directive inside.
  * and recompile to have more.
  */
 class GLViewer : public QGLViewer {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
 	Q_OBJECT
+#pragma GCC diagnostic pop
 
 	friend class QGLThread;
 
@@ -89,19 +94,19 @@ public:
 	int  timeDispMask;
 	enum { TIME_REAL = 1, TIME_VIRT = 2, TIME_ITER = 4 };
 
-	GLViewer(int viewId, const shared_ptr<OpenGLRenderer>& renderer, QGLWidget* shareWidget = 0);
+	GLViewer(int viewId, const shared_ptr<OpenGLRenderer>& renderer, QOpenGLWidget* = 0);
 	virtual ~GLViewer();
 #if 0
 			virtual void paintGL();
 #endif
-	virtual void draw();
-	virtual void drawWithNames();
-	void         displayMessage(const std::string& s) { QGLViewer::displayMessage(QString(s.c_str())); }
-	void         centerScene(
-	                const Real&     suggestedRadius      = -1,
-	                const Vector3r& setGridOrigin        = Vector3r(0, 0, 0),
-	                const Vector3r& suggestedCenter      = Vector3r(0, 0, 0),
-	                int             setGridDecimalPlaces = 4);
+	void draw() override;
+	void drawWithNames() override;
+	void displayMessage(const std::string& s) { QGLViewer::displayMessage(QString(s.c_str())); }
+	void centerScene(
+	        const Real&     suggestedRadius      = -1,
+	        const Vector3r& setGridOrigin        = Vector3r(0, 0, 0),
+	        const Vector3r& suggestedCenter      = Vector3r(0, 0, 0),
+	        int             setGridDecimalPlaces = 4);
 	void     centerPeriodic();
 	void     mouseMovesCamera();
 	void     mouseMovesManipulatedFrame(qglviewer::Constraint* c = NULL);
@@ -124,9 +129,9 @@ public:
 	std::pair<double, qglviewer::Vec> displayedSceneRadiusCenter();
 
 	//! Adds our attributes to the QGLViewer state that can be saved
-	QDomElement domElement(const QString& name, QDomDocument& document) const;
+	QDomElement domElement(const QString& name, QDomDocument& document) const override;
 	//! Adds our attributes to the QGLViewer state that can be restored
-	void initFromDOMElement(const QDomElement& element);
+	void initFromDOMElement(const QDomElement& element) override;
 
 	// if defined, snapshot will be saved to this file right after being drawn and the string will be reset.
 	// this way the caller will be notified of the frame being saved successfully.
@@ -136,24 +141,24 @@ public:
 	FILE* gl2psStream;
 #endif
 
-	boost::posix_time::ptime getLastUserEvent();
+	boost::posix_time::ptime getLastUserEvent() const;
 
 
 	DECLARE_LOGGER;
 
 protected:
-	virtual void keyPressEvent(QKeyEvent* e);
-	virtual void postDraw();
+	void keyPressEvent(QKeyEvent* e) override;
+	void postDraw() override;
 	// overridden in the player that doesn't get time from system clock but from the db
-	virtual string  getRealTimeString();
-	virtual void    closeEvent(QCloseEvent* e);
-	virtual void    postSelection(const QPoint& point);
-	virtual void    endSelection(const QPoint& point);
-	virtual void    mouseDoubleClickEvent(QMouseEvent* e);
-	virtual void    wheelEvent(QWheelEvent* e);
-	virtual void    mouseMoveEvent(QMouseEvent* e);
-	virtual void    mousePressEvent(QMouseEvent* e);
-	virtual QString helpString() const;
+	virtual string getRealTimeString() const;
+	void           closeEvent(QCloseEvent* e) override;
+	void           postSelection(const QPoint& point) override;
+	void           endSelection(const QPoint& point) override;
+	void           mouseDoubleClickEvent(QMouseEvent* e) override;
+	void           wheelEvent(QWheelEvent* e) override;
+	void           mouseMoveEvent(QMouseEvent* e) override;
+	void           mousePressEvent(QMouseEvent* e) override;
+	QString        helpString() const override;
 
 	// Draws text, where each letter has a shifted background letter of opposite color.
 	void drawReadableNum(const Real& n, const Vector3r& pos, unsigned precision = 4, const Vector3r& color = Vector3r(1, 1, 1));
@@ -162,7 +167,11 @@ protected:
 };
 
 class YadeCamera : public qglviewer::Camera {
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
 	Q_OBJECT
+#pragma GCC diagnostic pop
 private:
 	float cuttingDistance;
 
@@ -174,7 +183,7 @@ public:
 #else
 	using QGLCompatDouble = float;
 #endif
-	virtual QGLCompatDouble zNear() const;
+	QGLCompatDouble zNear() const override;
 
 	virtual void setCuttingDistance(float s) { cuttingDistance = s; };
 };
