@@ -94,10 +94,10 @@ namespace CGT {
 		using _N::surfaceSolidThroatInPore;
 		using _N::tesselation;
 
-		void interpolate(Tesselation& Tes, Tesselation& NewTes);
-		void computeFacetForcesWithCache(bool onlyCache = false);
-		void computePermeability();
-		void gaussSeidel(Real dt = 0);
+		void interpolate(Tesselation& Tes, Tesselation& NewTes) override;
+		void computeFacetForcesWithCache(bool onlyCache = false) override;
+		void computePermeability() override;
+		void gaussSeidel(Real dt = 0) override;
 		void displayStatistics();
 #ifdef EIGENSPARSE_LIB
 		//Eigen's sparse matrix for forces computation
@@ -114,20 +114,19 @@ namespace CGT {
 		RTriangulation& Tri = Tes.Triangulation();
 		for (VCellIterator cellIt = NewTes.cellHandles.begin(); cellIt != NewTes.cellHandles.end(); cellIt++) {
 			CellHandle& newCell = *cellIt;
-			if (newCell->info().Pcondition || newCell->info().isGhost)
-				continue;
+			if (newCell->info().Pcondition || newCell->info().isGhost) continue;
 			CVector center(0, 0, 0);
 			if (newCell->info().fictious() == 0)
 				for (int k = 0; k < 4; k++)
 					center = center + 0.25 * (Tes.vertex(newCell->vertex(k)->info().id())->point().point() - CGAL::ORIGIN);
 			else {
 				Real boundPos = 0;
-				int  coord    = 0;
+				int  coord = 0;
 				for (int k = 0; k < 4; k++) {
 					if (!newCell->vertex(k)->info().isFictious)
 						center = center + 0.3333333333 * (Tes.vertex(newCell->vertex(k)->info().id())->point().point() - CGAL::ORIGIN);
 					else {
-						coord    = boundary(newCell->vertex(k)->info().id()).coordinate;
+						coord = boundary(newCell->vertex(k)->info().id()).coordinate;
 						boundPos = boundary(newCell->vertex(k)->info().id()).p[coord];
 					}
 				}
@@ -146,16 +145,15 @@ namespace CGT {
 		RTriangulation&        Tri = T[currentTes].Triangulation();
 		CVector                nullVect(0, 0, 0);
 		static vector<CVector> oldForces;
-		if (oldForces.size() <= Tri.number_of_vertices())
-			oldForces.resize(Tri.number_of_vertices() + 1);
+		if (oldForces.size() <= Tri.number_of_vertices()) oldForces.resize(Tri.number_of_vertices() + 1);
 		//reset forces
 		for (FiniteVerticesIterator v = Tri.finite_vertices_begin(); v != Tri.finite_vertices_end(); ++v) {
 			if (noCache) {
 				oldForces[v->info().id()] = nullVect;
-				v->info().forces          = nullVect;
+				v->info().forces = nullVect;
 			} else {
 				oldForces[v->info().id()] = v->info().forces;
-				v->info().forces          = nullVect;
+				v->info().forces = nullVect;
 			}
 		}
 		CellHandle   neighbourCell;
@@ -173,12 +171,12 @@ namespace CGT {
 						// 				#ifdef EIGENSPARSE_LIB
 						// 				if (!cell->info().Pcondition) ++nPCells;
 						// 				#endif
-						neighbourCell        = cell->neighbor(j);
+						neighbourCell = cell->neighbor(j);
 						const CVector& Surfk = cell->info().facetSurfaces[j];
 						//FIXME : later compute that fluidSurf only once in hydraulicRadius, for now keep full surface not modified in cell->info for comparison with other forces schemes
 						//The ratio void surface / facet surface
-						Real                        area          = sqrt(Surfk.squared_length());
-						CVector                     facetNormal   = Surfk / area;
+						Real                        area = sqrt(Surfk.squared_length());
+						CVector                     facetNormal = Surfk / area;
 						const std::vector<CVector>& crossSections = cell->info().facetSphereCrossSections;
 						CVector fluidSurfk = cell->info().facetSurfaces[j] * cell->info().facetFluidSurfacesRatio[j];
 						/// handle fictious vertex since we can get the projected surface easily here
@@ -186,7 +184,7 @@ namespace CGT {
 							using math::
 							        abs; // It has to be added because on ubuntu xenial 16.04 g++ 5.3.1 Argument Depended Lookup does not work in cases when function from one namespace is used inside another namespace to be found by ADL
 							Real projSurf = abs(Surfk[boundary(cell->vertex(j)->info().id()).coordinate]);
-							tempVect      = -projSurf * boundary(cell->vertex(j)->info().id()).normal;
+							tempVect = -projSurf * boundary(cell->vertex(j)->info().id()).normal;
 							//define the cached value for later use with cache*p
 							cell->info().unitForceVectors[j] = cell->info().unitForceVectors[j] + tempVect;
 						}
@@ -208,8 +206,7 @@ namespace CGT {
 			}
 
 			noCache = false; //cache should always be defined after execution of this function
-			if (onlyCache)
-				return;
+			if (onlyCache) return;
 		} // end if(noCache)
 
 		//use cached values
@@ -221,7 +218,7 @@ namespace CGT {
 		for (VCellIterator cellIt = T[currentTes].cellHandles.begin(); cellIt != T[currentTes].cellHandles.end(); cellIt++) {
 			const CellHandle& cell = *cellIt;
 			for (int yy = 0; yy < 4; yy++) {
-				VertexInfo& vhi        = cell->vertex(yy)->info();
+				VertexInfo& vhi = cell->vertex(yy)->info();
 				Real        unshiftedP = cell->info().p();
 				//the pressure translated to a ghost cell adjacent to the non-ghost vertex
 				unshiftedP -= pDeltas[0] * vhi.period[0] + pDeltas[1] * vhi.period[1] + pDeltas[2] * vhi.period[2];
@@ -235,8 +232,7 @@ namespace CGT {
 				if (!v->info().isFictious /*&& !v->info().isGhost*/) {
 					totalForce = totalForce + v->info().forces;
 				} else /*if (!v->info().isGhost)*/ {
-					if (boundary(v->info().id()).flowCondition == 1)
-						totalForce = totalForce + v->info().forces;
+					if (boundary(v->info().id()).flowCondition == 1) totalForce = totalForce + v->info().forces;
 				}
 			}
 			cout << "totalForce = " << totalForce << endl;
@@ -245,8 +241,7 @@ namespace CGT {
 
 	template <class _Tesselation> void PeriodicFlow<_Tesselation>::computePermeability()
 	{
-		if (debugOut)
-			cout << "----Computing_Permeability (Periodic)------" << endl;
+		if (debugOut) cout << "----Computing_Permeability (Periodic)------" << endl;
 		RTriangulation& Tri = T[currentTes].Triangulation();
 		VSolidTot = 0, Vtotalissimo = 0, vPoral = 0, sSolidTot = 0, vTotalPorosity = 0, vPoralPorosity = 0;
 		CellHandle neighbourCell;
@@ -255,22 +250,20 @@ namespace CGT {
 		int         surfneg = 0;
 		int         NEG = 0, POS = 0, pass = 0;
 		Real        meanK = 0, STDEV = 0, meanRadius = 0, meanDistance = 0;
-		Real        infiniteK       = 1e3;
+		Real        infiniteK = 1e3;
 		Real        volume_sub_pore = 0.f;
-		VectorCell& cellHandles     = T[currentTes].cellHandles;
+		VectorCell& cellHandles = T[currentTes].cellHandles;
 		for (VCellIterator cellIt = T[currentTes].cellHandles.begin(); cellIt != T[currentTes].cellHandles.end(); cellIt++) {
 			CellHandle& cell = *cellIt;
-			Point&      p1   = cell->info();
-			if (cell->info().blocked) {
-				this->setBlocked(cell);
-			}
+			Point&      p1 = cell->info();
+			if (cell->info().blocked) { this->setBlocked(cell); }
 			if (cell->info().isGhost) {
 				cerr << "skipping a ghost" << endl;
 				continue;
 			}
 			for (int j = 0; j < 4; j++) {
 				neighbourCell = cell->neighbor(j);
-				Point& p2     = neighbourCell->info();
+				Point& p2 = neighbourCell->info();
 				if (!Tri.is_infinite(neighbourCell) /*&& (neighbour_cell->info().isvisited==ref || computeAllCells)*/) {
 					//compute and store the area of sphere-facet intersections for later use
 					VertexHandle W[3];
@@ -315,40 +308,32 @@ namespace CGT {
 
 					pass += 1;
 					CVector l = p1 - p2;
-					distance  = sqrt(l.squared_length());
-					if (!rAverage)
-						radius = 2 * this->computeHydraulicRadius(cell, j);
+					distance = sqrt(l.squared_length());
+					if (!rAverage) radius = 2 * this->computeHydraulicRadius(cell, j);
 					else
 						radius = (this->computeEffectiveRadius(cell, j) + this->computeEquivalentRadius(cell, j)) * 0.5;
-					if (radius < 0)
-						NEG++;
+					if (radius < 0) NEG++;
 					else
 						POS++;
-					if (radius == 0) {
-						cout << "INS-INS PROBLEM!!!!!!!" << endl;
-					}
+					if (radius == 0) { cout << "INS-INS PROBLEM!!!!!!!" << endl; }
 					Real fluidArea = 0;
-					int  test      = 0;
+					int  test = 0;
 					if (distance != 0) {
-						if (minPermLength > 0 && distanceCorrection)
-							distance = math::max(minPermLength * radius, distance);
-						const CVector& Surfk         = cell->info().facetSurfaces[j];
-						Real           area          = sqrt(Surfk.squared_length());
+						if (minPermLength > 0 && distanceCorrection) distance = math::max(minPermLength * radius, distance);
+						const CVector& Surfk = cell->info().facetSurfaces[j];
+						Real           area = sqrt(Surfk.squared_length());
 						const CVector& crossSections = cell->info().facetSphereCrossSections[j];
-						Real           S0            = 0;
-						S0                           = checkSphereFacetOverlap(v0, v1, v2);
-						if (S0 == 0)
-							S0 = checkSphereFacetOverlap(v1, v2, v0);
-						if (S0 == 0)
-							S0 = checkSphereFacetOverlap(v2, v0, v1);
+						Real           S0 = 0;
+						S0 = checkSphereFacetOverlap(v0, v1, v2);
+						if (S0 == 0) S0 = checkSphereFacetOverlap(v1, v2, v0);
+						if (S0 == 0) S0 = checkSphereFacetOverlap(v2, v0, v1);
 						//take absolute value, since in rare cases the surface can be negative (overlaping spheres)
 						using math::
 						        abs; // It has to be added because on ubuntu xenial 16.04 g++ 5.3.1 Argument Depended Lookup does not work in cases when function from one namespace is used inside another namespace to be found by ADL
 						fluidArea = abs(area - crossSections[0] - crossSections[1] - crossSections[2] + S0);
 						cell->info().facetFluidSurfacesRatio[j] = fluidArea / area;
 						// kFactor<0 means we replace Poiseuille by Darcy localy, yielding a particle size-independent bulk conductivity
-						if (kFactor > 0)
-							cell->info().kNorm()[j] = kFactor * (fluidArea * pow(radius, 2)) / (8 * viscosity * distance);
+						if (kFactor > 0) cell->info().kNorm()[j] = kFactor * (fluidArea * pow(radius, 2)) / (8 * viscosity * distance);
 						else
 							cell->info().kNorm()[j] = -kFactor * area / distance;
 						meanDistance += distance;
@@ -379,7 +364,7 @@ namespace CGT {
 					// 							}
 					// 					}
 					if (permeabilityMap) {
-						CellHandle c   = cell;
+						CellHandle c = cell;
 						cell->info().s = cell->info().s + k * distance / fluidArea * this->volumePoreVoronoiFraction(c, j);
 						volume_sub_pore += this->volumePoreVoronoiFraction(c, j);
 					}
@@ -387,15 +372,14 @@ namespace CGT {
 			}
 			// 			cell->info().isvisited = !ref;
 			if (permeabilityMap) {
-				cell->info().s  = cell->info().s / volume_sub_pore;
+				cell->info().s = cell->info().s / volume_sub_pore;
 				volume_sub_pore = 0.f;
 			}
 			// 		}
 		}
 
 
-		if (debugOut)
-			cout << "surfneg est " << surfneg << endl;
+		if (debugOut) cout << "surfneg est " << surfneg << endl;
 		meanK /= pass;
 		meanRadius /= pass;
 		meanDistance /= pass;
@@ -434,16 +418,14 @@ namespace CGT {
 					}
 				}
 			}
-		if (debugOut)
-			cout << "PassKcorrect = " << pass << endl;
+		if (debugOut) cout << "PassKcorrect = " << pass << endl;
 
-		if (debugOut)
-			cout << "POS = " << POS << " NEG = " << NEG << " pass = " << pass << endl;
+		if (debugOut) cout << "POS = " << POS << " NEG = " << NEG << " pass = " << pass << endl;
 
 		// A loop to compute the standard deviation of the local K distribution, and use it to include/exclude K values higher then (meanK +/- K_opt_factor*STDEV)
 		if (meanKStat) {
 			std::ofstream k_opt_file("k_stdev.txt", std::ios::out);
-			pass                        = 0;
+			pass = 0;
 			FiniteCellsIterator cellEnd = Tri.finite_cells_end();
 			for (FiniteCellsIterator cell = Tri.finite_cells_begin(); cell != cellEnd; cell++) {
 				for (int j = 0; j < 4; j++) {
@@ -455,8 +437,7 @@ namespace CGT {
 				}
 			}
 			STDEV = sqrt(STDEV / pass);
-			if (debugOut)
-				cout << "PassSTDEV = " << pass << endl;
+			if (debugOut) cout << "PassSTDEV = " << pass << endl;
 			cout << "STATISTIC K" << endl;
 			Real k_min = 0, k_max = meanK + KOptFactor * STDEV;
 			cout << "Kmoy = " << meanK << " Standard Deviation = " << STDEV << endl;
@@ -468,20 +449,19 @@ namespace CGT {
 					if (!Tri.is_infinite(neighbourCell) /*&& neighbour_cell->info().isvisited==ref*/) {
 						pass += 1;
 						if ((cell->info().kNorm())[j] > k_max) {
-							(cell->info().kNorm())[j]                                  = k_max;
+							(cell->info().kNorm())[j] = k_max;
 							(neighbourCell->info().kNorm())[Tri.mirror_index(cell, j)] = (cell->info().kNorm())[j];
 						}
 						k_opt_file << KOptFactor << " " << (cell->info().kNorm())[j] << endl;
 					}
 				}
 			}
-			if (debugOut)
-				cout << "PassKopt = " << pass << endl;
+			if (debugOut) cout << "PassKopt = " << pass << endl;
 		}
 		if (debugOut) {
 			FiniteVerticesIterator verticesEnd = Tri.finite_vertices_end();
-			Real                   Vgrains     = 0;
-			int                    grains      = 0;
+			Real                   Vgrains = 0;
+			int                    grains = 0;
 
 			for (FiniteVerticesIterator vIt = Tri.finite_vertices_begin(); vIt != verticesEnd; vIt++) {
 				if (!vIt->info().isFictious && !vIt->info().isGhost) {
@@ -495,8 +475,7 @@ namespace CGT {
 			     << " sSolidTot = " << sSolidTot << endl
 			     << endl;
 
-			if (!rAverage)
-				cout << "------Hydraulic Radius is used for permeability computation------" << endl << endl;
+			if (!rAverage) cout << "------Hydraulic Radius is used for permeability computation------" << endl << endl;
 			else
 				cout << "------Average Radius is used for permeability computation------" << endl << endl;
 			cout << "-----computed_Permeability Periodic-----" << endl;
@@ -507,12 +486,12 @@ namespace CGT {
 	template <class _Tesselation> void PeriodicFlow<_Tesselation>::gaussSeidel(Real dt)
 	{
 		RTriangulation& Tri = T[currentTes].Triangulation();
-		int             j   = 0;
+		int             j = 0;
 		Real            m, n, dp_max, p_max, sum_p, dp, sum_dp;
 		Real            compFlowFactor = 0;
 		vector<Real>    previousP;
 		previousP.resize(Tri.number_of_finite_cells());
-		const int num_threads  = 1;
+		const int num_threads = 1;
 		bool      compressible = fluidBulkModulus > 0;
 
 		vector<Real> t_sum_p, t_dp_max, t_sum_dp, t_p_max;
@@ -523,41 +502,37 @@ namespace CGT {
 		FiniteCellsIterator cellEnd = Tri.finite_cells_end();
 		do {
 			int cell2 = 0;
-			dp_max    = 0;
-			p_max     = 0;
-			sum_p     = 0;
-			sum_dp    = 0;
-			int bb    = -1;
+			dp_max = 0;
+			p_max = 0;
+			sum_p = 0;
+			sum_dp = 0;
+			int bb = -1;
 			for (FiniteCellsIterator cell = Tri.finite_cells_begin(); cell != cellEnd; cell++) {
 				bb++;
 				if (!cell->info().Pcondition && !cell->info().isGhost) {
 					cell2++;
-					if (compressible && j == 0)
-						previousP[bb] = cell->info().shiftedP();
+					if (compressible && j == 0) previousP[bb] = cell->info().shiftedP();
 					m = 0, n = 0;
 					for (int j2 = 0; j2 < 4; j2++) {
 						if (!Tri.is_infinite(cell->neighbor(j2))) {
 							if (compressible) {
 								compFlowFactor = fluidBulkModulus * dt * cell->info().invVoidVolume();
 								m += compFlowFactor * (cell->info().kNorm())[j2] * cell->neighbor(j2)->info().shiftedP();
-								if (j == 0)
-									n += compFlowFactor * (cell->info().kNorm())[j2];
+								if (j == 0) n += compFlowFactor * (cell->info().kNorm())[j2];
 							} else {
 								m += (cell->info().kNorm())[j2] * cell->neighbor(j2)->info().shiftedP();
 								if (math::isinf(m) && j < 10)
 									cout << "(cell->info().kNorm())[j2] = " << (cell->info().kNorm())[j2]
 									     << " cell->neighbor(j2)->info().shiftedP() = "
 									     << cell->neighbor(j2)->info().shiftedP() << endl;
-								if (j == 0)
-									n += (cell->info().kNorm())[j2];
+								if (j == 0) n += (cell->info().kNorm())[j2];
 							}
 						}
 					}
 					dp = cell->info().p();
 					if (n != 0 || j != 0) {
 						if (j == 0) {
-							if (compressible)
-								cell->info().invSumK = 1 / (1 + n);
+							if (compressible) cell->info().invSumK = 1 / (1 + n);
 							else
 								cell->info().invSumK = 1 / n;
 						}
@@ -577,15 +552,14 @@ namespace CGT {
 					}
 					dp -= cell->info().p();
 					dp_max = math::max(dp_max, math::abs(dp));
-					p_max  = math::max(p_max, math::abs(cell->info().shiftedP()));
+					p_max = math::max(p_max, math::abs(cell->info().shiftedP()));
 					sum_p += cell->info().shiftedP();
 					sum_dp += math::abs(dp);
 				}
 			}
 			j++;
 
-			if (j >= 40000)
-				cerr << "\r GS not converged after 40k iterations, break";
+			if (j >= 40000) cerr << "\r GS not converged after 40k iterations, break";
 
 		} while ((dp_max / p_max) > tolerance && j < 40000 /*&& ( dp_max > tolerance )*/ /* &&*/ /*( j<50 )*/);
 
@@ -600,35 +574,30 @@ namespace CGT {
 
 	template <class _Tesselation> void PeriodicFlow<_Tesselation>::displayStatistics()
 	{
-		RTriangulation&     Tri  = T[currentTes].Triangulation();
+		RTriangulation&     Tri = T[currentTes].Triangulation();
 		int                 Zero = 0, Inside = 0, Fictious = 0, ghostC = 0, realC = 0, ghostV = 0, realV = 0;
 		FiniteCellsIterator cellEnd = Tri.finite_cells_end();
 		for (FiniteCellsIterator cell = Tri.finite_cells_begin(); cell != cellEnd; cell++) {
 			int zeros = 0;
 			for (int j = 0; j != 4; j++)
-				if ((cell->info().kNorm())[j] == 0)
-					zeros += 1;
-			if (zeros == 4)
-				Zero += 1;
-			if (!cell->info().fictious())
-				Inside += 1;
+				if ((cell->info().kNorm())[j] == 0) zeros += 1;
+			if (zeros == 4) Zero += 1;
+			if (!cell->info().fictious()) Inside += 1;
 			else
 				Fictious += 1;
-			if (cell->info().isGhost)
-				ghostC += 1;
+			if (cell->info().isGhost) ghostC += 1;
 			else
 				realC += 1;
 		}
 		int fict = 0, real = 0;
 		for (FiniteVerticesIterator v = Tri.finite_vertices_begin(); v != Tri.finite_vertices_end(); ++v) {
-			if (v->info().isFictious)
-				fict += 1;
+			if (v->info().isFictious) fict += 1;
 			else
 				real += 1;
 		}
 		long Vertices = Tri.number_of_vertices();
-		long Cells    = Tri.number_of_finite_cells();
-		long Facets   = Tri.number_of_finite_facets();
+		long Cells = Tri.number_of_finite_cells();
+		long Facets = Tri.number_of_finite_facets();
 		if (debugOut) {
 			cout << "zeros = " << Zero << endl;
 			cout << "There are " << Vertices << " vertices, dont " << fict << " fictious et " << real << " reeeeeel" << std::endl;
@@ -640,8 +609,8 @@ namespace CGT {
 			cout << "There are " << Fictious << " cells FICTIOUS." << endl;
 		}
 		vtkInfiniteVertices = fict;
-		vtkInfiniteCells    = Fictious;
-		num_particles       = real;
+		vtkInfiniteCells = Fictious;
+		num_particles = real;
 	}
 
 } //END NAMESPACE CGT
