@@ -8,8 +8,7 @@ namespace yade { // Cannot have #include directive inside.
 
 class NormPhys : public IPhys {
 public:
-	virtual ~NormPhys() {};
-	virtual Vector3r getRotStiffness() { return Vector3r::Zero(); }
+	virtual ~NormPhys() = default;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(NormPhys,IPhys,"Abstract class for interactions that have normal stiffness.",
 		((Real,kn,0,,"Normal stiffness"))
@@ -23,10 +22,10 @@ REGISTER_SERIALIZABLE(NormPhys);
 
 class NormShearPhys : public NormPhys {
 public:
-	virtual ~NormShearPhys() {};
+	virtual ~NormShearPhys() = default;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(NormShearPhys,NormPhys,
-		"Abstract class for interactions that have shear stiffnesses, in addition to normal stiffness. This class is used in the PFC3d-style stiffness timestepper.",
+		"Abstract class for interactions that have shear stiffnesses, in addition to normal stiffness. This class is used in the PFC3d-style :yref:`stiffness timestepper<GlobalStiffnessTimeStepper>`.",
 		((Real,ks,0,,"Shear stiffness"))
 		((Vector3r,shearForce,Vector3r::Zero(),,"Shear force after previous step (in global coordinates), as sustained by particle #2 (from particle #1).")),
 		createIndex();
