@@ -61,9 +61,9 @@ boost::tuple<Vector3r, bool, double, double, double> Ig2_Sphere_PFacet_ScGridCoG
 
 	// Compute the barycentric coordinates of the projection P
 	Real invDenom = 1 / (dot00 * dot11 - dot01 * dot01);
-	Real p1       = (dot11 * dot02 - dot01 * dot12) * invDenom;
-	Real p2       = (dot00 * dot12 - dot01 * dot02) * invDenom;
-	Real p3       = 1 - p1 - p2;
+	Real p2       = (dot11 * dot02 - dot01 * dot12) * invDenom;
+	Real p3       = (dot00 * dot12 - dot01 * dot02) * invDenom;
+	Real p1       = 1 - p2 - p3;
 
 	// Check if P is in triangle
 	bool isintriangle = (p1 > 0) && (p2 > 0) && (p1 + p2 < 1);
@@ -110,13 +110,11 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 	shared_ptr<ScGridCoGeom> scm;
 	bool                     isNew = !(c->geom);
 
-	if (c->geom)
-		scm = YADE_PTR_CAST<ScGridCoGeom>(c->geom);
+	if (c->geom) scm = YADE_PTR_CAST<ScGridCoGeom>(c->geom);
 	else
 		scm = shared_ptr<ScGridCoGeom>(new ScGridCoGeom());
 
-	if (scm->isDuplicate == 2 && scm->trueInt != c->id2)
-		return true; //the contact will be deleted into the Law, no need to compute here.
+	if (scm->isDuplicate == 2 && scm->trueInt != c->id2) return true; //the contact will be deleted into the Law, no need to compute here.
 	scm->isDuplicate = 0;
 	scm->trueInt     = -1;
 
@@ -184,12 +182,9 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 		}
 	} else {
 		// 		identification of the cylinder possibly in contact with the sphere
-		if (isconn1)
-			connnum = 0;
-		if (isconn2)
-			connnum = 1;
-		if (isconn3)
-			connnum = 2;
+		if (isconn1) connnum = 0;
+		if (isconn2) connnum = 1;
+		if (isconn3) connnum = 2;
 		// 		check if the identified cylinder  previously is in contact with the sphere
 		if (connnum != -1) {
 			//verify if there is a contact between the a neighbouring PFacet, avoid double contacts
@@ -231,10 +226,8 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 			Vector3r branch    = spherePos - gridNo1St->pos;
 			Vector3r branchN   = spherePos - gridNo2St->pos;
 			for (int i = 0; i < 3; i++) {
-				if (math::abs(branch[i]) < 1e-14)
-					branch[i] = 0.0;
-				if (math::abs(branchN[i]) < 1e-14)
-					branchN[i] = 0.0;
+				if (math::abs(branch[i]) < 1e-14) branch[i] = 0.0;
+				if (math::abs(branchN[i]) < 1e-14) branchN[i] = 0.0;
 			}
 			Real relPos = branch.dot(segt) / (len * len);
 			bool SGr    = true;
@@ -242,15 +235,13 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 				if (gridNo1->ConnList.size() > 1) { //	if the node is not an extremity of the Grid (only one connection)
 					for (int unsigned i = 0; i < gridNo1->ConnList.size(); i++) { // ... loop on all the Connections of the same Node ...
 						GridConnection* GC = (GridConnection*)gridNo1->ConnList[i]->shape.get();
-						if (GC == gridCo)
-							continue; //	self comparison.
+						if (GC == gridCo) continue; //	self comparison.
 						Vector3r segtCandidate1 = GC->node1->state->pos
 						        - gridNo1St->pos; // (be sure of the direction of segtPrev to compare relPosPrev.)
 						Vector3r segtCandidate2 = GC->node2->state->pos - gridNo1St->pos;
 						Vector3r segtPrev       = segtCandidate1.norm() > segtCandidate2.norm() ? segtCandidate1 : segtCandidate2;
 						for (int j = 0; j < 3; j++) {
-							if (math::abs(segtPrev[j]) < 1e-14)
-								segtPrev[j] = 0.0;
+							if (math::abs(segtPrev[j]) < 1e-14) segtPrev[j] = 0.0;
 						}
 						Real relPosPrev = (branch.dot(segtPrev)) / (segtPrev.norm() * segtPrev.norm());
 						// ... and check whether the sphere projection is before the neighbours connections too.
@@ -292,14 +283,12 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 				if (gridNo2->ConnList.size() > 1) {
 					for (int unsigned i = 0; i < gridNo2->ConnList.size(); i++) {
 						GridConnection* GC = (GridConnection*)gridNo2->ConnList[i]->shape.get();
-						if (GC == gridCo)
-							continue; //	self comparison.
+						if (GC == gridCo) continue; //	self comparison.
 						Vector3r segtCandidate1 = GC->node1->state->pos - gridNo2St->pos;
 						Vector3r segtCandidate2 = GC->node2->state->pos - gridNo2St->pos;
 						Vector3r segtNext       = segtCandidate1.norm() > segtCandidate2.norm() ? segtCandidate1 : segtCandidate2;
 						for (int j = 0; j < 3; j++) {
-							if (math::abs(segtNext[j]) < 1e-14)
-								segtNext[j] = 0.0;
+							if (math::abs(segtNext[j]) < 1e-14) segtNext[j] = 0.0;
 						}
 
 						Real relPosNext = (branchN.dot(segtNext)) / (segtNext.norm() * segtNext.norm());
@@ -312,8 +301,7 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 									if (intr && intr->isReal()) {
 										shared_ptr<ScGridCoGeom> intrGeom = YADE_PTR_CAST<ScGridCoGeom>(intr->geom);
 										if (!(intrGeom->isDuplicate == 1)) {
-											if (isNew)
-												SGr = false;
+											if (isNew) SGr = false;
 											else
 												scm->isDuplicate
 												        = 1; /*cout<<"Declare "<<c->id1<<"-"<<c->id2<<" as duplicated."<<endl;*/
@@ -322,8 +310,7 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 								}
 							}
 						} else { //the sphere projection is outside the current Connection but inside the previous neighbour. The contact has to be handled by the Prev GridConnection, not here.
-							if (isNew)
-								SGr = false;
+							if (isNew) SGr = false;
 							else { //cout<<"The contact "<<c->id1<<"-"<<c->id2<<" HAVE to be copied and deleted NOW."<<endl ;
 								scm->isDuplicate = 1;
 								scm->trueInt     = -1;
@@ -336,16 +323,14 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 				if (gridNo1->ConnList.size() > 1) { //	if the node is not an extremity of the Grid (only one connection)
 					for (int unsigned i = 0; i < gridNo1->ConnList.size(); i++) { // ... loop on all the Connections of the same Node ...
 						GridConnection* GC = (GridConnection*)gridNo1->ConnList[i]->shape.get();
-						if (GC == gridCo)
-							continue; //	self comparison.
+						if (GC == gridCo) continue; //	self comparison.
 
 						Vector3r segtCandidate1 = GC->node1->state->pos
 						        - gridNo1St->pos; // (be sure of the direction of segtPrev to compare relPosPrev.)
 						Vector3r segtCandidate2 = GC->node2->state->pos - gridNo1St->pos;
 						Vector3r segtPrev       = segtCandidate1.norm() > segtCandidate2.norm() ? segtCandidate1 : segtCandidate2;
 						for (int j = 0; j < 3; j++) {
-							if (math::abs(segtPrev[j]) < 1e-14)
-								segtPrev[j] = 0.0;
+							if (math::abs(segtPrev[j]) < 1e-14) segtPrev[j] = 0.0;
 						}
 						Real relPosPrev = (branch.dot(segtPrev)) / (segtPrev.norm() * segtPrev.norm());
 						if (relPosPrev
@@ -380,14 +365,12 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 				if (gridNo2->ConnList.size() > 1) {
 					for (int unsigned i = 0; i < gridNo2->ConnList.size(); i++) {
 						GridConnection* GC = (GridConnection*)gridNo2->ConnList[i]->shape.get();
-						if (GC == gridCo)
-							continue; //	self comparison.
+						if (GC == gridCo) continue; //	self comparison.
 						Vector3r segtCandidate1 = GC->node1->state->pos - gridNo2St->pos;
 						Vector3r segtCandidate2 = GC->node2->state->pos - gridNo2St->pos;
 						Vector3r segtNext       = segtCandidate1.norm() > segtCandidate2.norm() ? segtCandidate1 : segtCandidate2;
 						for (int j = 0; j < 3; j++) {
-							if (math::abs(segtNext[j]) < 1e-14)
-								segtNext[j] = 0.0;
+							if (math::abs(segtNext[j]) < 1e-14) segtNext[j] = 0.0;
 						}
 						Real relPosNext = (branchN.dot(segtNext)) / (segtNext.norm() * segtNext.norm());
 						if (relPosNext
@@ -424,8 +407,7 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 				bool SG    = !(isNew && (dist2 > (sphere->radius + gridCo->radius)));
 				if (SG) {
 					//	Create the geometry :
-					if (isNew)
-						c->geom = scm;
+					if (isNew) c->geom = scm;
 					scm->radius1 = sphere->radius;
 					scm->radius2 = gridCo->radius;
 					scm->id3     = gridCo->node1->getId();
@@ -492,8 +474,7 @@ bool Ig2_Sphere_PFacet_ScGridCoGeom::go(
 		penetrationDepth = sphereRadius + PFacetradius - math::abs(dist);
 		normal.normalize();
 		if (penetrationDepth > 0 || c->isReal()) {
-			if (isNew)
-				c->geom = scm;
+			if (isNew) c->geom = scm;
 			scm->radius1              = sphereRadius;
 			scm->radius2              = PFacetradius;
 			scm->id3                  = Pfacet->node1->getId();
@@ -569,8 +550,8 @@ bool Ig2_GridConnection_PFacet_ScGeom::go(
 		oss << chaine << entier;
 		string chaine1 = oss.str();
 		if (!scene->interactions->found(id1, ids2[i])) {
-			shared_ptr<Interaction> chaine1(new Interaction(id1, ids2[i]));
-			scene->interactions->insert(chaine1);
+			shared_ptr<Interaction> chain1(new Interaction(id1, ids2[i]));
+			scene->interactions->insert(chain1);
 		}
 	}
 
@@ -633,13 +614,12 @@ bool Ig2_PFacet_PFacet_ScGeom::go(
 	bool istriangleNodes2P1 = (isintriangle1 == true) && (isintriangle2 == true) && (isintriangle3 == true);
 	bool istriangleNodes1P2 = (isintriangle4 == true) && (isintriangle5 == true) && (isintriangle6 == true);
 
-
 	if (istriangleNodes1P2) {
 		Body::id_t idNode11 = Pfacet1->node1->getId();
 		Body::id_t idNode12 = Pfacet1->node2->getId();
 		Body::id_t idNode13 = Pfacet1->node3->getId();
 
-
+		// FIXME: if projection of some nodes is in triangle but not in contact, do we need to create interaxctions here?
 		if (!scene->interactions->found(idNode11, id2)) {
 			shared_ptr<Interaction> scm1(new Interaction(idNode11, id2));
 			scene->interactions->insert(scm1);
@@ -675,133 +655,21 @@ bool Ig2_PFacet_PFacet_ScGeom::go(
 			scene->interactions->insert(scm3);
 		}
 	} else {
-		vector<Vector3r> vertices1 = { Pfacet1->node1->state->pos, Pfacet1->node2->state->pos, Pfacet1->node3->state->pos };
-		vector<Vector3r> vertices2 = { Pfacet2->node1->state->pos, Pfacet2->node2->state->pos, Pfacet2->node3->state->pos };
-
-
-		GridConnection* gridCo1P1 = (GridConnection*)Pfacet1->conn1->shape.get();
-		GridConnection* gridCo2P1 = (GridConnection*)Pfacet1->conn2->shape.get();
-		GridConnection* gridCo3P1 = (GridConnection*)Pfacet1->conn3->shape.get();
-
-		GridConnection* gridCo1P2 = (GridConnection*)Pfacet2->conn1->shape.get();
-		GridConnection* gridCo2P2 = (GridConnection*)Pfacet2->conn2->shape.get();
-		GridConnection* gridCo3P2 = (GridConnection*)Pfacet2->conn3->shape.get();
-
-
-		State* gridNo1StgridCo1P1 = YADE_CAST<State*>(gridCo1P1->node1->state.get());
-		State* gridNo2StgridCo1P1 = YADE_CAST<State*>(gridCo1P1->node2->state.get());
-
-		State* gridNo1StgridCo2P1 = YADE_CAST<State*>(gridCo2P1->node1->state.get());
-		State* gridNo2StgridCo2P1 = YADE_CAST<State*>(gridCo2P1->node2->state.get());
-
-		State* gridNo1StgridCo3P1 = YADE_CAST<State*>(gridCo3P1->node1->state.get());
-		State* gridNo2StgridCo3P1 = YADE_CAST<State*>(gridCo3P1->node2->state.get());
-
-		State* gridNo1StgridCo1P2 = YADE_CAST<State*>(gridCo1P2->node1->state.get());
-		State* gridNo2StgridCo1P2 = YADE_CAST<State*>(gridCo1P2->node2->state.get());
-
-		State* gridNo1StgridCo2P2 = YADE_CAST<State*>(gridCo2P2->node1->state.get());
-		State* gridNo2StgridCo2P2 = YADE_CAST<State*>(gridCo2P2->node2->state.get());
-
-		State* gridNo1StgridCo3P2 = YADE_CAST<State*>(gridCo3P2->node1->state.get());
-		State* gridNo2StgridCo3P2 = YADE_CAST<State*>(gridCo3P2->node2->state.get());
-
-
-		Vector3r seg11 = (gridNo1StgridCo1P1->pos - gridNo2StgridCo1P1->pos) / (gridNo1StgridCo1P1->pos - gridNo2StgridCo1P1->pos).norm();
-		Vector3r seg12 = (gridNo1StgridCo2P1->pos - gridNo2StgridCo2P1->pos) / (gridNo1StgridCo2P1->pos - gridNo2StgridCo2P1->pos).norm();
-		Vector3r seg13 = (gridNo1StgridCo3P1->pos - gridNo2StgridCo3P1->pos) / (gridNo1StgridCo3P1->pos - gridNo2StgridCo3P1->pos).norm();
-
-
-		Vector3r seg21 = (gridNo1StgridCo1P2->pos - gridNo2StgridCo1P2->pos) / (gridNo1StgridCo1P2->pos - gridNo2StgridCo1P2->pos).norm();
-		Vector3r seg22 = (gridNo1StgridCo2P2->pos - gridNo2StgridCo2P2->pos) / (gridNo1StgridCo2P2->pos - gridNo2StgridCo2P2->pos).norm();
-		Vector3r seg23 = (gridNo1StgridCo3P2->pos - gridNo2StgridCo3P2->pos) / (gridNo1StgridCo3P2->pos - gridNo2StgridCo3P2->pos).norm();
-
-
-		Real normal1seg21seg11 = seg21.dot(seg11);
-		Real normal1seg21seg12 = seg21.dot(seg12);
-		Real normal1seg21seg13 = seg21.dot(seg13);
-
-		Real normal1seg22seg11 = seg22.dot(seg11);
-		Real normal1seg22seg12 = seg22.dot(seg12);
-		Real normal1seg22seg13 = seg22.dot(seg13);
-
-		Real normal1seg23seg11 = seg23.dot(seg11);
-		Real normal1seg23seg12 = seg23.dot(seg12);
-		Real normal1seg23seg13 = seg23.dot(seg13);
-
 		Body::id_t ids1[3] = { Pfacet1->conn1->getId(), Pfacet1->conn2->getId(), Pfacet1->conn3->getId() };
 		Body::id_t ids2[3] = { Pfacet2->conn1->getId(), Pfacet2->conn2->getId(), Pfacet2->conn3->getId() };
 
-		Body::id_t c1 = -1;
-		Body::id_t c2 = -1;
-
-
-		if (math::abs(normal1seg21seg11) == 1) {
-			c1 = ids2[0];
-			c2 = ids1[0];
-		}
-		if (math::abs(normal1seg21seg12) == 1) {
-			c1 = ids2[0];
-			c2 = ids1[1];
-		}
-		if (math::abs(normal1seg21seg13) == 1) {
-			c1 = ids2[0];
-			c2 = ids1[2];
-		}
-
-		if (math::abs(normal1seg22seg11) == 1) {
-			c1 = ids2[1];
-			c2 = ids1[0];
-		}
-		if (math::abs(normal1seg22seg12) == 1) {
-			c1 = ids2[1];
-			c2 = ids1[1];
-		}
-		if (math::abs(normal1seg22seg13) == 1) {
-			c1 = ids2[1];
-			c2 = ids1[2];
-		}
-
-		if (math::abs(normal1seg23seg11) == 1) {
-			c1 = ids2[2];
-			c2 = ids1[0];
-		}
-		if (math::abs(normal1seg23seg12) == 1) {
-			c1 = ids2[2];
-			c2 = ids1[1];
-		}
-		if (math::abs(normal1seg23seg13) == 1) {
-			c1 = ids2[2];
-			c2 = ids1[2];
-		}
-
 		if ((isintriangle1 == false) && (isintriangle2 == false) && (isintriangle3 == false) && (isintriangle4 == false) && (isintriangle5 == false)
 		    && (isintriangle6 == false)) {
-			if ((c1 != -1) and (c2 != -1) and (Body::byId(c1)->getGroupMask() != 0) and (Body::byId(c2)->getGroupMask() != 0)) {
-				std::ostringstream oss;
-				string             chaine = "scm";
-				if (!scene->interactions->found(c1, c2)) {
-					shared_ptr<Interaction> chaine(new Interaction(c1, c2));
-					scene->interactions->insert(chaine);
-				}
-			} else {
-				for (int i = 0; i < 3; i++) {
-					for (int j = 0; j < 3; j++) {
-						int                entier = j + i * 3;
-						std::ostringstream oss;
-						string             chaine = "scm";
-						oss << chaine << entier;
-						string chaine1 = oss.str();
-						if (!scene->interactions->found(ids1[i], ids2[j])) {
-							if ((Body::byId(ids1[i])->getGroupMask() != 0) and (Body::byId(ids2[j])->getGroupMask() != 0)) {
-								shared_ptr<Interaction> chaine1(new Interaction(ids1[i], ids2[j]));
-								scene->interactions->insert(chaine1);
-							}
+			for (int i = 0; i < 3; i++) {
+				for (int j = 0; j < 3; j++) {
+					if (!scene->interactions->found(ids1[i], ids2[j])) {
+						if ((Body::byId(ids1[i])->getGroupMask() != 0) and (Body::byId(ids2[j])->getGroupMask() != 0)) {
+							shared_ptr<Interaction> chain1(new Interaction(ids1[i], ids2[j]));
+							scene->interactions->insert(chain1);
 						}
 					}
 				}
 			}
-
 		} else {
 			Body::id_t idNode11 = Pfacet1->node1->getId();
 			Body::id_t idNode12 = Pfacet1->node2->getId();
@@ -855,15 +723,14 @@ bool Ig2_PFacet_PFacet_ScGeom::go(
 					string chaine1 = oss.str();
 					if (!scene->interactions->found(ids1a[i], ids2a[j])) {
 						if ((Body::byId(ids1a[i])->getGroupMask() != 0) and (Body::byId(ids2a[j])->getGroupMask() != 0)) {
-							shared_ptr<Interaction> chaine1(new Interaction(ids1a[i], ids2a[j]));
-							scene->interactions->insert(chaine1);
+							shared_ptr<Interaction> chain1(new Interaction(ids1a[i], ids2a[j]));
+							scene->interactions->insert(chain1);
 						}
 					}
 				}
 			}
 		}
 	}
-
 	return (false);
 }
 
@@ -924,9 +791,7 @@ YADE_PLUGIN((Ig2_Wall_PFacet_ScGeom));
 void Bo1_PFacet_Aabb::go(const shared_ptr<Shape>& cm, shared_ptr<Bound>& bv, const Se3r& /*se3*/, const Body* /*b*/)
 {
 	PFacet* Pfacet = YADE_CAST<PFacet*>(cm.get());
-	if (!bv) {
-		bv = shared_ptr<Bound>(new Aabb);
-	}
+	if (!bv) { bv = shared_ptr<Bound>(new Aabb); }
 	Aabb*    aabb = static_cast<Aabb*>(bv.get());
 	Vector3r O    = Pfacet->node1->state->pos;
 	Vector3r O2   = Pfacet->node2->state->pos;
