@@ -10,14 +10,14 @@ namespace yade { // Cannot have #include directive inside.
 
 class PeriodicEngine : public GlobalEngine {
 public:
-	static Real getClock()
+	static Real getClock() // FIXME - we have clock in lib/base/Timer.hpp
 	{
 		timeval tp;
 		gettimeofday(&tp, NULL);
 		return tp.tv_sec + tp.tv_usec / 1e6;
 	}
 	virtual ~PeriodicEngine() {}; // vtable
-	virtual bool isActivated()
+	bool isActivated() override
 	{
 		const Real& virtNow = scene->time;
 		Real        realNow = getClock();
@@ -34,8 +34,7 @@ public:
 			return false;
 		}
 
-		if (iterNow < iterLast)
-			nDone = 0; //handle O.resetTime(), all counters will be initialized again
+		if (iterNow < iterLast) nDone = 0; //handle O.resetTime(), all counters will be initialized again
 		if ((nDo < 0 || nDone < nDo)
 		    && ((virtPeriod > 0 && virtNow - virtLast >= virtPeriod) || (realPeriod > 0 && realNow - realLast >= realPeriod)
 		        || (iterPeriod > 0 && iterNow - iterLast >= iterPeriod))) {
@@ -51,8 +50,7 @@ public:
 			virtLast = virtNow;
 			iterLast = iterNow;
 			nDone++;
-			if (initRun)
-				return true;
+			if (initRun) return true;
 			return false;
 		}
 		return false;
