@@ -6,7 +6,7 @@
 *  GNU General Public License v2 or later. See file LICENSE for details. *
 *************************************************************************/
 #pragma once
-#include <pkg/common/Dispatching.hpp>
+#include <core/Dispatching.hpp>
 #include <pkg/common/ElastMat.hpp>
 #include <pkg/dem/FrictPhys.hpp>
 
@@ -42,7 +42,7 @@ REGISTER_SERIALIZABLE(CapillaryPhys);
 
 class Ip2_FrictMat_FrictMat_CapillaryPhys : public IPhysFunctor {
 public:
-	virtual void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction);
+	void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction) override;
 
 	FUNCTOR2D(FrictMat, FrictMat);
 	// clang-format off
