@@ -9,24 +9,19 @@
 namespace yade { // Cannot have #include directive inside.
 
 YADE_PLUGIN((MindlinPhys)(Ip2_FrictMat_FrictMat_MindlinPhys)(Law2_ScGeom_MindlinPhys_MindlinDeresiewitz)(Law2_ScGeom_MindlinPhys_HertzWithLinearShear)(
-        Law2_ScGeom_MindlinPhys_Mindlin)(MindlinCapillaryPhys)(Ip2_FrictMat_FrictMat_MindlinCapillaryPhys)
-#ifdef PARTIALSAT
-                    (PartialSatMat)(PartialSatState)(Ip2_PartialSatMat_PartialSatMat_MindlinPhys)
-#endif
-);
+        Law2_ScGeom_MindlinPhys_Mindlin)(MindlinCapillaryPhys)(Ip2_FrictMat_FrictMat_MindlinCapillaryPhys));
 
-Real Law2_ScGeom_MindlinPhys_Mindlin::getfrictionDissipation() { return (Real)frictionDissipation; }
-Real Law2_ScGeom_MindlinPhys_Mindlin::getshearEnergy() { return (Real)shearEnergy; }
-Real Law2_ScGeom_MindlinPhys_Mindlin::getnormDampDissip() { return (Real)normDampDissip; }
-Real Law2_ScGeom_MindlinPhys_Mindlin::getshearDampDissip() { return (Real)shearDampDissip; }
+Real Law2_ScGeom_MindlinPhys_Mindlin::getfrictionDissipation() const { return (Real)frictionDissipation; }
+Real Law2_ScGeom_MindlinPhys_Mindlin::getshearEnergy() const { return (Real)shearEnergy; }
+Real Law2_ScGeom_MindlinPhys_Mindlin::getnormDampDissip() const { return (Real)normDampDissip; }
+Real Law2_ScGeom_MindlinPhys_Mindlin::getshearDampDissip() const { return (Real)shearDampDissip; }
 
 /******************** Ip2_FrictMat_FrictMat_MindlinPhys *******/
 CREATE_LOGGER(Ip2_FrictMat_FrictMat_MindlinPhys);
 
 void Ip2_FrictMat_FrictMat_MindlinPhys::go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction)
 {
-	if (interaction->phys)
-		return; // no updates of an already existing contact necessary
+	if (interaction->phys) return; // no updates of an already existing contact necessary
 	shared_ptr<MindlinPhys> contactPhysics(new MindlinPhys());
 	interaction->phys = contactPhysics;
 	const auto mat1   = YADE_CAST<FrictMat*>(b1.get());
@@ -74,10 +69,8 @@ void Ip2_FrictMat_FrictMat_MindlinPhys::go(const shared_ptr<Material>& b1, const
 	contactPhysics->maxBendPl = eta * Rmean; // does this make sense? why do we take Rmean?
 
 	/* compute viscous coefficients */
-	if (en && betan)
-		throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinPhys: only one of en, betan can be specified.");
-	if (es && betas)
-		throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinPhys: only one of es, betas can be specified.");
+	if (en && betan) throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinPhys: only one of en, betan can be specified.");
+	if (es && betas) throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinPhys: only one of es, betas can be specified.");
 
 	// en or es specified, just compute alpha, otherwise alpha remains 0
 	if (en || es) {
@@ -99,12 +92,9 @@ Real Law2_ScGeom_MindlinPhys_Mindlin::contactsAdhesive() // It is returning some
 	Real contactsAdhesive = 0;
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		MindlinPhys* phys = dynamic_cast<MindlinPhys*>(I->phys.get());
-		if (phys->isAdhesive) {
-			contactsAdhesive += 1;
-		}
+		if (phys->isAdhesive) { contactsAdhesive += 1; }
 	}
 	return contactsAdhesive;
 }
@@ -116,12 +106,9 @@ Real Law2_ScGeom_MindlinPhys_Mindlin::ratioSlidingContacts()
 	int  count(0);
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		MindlinPhys* phys = dynamic_cast<MindlinPhys*>(I->phys.get());
-		if (phys->isSliding) {
-			ratio += 1;
-		}
+		if (phys->isSliding) { ratio += 1; }
 		count++;
 	}
 	ratio /= count;
@@ -134,8 +121,7 @@ Real Law2_ScGeom_MindlinPhys_Mindlin::normElastEnergy()
 	Real normEnergy = 0;
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		ScGeom*      scg  = dynamic_cast<ScGeom*>(I->geom.get());
 		MindlinPhys* phys = dynamic_cast<MindlinPhys*>(I->phys.get());
 		if (phys) {
@@ -155,8 +141,7 @@ Real Law2_ScGeom_MindlinPhys_Mindlin::adhesionEnergy()
 	Real adhesionEnergy = 0;
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		ScGeom*      scg  = dynamic_cast<ScGeom*>(I->geom.get());
 		MindlinPhys* phys = dynamic_cast<MindlinPhys*>(I->phys.get());
 		if (phys && includeAdhesion) {
@@ -187,8 +172,7 @@ bool Law2_ScGeom_MindlinPhys_MindlinDeresiewitz::go(shared_ptr<IGeom>& ig, share
 	Real Fn           = phys->kno * pow(uN, 3 / 2.);
 	phys->normalForce = Fn * geom->normal;
 	// exactly zero would not work with the shear formulation, and would give zero shear force anyway
-	if (Fn == 0)
-		return true;
+	if (Fn == 0) return true;
 	//phys->kn=3./2.*phys->kno*math::pow(uN,0.5); // update stiffness, not needed
 
 	// contact radius
@@ -257,8 +241,7 @@ bool Law2_ScGeom_MindlinPhys_HertzWithLinearShear::go(shared_ptr<IGeom>& ig, sha
 	Fs -= ks * shearIncrement;
 	// Mohr-Coulomb slip
 	Real maxFs2 = pow(Fn, 2) * pow(phys->tangensOfFrictionAngle, 2);
-	if (Fs.squaredNorm() > maxFs2)
-		Fs *= sqrt(maxFs2) / Fs.norm();
+	if (Fs.squaredNorm() > maxFs2) Fs *= sqrt(maxFs2) / Fs.norm();
 
 	// apply forces
 	Vector3r f = -phys->normalForce - phys->shearForce; /* should be a reference returned by geom->rotate */
@@ -292,9 +275,7 @@ bool Law2_ScGeom_MindlinPhys_Mindlin::go(shared_ptr<IGeom>& ig, shared_ptr<IPhys
 
 	bool useDamping = (phys->betan != 0. || phys->betas != 0. || phys->alpha != 0.);
 	bool LinDamp    = true;
-	if (phys->alpha != 0.) {
-		LinDamp = false;
-	} // use non linear damping
+	if (phys->alpha != 0.) { LinDamp = false; } // use non linear damping
 
 #ifdef PARTIALSAT
 	if (contact->isFresh(scene)) {
@@ -432,9 +413,7 @@ bool Law2_ScGeom_MindlinPhys_Mindlin::go(shared_ptr<IGeom>& ig, shared_ptr<IPhys
 				phys->normalForce -= phys->normalViscous;
 			}
 		}
-		if (calcEnergy) {
-			normDampDissip += phys->normalViscous.dot(incidentVn * dt);
-		} // calc dissipation of energy due to normal damping
+		if (calcEnergy) { normDampDissip += phys->normalViscous.dot(incidentVn * dt); } // calc dissipation of energy due to normal damping
 	}
 
 
@@ -521,9 +500,7 @@ bool Law2_ScGeom_MindlinPhys_Mindlin::go(shared_ptr<IGeom>& ig, shared_ptr<IPhys
 
 	if (useDamping) { // get normal viscous component (the shear one is calculated inside Mohr-Coulomb criterion, see above)
 		if (calcEnergy) {
-			if (!noShearDamp) {
-				shearDampDissip += phys->shearViscous.dot(incidentVs * dt);
-			}
+			if (!noShearDamp) { shearDampDissip += phys->shearViscous.dot(incidentVs * dt); }
 		} // calc energy dissipation due to viscous linear damping
 	}
 
@@ -623,8 +600,7 @@ void Ip2_FrictMat_FrictMat_MindlinCapillaryPhys::go(
         ,
         const shared_ptr<Interaction>& interaction)
 {
-	if (interaction->phys)
-		return; // no updates of an already existing contact necessary
+	if (interaction->phys) return; // no updates of an already existing contact necessary
 
 	shared_ptr<MindlinCapillaryPhys> contactPhysics(new MindlinCapillaryPhys());
 	interaction->phys = contactPhysics;
@@ -672,10 +648,8 @@ void Ip2_FrictMat_FrictMat_MindlinCapillaryPhys::go(
 	contactPhysics->maxBendPl = eta * Rmean; // does this make sense? why do we take Rmean?
 
 	/* compute viscous coefficients */
-	if (en && betan)
-		throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinCapillaryPhys: only one of en, betan can be specified.");
-	if (es && betas)
-		throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinCapillaryPhys: only one of es, betas can be specified.");
+	if (en && betan) throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinCapillaryPhys: only one of en, betan can be specified.");
+	if (es && betas) throw std::invalid_argument("Ip2_FrictMat_FrictMat_MindlinCapillaryPhys: only one of es, betas can be specified.");
 
 	// en or es specified, just compute alpha, otherwise alpha remains 0
 	if (en || es) {
@@ -690,80 +664,4 @@ void Ip2_FrictMat_FrictMat_MindlinCapillaryPhys::go(
 	}
 };
 
-#ifdef PARTIALSAT
-/******************** Ip2_PartialSatMat_PartialSatMat_MindlinPhys *******/
-CREATE_LOGGER(Ip2_PartialSatMat_PartialSatMat_MindlinPhys);
-
-void Ip2_PartialSatMat_PartialSatMat_MindlinPhys::go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction)
-{
-	if (interaction->phys)
-		return; // no updates of an already existing contact necessary
-	shared_ptr<MindlinPhys> contactPhysics(new MindlinPhys());
-	interaction->phys = contactPhysics;
-	const auto mat1   = YADE_CAST<FrictMat*>(b1.get());
-	const auto mat2   = YADE_CAST<FrictMat*>(b2.get());
-
-	/* from interaction physics */
-	const Real Ea = mat1->young;
-	const Real Eb = mat2->young;
-	const Real Va = mat1->poisson;
-	const Real Vb = mat2->poisson;
-	const Real fa = mat1->frictionAngle;
-	const Real fb = mat2->frictionAngle;
-
-
-	/* from interaction geometry */
-	const auto scg = YADE_CAST<GenericSpheresContact*>(interaction->geom.get());
-	const Real Da  = scg->refR1 > 0 ? scg->refR1 : scg->refR2;
-	const Real Db  = scg->refR2;
-	//Vector3r normal=scg->normal;        //The variable set but not used
-
-
-	/* calculate stiffness coefficients */
-	const Real Ga            = Ea / (2 * (1 + Va));
-	const Real Gb            = Eb / (2 * (1 + Vb));
-	const Real G             = (Ga + Gb) / 2;                                                           // average of shear modulus
-	const Real V             = (Va + Vb) / 2;                                                           // average of poisson's ratio
-	const Real E             = Ea * Eb / ((1. - math::pow(Va, 2)) * Eb + (1. - math::pow(Vb, 2)) * Ea); // Young modulus
-	const Real R             = Da * Db / (Da + Db);                                                     // equivalent radius
-	const Real Rmean         = (Da + Db) / 2.;                                                          // mean radius
-	const Real Kno           = 4. / 3. * E * sqrt(R);                                                   // coefficient for normal stiffness
-	const Real Kso           = 2 * sqrt(4 * R) * G / (2 - V);                                           // coefficient for shear stiffness
-	const Real frictionAngle = (!frictAngle) ? math::min(fa, fb) : (*frictAngle)(mat1->id, mat2->id, mat1->frictionAngle, mat2->frictionAngle);
-
-	const Real Adhesion = 4. * Mathr::PI * R * gamma; // calculate adhesion force as predicted by DMT theory
-
-	/* pass values calculated from above to MindlinPhys */
-	contactPhysics->tangensOfFrictionAngle = math::tan(frictionAngle);
-	//contactPhysics->prevNormal = scg->normal; // used to compute relative rotation
-	contactPhysics->kno           = Kno; // this is just a coeff
-	contactPhysics->kso           = Kso; // this is just a coeff
-	contactPhysics->adhesionForce = Adhesion;
-
-	contactPhysics->kr        = krot;
-	contactPhysics->ktw       = ktwist;
-	contactPhysics->maxBendPl = eta * Rmean; // does this make sense? why do we take Rmean?
-
-	/* compute viscous coefficients */
-	if (en && betan)
-		throw std::invalid_argument("Ip2_PartialSatMat_PartialSatMat_MindlinPhys: only one of en, betan can be specified.");
-	if (es && betas)
-		throw std::invalid_argument("Ip2_PartialSatMat_PartialSatMat_MindlinPhys: only one of es, betas can be specified.");
-
-	// en or es specified, just compute alpha, otherwise alpha remains 0
-	if (en || es) {
-		const Real logE       = log((*en)(mat1->id, mat2->id));
-		contactPhysics->alpha = -sqrt(5 / 6.) * 2 * logE / sqrt(pow(logE, 2) + pow(Mathr::PI, 2))
-		        * sqrt(2 * E * sqrt(R)); // (see Tsuji, 1992), also [Antypov2011] eq. 17
-	}
-
-	// betan specified, use that value directly; otherwise give zero
-	else {
-		contactPhysics->betan = betan ? (*betan)(mat1->id, mat2->id) : 0;
-		contactPhysics->betas = betas ? (*betas)(mat1->id, mat2->id) : contactPhysics->betan;
-	}
-}
-
-#endif
-
 } // namespace yade
