@@ -10,7 +10,7 @@ The DMT formulation is also considered (for adhesive particles, rigid and small
 
 #pragma once
 
-#include <pkg/common/Dispatching.hpp>
+#include <core/Dispatching.hpp>
 #include <pkg/common/ElastMat.hpp>
 #include <pkg/common/MatchMaker.hpp>
 #include <pkg/common/NormShearPhys.hpp>
@@ -21,19 +21,17 @@ The DMT formulation is also considered (for adhesive particles, rigid and small
 #include <lib/base/openmp-accu.hpp>
 #include <boost/tuple/tuple.hpp>
 
-
 namespace yade { // Cannot have #include directive inside.
 
 /******************** MindlinPhys *********************************/
-class MindlinPhys : public FrictPhys {
+class MindlinPhys : public RotStiffFrictPhys {
 public:
-	virtual ~MindlinPhys() {};
+	virtual ~MindlinPhys() = default;
+
 	// clang-format off
-	YADE_CLASS_BASE_DOC_ATTRS_CTOR(MindlinPhys,FrictPhys,"Representation of an interaction of the Hertz-Mindlin type.",
+	YADE_CLASS_BASE_DOC_ATTRS_CTOR(MindlinPhys,RotStiffFrictPhys,"Representation of an interaction of the Hertz-Mindlin type.",
 			((Real,kno,0.0,,"Constant value in the formulation of the normal stiffness"))
 			((Real,kso,0.0,,"Constant value in the formulation of the tangential stiffness"))
-			((Real,kr,0.0,,"Rotational stiffness"))
-			((Real,ktw,0.0,,"Rotational stiffness"))
 			((Real,maxBendPl,0.0,,"Coefficient to determine the maximum plastic moment to apply at the contact"))
 
 			((Vector3r,normalViscous,Vector3r::Zero(),,"Normal viscous component"))
@@ -71,7 +69,7 @@ public:
 			,
 			createIndex());
 	// clang-format on
-	REGISTER_CLASS_INDEX(MindlinPhys, FrictPhys);
+	REGISTER_CLASS_INDEX(MindlinPhys, RotStiffFrictPhys);
 	DECLARE_LOGGER;
 };
 REGISTER_SERIALIZABLE(MindlinPhys);
@@ -80,23 +78,34 @@ REGISTER_SERIALIZABLE(MindlinPhys);
 /******************** Ip2_FrictMat_FrictMat_MindlinPhys *******/
 class Ip2_FrictMat_FrictMat_MindlinPhys : public IPhysFunctor {
 public:
-	virtual void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction);
+	void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction) override;
 	FUNCTOR2D(FrictMat, FrictMat);
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(
-			Ip2_FrictMat_FrictMat_MindlinPhys,IPhysFunctor,"Calculate some physical parameters needed to obtain \
-the normal and shear stiffnesses according to the Hertz-Mindlin formulation (as implemented in PFC).\n\n\
-Viscous parameters can be specified either using coefficients of restitution ($e_n$, $e_s$) or viscous \
-damping ratio ($\\beta_n$, $\\beta_s$). The following rules apply:\n#. If the $\\beta_n$ ($\\beta_s$) \
-ratio is given, it is assigned to :yref:`MindlinPhys.betan` (:yref:`MindlinPhys.betas`) directly.\n#. \
-If $e_n$ is given, :yref:`MindlinPhys.betan` is computed using $\\beta_n=-(\\log e_n)/\\sqrt{\\pi^2+(\\log e_n)^2}$. \
-The same applies to $e_s$, :yref:`MindlinPhys.betas`.\n#. It is an error (exception) to specify both $e_n$ \
-and $\\beta_n$ ($e_s$ and $\\beta_s$).\n#. If neither $e_n$ nor $\\beta_n$ is given, zero value \
-for :yref:`MindlinPhys.betan` is used; there will be no viscous effects.\n#.If neither $e_s$ nor $\\beta_s$ \
-is given, the value of :yref:`MindlinPhys.betan` is used for :yref:`MindlinPhys.betas` as well.\n\nThe \
-$e_n$, $\\beta_n$, $e_s$, $\\beta_s$ are :yref:`MatchMaker` objects; they can be constructed from float \
-values to always return constant value.\n\nSee :ysrc:`scripts/test/shots.py` for an example of specifying \
-$e_n$ based on combination of parameters.",
+			Ip2_FrictMat_FrictMat_MindlinPhys,IPhysFunctor, 
+				R"""(Calculate some physical parameters needed to obtain the normal and shear stiffnesses according to the Hertz-Mindlin formulation (as implemented in PFC).
+The viscous damping coefficients $c_n$, $c_s$ can be specified either using viscous damping ratios ($\beta_n$, $\beta_s$) or coefficients of restitution ($e_n$, $e_s$).
+
+# If the viscous damping ratio $\beta_n$ ($\beta_s$) is given, it is assigned directly to :yref:`MindlinPhys.betan` (:yref:`MindlinPhys.betas`) and the viscous damping coefficient is calculated as $c_n=2 \cdot \beta_n \cdot \sqrt{m_{bar} \cdot k_n}$ ($c_s=2 \cdot \beta_s \cdot \sqrt{m_{bar} \cdot k_s}$), where $k_n$ ($k_s$) the tangential normal (shear) stiffness. Replacing $k_n=3/2 \cdot k_{no} \cdot {u_{N}}^{0.5}$ ($k_s=k_{so} \cdot {u_{N}}^{0.5}$) and $k_{no}=4/3 \cdot E \cdot \sqrt{R}$ ($k_{so}=2 \cdot \sqrt{4 \cdot R} \cdot G/(2-\nu)$), we get $c_n=2 \cdot \beta_n \cdot \sqrt{m_{bar}} \cdot \sqrt{2 \cdot E \cdot \sqrt{R}}\cdot {u_{N}}^{0.25}$ ($c_s=2 \cdot \beta_s  \cdot \sqrt{m_{bar}} \cdot \sqrt{4 \cdot \sqrt{R} \cdot G/(2-\nu)} \cdot {u_N}^{0.25}$), where $m_{bar}$, $R$, $E$, $G$ the effective mass and mean radius, elastic and shear moduli of the interacting particles.
+
+# If the coefficient of restitution $e_n$ is given instead, the normal viscous damping ratio is computed using $\beta_n=-(\log e_n)/\sqrt{\pi^2+(\log e_n)^2}$. The shear coefficient of restitution is considered as $e_s=e_n$ and the viscous damping coefficient is calculated as $c_n=c_s=\alpha \cdot \sqrt{m_{bar}} \cdot {u_{N}}^{0.25}$, where $\alpha=2 \cdot \sqrt{5/6} \cdot \beta_n \cdot \sqrt{2 \cdot E \cdot \sqrt{R}}$, i.e. $c_n=c_s=2 \cdot \sqrt{5/6} \cdot \beta_n \cdot \sqrt{m_{bar}} \cdot \sqrt{2 \cdot E \cdot \sqrt{R}} \cdot {u_{N}}^{0.25}$.
+
+In both cases, the viscous forces are calculated as $F_{n,viscous}=c_n \cdot v_n$ ($F_{s,viscous}=c_s \cdot v_s$), where $v_n$ ($v_s$) the normal (shear) component of the relative velocity.
+The following rules apply:
+
+# If $\beta_n$ and $\beta_s$ are used, then :yref:`MindlinPhys.alpha` =0; if $e_n$ is defined instead, then :yref:`MindlinPhys.betan` = :yref:`MindlinPhys.betan` =0.0.
+
+# It is an error (exception) to specify both $e_n$ and $\beta_n$ ($e_s$ and $\beta_s$).
+
+# If neither $e_n$ nor $\beta_n$ is given, zero value for :yref:`MindlinPhys.betan` is used; there will be no viscous effects.
+
+# If neither $e_s$ nor $\beta_s$ is given, the value of :yref:`MindlinPhys.betan` is used for :yref:`MindlinPhys.betas` as well.
+
+# To consider different viscous coefficients in the normal and shear contact directions, use $\beta_n$, $\beta_s$, instead of $e_n$.
+
+The $e_n$, $\beta_n$, $e_s$, $\beta_s$ are :yref:`MatchMaker` objects; they can be constructed from float values to always return constant values. See :ysrc:`scripts/examples/spheresFactory.py` for an example of specifying $e_n$ based on combination of parameters, for different materials in contact.
+
+)""",
 			((Real,gamma,0.0,,"Surface energy parameter [J/m^2] per each unit contact surface, to derive DMT formulation from HM"))
 			((Real,eta,0.0,,"Coefficient to determine the plastic bending moment"))
 			((Real,krot,0.0,,"Rotational stiffness for moment contact law"))
@@ -115,7 +124,7 @@ REGISTER_SERIALIZABLE(Ip2_FrictMat_FrictMat_MindlinPhys);
 
 class Law2_ScGeom_MindlinPhys_MindlinDeresiewitz : public LawFunctor {
 public:
-	virtual bool go(shared_ptr<IGeom>&, shared_ptr<IPhys>&, Interaction*);
+	bool go(shared_ptr<IGeom>&, shared_ptr<IPhys>&, Interaction*) override;
 	FUNCTOR2D(ScGeom, MindlinPhys);
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS(Law2_ScGeom_MindlinPhys_MindlinDeresiewitz,LawFunctor,
@@ -128,11 +137,11 @@ REGISTER_SERIALIZABLE(Law2_ScGeom_MindlinPhys_MindlinDeresiewitz);
 
 class Law2_ScGeom_MindlinPhys_HertzWithLinearShear : public LawFunctor {
 public:
-	virtual bool go(shared_ptr<IGeom>&, shared_ptr<IPhys>&, Interaction*);
+	bool go(shared_ptr<IGeom>&, shared_ptr<IPhys>&, Interaction*) override;
 	FUNCTOR2D(ScGeom, MindlinPhys);
 	// clang-format off
 		YADE_CLASS_BASE_DOC_ATTRS(Law2_ScGeom_MindlinPhys_HertzWithLinearShear,LawFunctor,
-			"Constitutive law for the Hertz formulation (using :yref:`MindlinPhys.kno`) and linear beahvior in shear (using :yref:`MindlinPhys.kso` for stiffness and :yref:`FrictPhys.tangensOfFrictionAngle`). \n\n.. note:: No viscosity or damping. If you need those, look at  :yref:`Law2_ScGeom_MindlinPhys_Mindlin`, which also includes non-linear Mindlin shear.",
+			"Constitutive law for the Hertz formulation (using :yref:`MindlinPhys.kno`) and linear behavior in shear (using :yref:`MindlinPhys.kso` for stiffness and :yref:`FrictPhys.tangensOfFrictionAngle`). \n\n.. note:: No viscosity or damping. If you need those, look at  :yref:`Law2_ScGeom_MindlinPhys_Mindlin`, which also includes non-linear Mindlin shear.",
 				((bool,neverErase,false,,"Keep interactions even if particles go away from each other (only in case another constitutive law is in the scene, e.g. :yref:`Law2_ScGeom_CapillaryPhys_Capillarity`)"))
 				((int,nonLin,0,,"Shear force nonlinearity (the value determines how many features of the non-linearity are taken in account). 1: ks as in HM 2: shearElastic increment computed as in HM 3. granular ratcheting disabled."))
 		);
@@ -144,14 +153,14 @@ REGISTER_SERIALIZABLE(Law2_ScGeom_MindlinPhys_HertzWithLinearShear);
 /******************** Law2_ScGeom_MindlinPhys_Mindlin *********/
 class Law2_ScGeom_MindlinPhys_Mindlin : public LawFunctor {
 public:
-	virtual bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I);
-	Real         normElastEnergy();
-	Real         adhesionEnergy();
+	bool go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I) override;
+	Real normElastEnergy();
+	Real adhesionEnergy();
 
-	Real getfrictionDissipation();
-	Real getshearEnergy();
-	Real getnormDampDissip();
-	Real getshearDampDissip();
+	Real getfrictionDissipation() const;
+	Real getshearEnergy() const;
+	Real getnormDampDissip() const;
+	Real getshearDampDissip() const;
 	Real contactsAdhesive();
 	Real ratioSlidingContacts();
 
@@ -210,7 +219,7 @@ REGISTER_SERIALIZABLE(MindlinCapillaryPhys);
 
 class Ip2_FrictMat_FrictMat_MindlinCapillaryPhys : public IPhysFunctor {
 public:
-	virtual void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction);
+	void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction) override;
 
 	FUNCTOR2D(FrictMat, FrictMat);
 	// clang-format off
@@ -229,81 +238,4 @@ public:
 };
 REGISTER_SERIALIZABLE(Ip2_FrictMat_FrictMat_MindlinCapillaryPhys);
 
-#ifdef PARTIALSAT
-
-class PartialSatState : public State {
-	// clang-format off
-	YADE_CLASS_BASE_DOC_ATTRS_CTOR(PartialSatState,State,"Hertz mindlin state information about each body. Only active if partially saturated clay model is active.",
-
-		((Real,suctionSum,0,,"sum of suctions associated with incident cells"))
-		((Real,suction,0,,"suction computed for particle (sum(sat of inc. cells)/num inc. cells)"))
-		((Real,radiiChange,0,,"total change of particle radius due to swelling"))
-		((Real,radiiOriginal,0,,"original particle radius prior to swelling"))
-		((int,incidentCells,0,,"number of incident cells"))
-		((int,lastIncidentCells,0,,"number of incident cells"))
-		((Real,volumeOriginal,0,,"original particle volume stored for strain increments"))
-
-		,
-		createIndex();
-	);
-	// clang-format on
-	REGISTER_CLASS_INDEX(PartialSatState, State);
-};
-REGISTER_SERIALIZABLE(PartialSatState);
-
-class PartialSatMat : public FrictMat {
-public:
-	virtual shared_ptr<State> newAssocState() const { return shared_ptr<State>(new PartialSatState); }
-	virtual bool              stateTypeOk(State* s) const { return (bool)dynamic_cast<PartialSatState*>(s); }
-
-	// clang-format off
-	YADE_CLASS_BASE_DOC_ATTRS_CTOR(PartialSatMat,FrictMat,"Material used for :yref:`PartialSatClayEngine`. Necessary for the custom PartialSatState.",
-		((int,num,0,,"Particle number"))
-		,
-		createIndex();
-	);
-	// clang-format on
-	REGISTER_CLASS_INDEX(PartialSatMat, FrictMat);
-};
-REGISTER_SERIALIZABLE(PartialSatMat);
-
-class Ip2_PartialSatMat_PartialSatMat_MindlinPhys : public IPhysFunctor {
-public:
-	virtual void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction);
-	FUNCTOR2D(PartialSatMat, PartialSatMat);
-	// clang-format off
-	YADE_CLASS_BASE_DOC_ATTRS(
-			Ip2_PartialSatMat_PartialSatMat_MindlinPhys,IPhysFunctor,"PartialSat variant of HertzMindlin \n\n \
-Calculate some physical parameters needed to obtain \
-the normal and shear stiffnesses according to the Hertz-Mindlin formulation (as implemented in PFC).\n\n\
-Viscous parameters can be specified either using coefficients of restitution ($e_n$, $e_s$) or viscous \
-damping ratio ($\\beta_n$, $\\beta_s$). The following rules apply:\n#. If the $\\beta_n$ ($\\beta_s$) \
-ratio is given, it is assigned to :yref:`MindlinPhys.betan` (:yref:`MindlinPhys.betas`) directly.\n#. \
-If $e_n$ is given, :yref:`MindlinPhys.betan` is computed using $\\beta_n=-(\\log e_n)/\\sqrt{\\pi^2+(\\log e_n)^2}$. \
-The same applies to $e_s$, :yref:`MindlinPhys.betas`.\n#. It is an error (exception) to specify both $e_n$ \
-and $\\beta_n$ ($e_s$ and $\\beta_s$).\n#. If neither $e_n$ nor $\\beta_n$ is given, zero value \
-for :yref:`MindlinPhys.betan` is used; there will be no viscous effects.\n#.If neither $e_s$ nor $\\beta_s$ \
-is given, the value of :yref:`MindlinPhys.betan` is used for :yref:`MindlinPhys.betas` as well.\n\nThe \
-$e_n$, $\\beta_n$, $e_s$, $\\beta_s$ are :yref:`MatchMaker` objects; they can be constructed from float \
-values to always return constant value.\n\nSee :ysrc:`scripts/test/shots.py` for an example of specifying \
-$e_n$ based on combination of parameters.",
-			((Real,gamma,0.0,,"Surface energy parameter [J/m^2] per each unit contact surface, to derive DMT formulation from HM"))
-			((Real,eta,0.0,,"Coefficient to determine the plastic bending moment"))
-			((Real,krot,0.0,,"Rotational stiffness for moment contact law"))
-			((Real,ktwist,0.0,,"Torsional stiffness for moment contact law"))
-			((shared_ptr<MatchMaker>,en,,,"Normal coefficient of restitution $e_n$."))
-			((shared_ptr<MatchMaker>,es,,,"Shear coefficient of restitution $e_s$."))
-			((shared_ptr<MatchMaker>,betan,,,"Normal viscous damping ratio $\\beta_n$."))
-			((shared_ptr<MatchMaker>,betas,,,"Shear viscous damping ratio $\\beta_s$."))
-			((shared_ptr<MatchMaker>,frictAngle,,,"Instance of :yref:`MatchMaker` determining how to compute the friction angle of an interaction. If ``None``, minimum value is used."))
-	);
-	// clang-format on
-	DECLARE_LOGGER;
-};
-REGISTER_SERIALIZABLE(Ip2_PartialSatMat_PartialSatMat_MindlinPhys);
-
-
-#endif
-
-
 } // namespace yade
