@@ -9,7 +9,7 @@
 #pragma once
 
 #include <lib/serialization/Serializable.hpp>
-#include <pkg/common/Dispatching.hpp>
+#include <core/Dispatching.hpp>
 #include <pkg/common/Facet.hpp>
 #include <pkg/common/Sphere.hpp>
 #include <pkg/common/Wall.hpp>
@@ -17,6 +17,9 @@
 namespace yade { // Cannot have #include directive inside.
 
 class Ig2_Facet_Sphere_ScGeom : public IGeomFunctor {
+private:
+	const Real hertzFac = 1e8;
+
 public:
 	virtual bool
 	             go(const shared_ptr<Shape>&       cm1,
@@ -25,7 +28,7 @@ public:
 	                const State&                   state2,
 	                const Vector3r&                shift2,
 	                const bool&                    force,
-	                const shared_ptr<Interaction>& c);
+	                const shared_ptr<Interaction>& c) override;
 	virtual bool goReverse(
 	        const shared_ptr<Shape>&       cm1,
 	        const shared_ptr<Shape>&       cm2,
@@ -33,10 +36,11 @@ public:
 	        const State&                   state2,
 	        const Vector3r&                shift2,
 	        const bool&                    force,
-	        const shared_ptr<Interaction>& c);
+	        const shared_ptr<Interaction>& c) override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Ig2_Facet_Sphere_ScGeom,IGeomFunctor,"Create/update a :yref:`ScGeom` instance representing intersection of :yref:`Facet` and :yref:`Sphere`. The equivalent radius for the Facet (:yref:`ScGeom.refR1`) is chosen as twice the Sphere's one.",
 		((Real,shrinkFactor,((void)"no shrinking",0),,"The radius of the inscribed circle of the facet is decreased by the value of the sphere's radius multiplied by *shrinkFactor*. From the definition of contact point on the surface made of facets, the given surface is not continuous and becomes in effect surface covered with triangular tiles, with gap between the separate tiles equal to the sphere's radius multiplied by 2×*shrinkFactor*. If zero, no shrinking is done."))
+		((bool,hertzian,false,,"The equivalent radius for the Facet (:yref:`ScGeom.refR1`) is chosen as 1e8 times the Sphere's radius (closer to Hertzian therory, where it is infinite)."))
 	);
 	// clang-format on
 	DECLARE_LOGGER;
@@ -55,7 +59,7 @@ public:
 	                const State&                   state2,
 	                const Vector3r&                shift2,
 	                const bool&                    force,
-	                const shared_ptr<Interaction>& c);
+	                const shared_ptr<Interaction>& c) override;
 	virtual bool goReverse(
 	        const shared_ptr<Shape>&       cm1,
 	        const shared_ptr<Shape>&       cm2,
@@ -63,7 +67,7 @@ public:
 	        const State&                   state2,
 	        const Vector3r&                shift2,
 	        const bool&                    force,
-	        const shared_ptr<Interaction>& c);
+	        const shared_ptr<Interaction>& c) override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC(Ig2_Facet_Sphere_ScGeom6D,Ig2_Facet_Sphere_ScGeom,"Create an interaction geometry :yref:`ScGeom6D` from :yref:`Facet` and :yref:`Sphere`, representing the Facet with a projected virtual sphere of same radius.")
 	// clang-format on
@@ -73,6 +77,9 @@ public:
 REGISTER_SERIALIZABLE(Ig2_Facet_Sphere_ScGeom6D);
 
 class Ig2_Wall_Sphere_ScGeom : public IGeomFunctor {
+private:
+	const Real hertzFac = 1e8;
+
 public:
 	virtual bool
 	go(const shared_ptr<Shape>&       cm1,
@@ -81,10 +88,11 @@ public:
 	   const State&                   state2,
 	   const Vector3r&                shift2,
 	   const bool&                    force,
-	   const shared_ptr<Interaction>& c);
+	   const shared_ptr<Interaction>& c) override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS(Ig2_Wall_Sphere_ScGeom,IGeomFunctor,"Create/update a :yref:`ScGeom` instance representing intersection of :yref:`Wall` and :yref:`Sphere`. The equivalent radius for the Wall (:yref:`ScGeom.refR1`) is chosen equal to the Sphere's radius.",
 		((bool,noRatch,true,,"Avoid granular ratcheting"))
+        ((bool,hertzian,false,,"The equivalent radius for the Wall (:yref:`ScGeom.refR1`) is chosen as 1e8 times the Sphere's radius (closer to Hertzian therory, where it is infinite)."))
 	);
 	// clang-format on
 	FUNCTOR2D(Wall, Sphere);
