@@ -10,12 +10,13 @@ YADE_PLUGIN((Ip2_FrictMat_FrictMat_LubricationPhys)(LubricationPhys)(Law2_ScGeom
 LubricationPhys::~LubricationPhys() { }
 
 CREATE_LOGGER(LubricationPhys);
+CREATE_LOGGER(Law2_ScGeom_ImplicitLubricationPhys);
+CREATE_LOGGER(Law2_ScGeom_VirtualLubricationPhys);
 
 void Ip2_FrictMat_FrictMat_LubricationPhys::go(
         const shared_ptr<Material>& material1, const shared_ptr<Material>& material2, const shared_ptr<Interaction>& interaction)
 {
-	if (interaction->phys)
-		return;
+	if (interaction->phys) return;
 
 	// Cast to Lubrication
 	shared_ptr<LubricationPhys> phys(new LubricationPhys());
@@ -53,6 +54,7 @@ void Ip2_FrictMat_FrictMat_LubricationPhys::go(
 	Real Ks = 2. * Ea * Da * Va * Eb * Db * Vb / (Ea * Da * Va + Eb * Db * Vb);
 
 	phys->kn = Kn;
+        phys->keps = Kn*keps;
 	phys->ks = Ks;
 
 	/* Friction */
@@ -86,8 +88,7 @@ Real Law2_ScGeom_ImplicitLubricationPhys::normalForce_AdimExp(LubricationPhys* p
 	Real a((geom->radius1 + geom->radius2) / 2.);
 	if (isNew) {
 		phys->u = -geom->penetrationDepth;
-		if (phys->u < 0.)
-			LOG_ERROR("phys->u < 0 at starting point!!! Increase interaction detection distance." << phys->u);
+		if (phys->u < 0.) LOG_ERROR("phys->u < 0 at starting point!!! Increase interaction detection distance." << phys->u);
 		phys->delta = math::log(phys->u / a);
 	}
 
@@ -145,15 +146,13 @@ Real Law2_ScGeom_ImplicitLubricationPhys::NRAdimExp_integrate_u(
 
 		d = d - ratio;
 
-		if (math::abs(F) < SolutionTol)
-			break;
+		if (math::abs(F) < SolutionTol) break;
 
 		LOG_DEBUG("d " << d << " ratio " << ratio << " F " << F << " i " << i << " a " << a << " depth " << depth);
 	}
 
 	if (i < MaxIter || depth > maxSubSteps) {
-		if (depth > maxSubSteps)
-			LOG_WARN("Max Substepping reach: results may be inconsistant F=" << F);
+		if (depth > maxSubSteps) LOG_WARN("Max Substepping reach: results may be inconsistant F=" << F);
 
 		prevDotU = -(1. + a) * math::exp(d) + a * eps + un;
 		return d;
@@ -214,8 +213,7 @@ Real Law2_ScGeom_ImplicitLubricationPhys::DichoAdimExp_integrate_u(
 		d = (d_left + d_right) / 2.;
 		F = ObjF(un, eps, alpha, prevDotU, dt, prev_d, undot, d);
 
-		if (math::abs(F) < SolutionTol)
-			break;
+		if (math::abs(F) < SolutionTol) break;
 
 		if (F * F_left < 0.) {
 			F_right = F;
@@ -226,8 +224,7 @@ Real Law2_ScGeom_ImplicitLubricationPhys::DichoAdimExp_integrate_u(
 		}
 	}
 
-	if (i == MaxIter)
-		LOG_DEBUG("Max iteration reach: d_left=" << d_left << " F_left=" << F_left << " d_right=" << d_right << " F_right=" << F_right);
+	if (i == MaxIter) LOG_DEBUG("Max iteration reach: d_left=" << d_left << " F_left=" << F_left << " d_right=" << d_right << " F_right=" << F_right);
 
 	Real a   = (math::exp(d) < eps) ? alpha : 0.;
 	prevDotU = -(1. + a) * math::exp(d) + a * eps + un;
@@ -253,9 +250,7 @@ Real Law2_ScGeom_ImplicitLubricationPhys::normalForce_trpz_adim(LubricationPhys*
 	}
 
 	Real a((geom->radius1 + geom->radius2) / 2.);
-	if (isNew) {
-		phys->u = -geom->penetrationDepth;
-	}
+	if (isNew) { phys->u = -geom->penetrationDepth; }
 
 	Real uprim = trapz_integrate_u_adim(
 	        -geom->penetrationDepth / a, 2. * phys->eps, scene->dt * a * phys->kn / (phys->nun * 3. / 2.), phys->u / a, phys->contact, phys->prevDotU);
@@ -321,14 +316,14 @@ Real Law2_ScGeom_ImplicitLubricationPhys::normalForce_trapezoidal(LubricationPhy
 	                            -geom->penetrationDepth,
 	                            (phys->nun * 3. / 2.),
 	                            phys->kn,
-	                            phys->kn /*should be keps, currently both are equal*/,
+	                            phys->keps /*should be keps, currently both are equal*/,
 	                            2. * phys->eps * a,
 	                            scene->dt,
 	                            phys->u < (2 * phys->eps * a),
 	                            isNew ? (maxSubSteps + 1) : 0 /* depth = maxSubSteps+1 will trigger backward Euler for initialization*/);
 
 	phys->contact                = phys->u < 2. * phys->eps * a;
-	phys->normalContactForce     = ((phys->contact) ? phys->kn * (phys->u - 2 * phys->eps * a) : 0.) * geom->normal;
+	phys->normalContactForce     = ((phys->contact) ? phys->keps * (phys->u - 2 * phys->eps * a) : 0.) * geom->normal;
 	phys->normalLubricationForce = phys->normalForce - phys->normalContactForce;
 	phys->ue                     = -geom->penetrationDepth - phys->u;
 
@@ -371,12 +366,19 @@ Real Law2_ScGeom_ImplicitLubricationPhys::trapz_integrate_u(
 		b = nu / dt / keff - un_eff;
 		c = -w * u_prev; /*implicit backward Euler 1st order*/
 	}
-	Real delta = b * b - 4 * c; //note: a=1
 	Real rr[2] = { 0, 0 };
+        Real delta = b * b - 4 * c; //note: a=1
 	if (delta >= 0) {
-		rr[0] = 0.5 * (-b + sqrt(delta));
-		rr[1] = 0.5 * (-b - sqrt(delta));
-	}                             //roots
+                // there is an accuracy issue when computing (-b+√(b²-4ac))/2a, use 1st order approx when needed (first case): r=-c/b
+                if ((-c) < (1e-12*delta)) { 
+                    rr[0] = -c/b;
+                    rr[1] = c/b;
+                } else {
+                    rr[0] = 0.5 * (-b + sqrt(delta));
+                    rr[1] = 0.5 * (-b - sqrt(delta));
+                }
+	}  
+		
 	if (delta < 0 or rr[0] < 0) { // recursive calls after halving the time increment if no positive solution found (no need to check r[1], always smaller)
 		if (depth < maxSubSteps) { //sub-stepping
 			                   //LOG_WARN("delta<0 or negative roots, sub-stepping with dt="<<dt/2.);
@@ -384,15 +386,17 @@ Real Law2_ScGeom_ImplicitLubricationPhys::trapz_integrate_u(
 			trapz_integrate_u(prevDotU, un_prev, u_prev, un_mid, nu, k, keps, eps, dt / 2., withContact, depth + 1);
 			return trapz_integrate_u(prevDotU, un_prev, u_prev, un_curr, nu, k, keps, eps, dt / 2., withContact, depth + 1);
 		} else { // switch to backward Euler (theta = 1) by increasing depth again (see above)
-			LOG_DEBUG("minimal sub-step reached (depth=" << maxSubSteps << "), the result may be innacurate. Increase maxSubSteps?");
+			LOG_WARN("minimal sub-step reached (depth=" << maxSubSteps << ")"<<rr[0]<<" "<<rr[1]<<" "<<b<<" "<<c<<" "<<delta<<" "<<w);
 			return trapz_integrate_u(prevDotU, un_prev, u_prev, un_curr, nu, k, keps, eps, dt, withContact, depth + 1);
 		}
 	} else { // normal case, keep the positive solution closest to the previous one, and check contact status
 		// select the nearest strictly positive solution, keep 0 only if there is no positive solution
-		if ((math::abs(rr[0] - u_prev) < math::abs(rr[1] - u_prev) and rr[0] > 0) or rr[1] <= 0)
-			u = rr[0];
-		else
+		if (rr[0]==0) LOG_WARN("nul gap found "<<delta<<" "<<b<<" "<<c<<" "<<keff<<" "<<un_eff<<" "<<w<<" "<<dt<<" "<<depth<<" "<<u_prev<<" "<<un_curr)
+		if ((math::abs(rr[0] - u_prev) < math::abs(rr[1] - u_prev) and rr[0] > 0) or rr[1] <= 0) u = rr[0];
+		else {
+                        LOG_WARN("root 1 was used")
 			u = rr[1];
+                }
 		bool hasContact = u < eps;
 		// if contact appeared/disappeared recalculate with different coefficients (another recursion)
 		if (withContact and not hasContact) {
@@ -411,6 +415,7 @@ Real Law2_ScGeom_ImplicitLubricationPhys::trapz_integrate_u(
 		prevDotU = keff * u * (un_eff - u); //set for next iteration
 		un_prev  = un_curr;
 		u_prev   = u;
+//                 if (u<=1e-15) LOG_WARN("u<=1e-15, rr0="<<rr[0]<<" "<<rr[1]<<" "<<delta<<" "<<b<<" "<<c<<" "<<u )
 		return k * (un_curr - u);
 	}
 }
@@ -423,7 +428,7 @@ void Law2_ScGeom_VirtualLubricationPhys::shearForce_firstOrder(LubricationPhys*
 	Real            a((geom->radius1 + geom->radius2) / 2.);
 	const Vector3r& dus = geom->shearIncrement();
 	Real            kt  = phys->ks;
-	Real            nut = (phys->eta > 0.) ? M_PI * phys->eta / 2. * (-2. * a + (2. * a + phys->u) * math::log((2. * a + phys->u) / phys->u)) : 0.;
+	Real            nut = (phys->eta > 0.) ? M_PI * phys->eta / 2. * (-2. * a + (2. * a + phys->u) * (math::log(2. * a + phys->u) -  math::log(phys->u))) : 0.;
 
 	phys->shearForce            = Vector3r::Zero();
 	phys->shearLubricationForce = Vector3r::Zero();
@@ -441,7 +446,7 @@ void Law2_ScGeom_VirtualLubricationPhys::shearForce_firstOrder(LubricationPhys*
 			//LOG_INFO("SLIP");
 			Ft *= phys->normalContactForce.norm() * math::max(0., phys->mum) / Ft.norm();
 			phys->shearContactForce     = Ft;
-			Ft                          = (Ft * kt * scene->dt + Ft_ * nut + dus * kt * nut) / (kt * scene->dt + nut);
+			Ft                          = (kt*(Ft*scene->dt + dus*nut) + Ft_ * nut ) / (kt * scene->dt + nut);
 			phys->slip                  = true;
 			phys->shearLubricationForce = nut * dus / scene->dt;
 		}
@@ -525,12 +530,8 @@ bool Law2_ScGeom_ImplicitLubricationPhys::go(shared_ptr<IGeom>& iGeom, shared_pt
 	//    Vector3r relVT = relV - relVN; // Tangeancial velocity
 	Real undot = relV.dot(geom->normal); // Normal velocity norm
 
-	if (-geom->penetrationDepth > MaxDist * a) {
-		//FIXME: it needs to go to potential always based on distance, the "undot < 0" here is dangerous (let the collider do its job), ex: if true is returned here the interaction is still alive and it will be included in the stress
-		//         return undot < 0; // Only go to potential if distance is increasing
-
-		return false;
-	}
+        // the second condition below is to keep alive soft sticking contacts (large elastic forces between distant particles)
+	if (-geom->penetrationDepth > MaxDist * a and (phys->u > (-0.99*geom->penetrationDepth) )) return false;
 
 	// inititalization
 	if (phys->u == -1.) {
@@ -544,6 +545,7 @@ bool Law2_ScGeom_ImplicitLubricationPhys::go(shared_ptr<IGeom>& iGeom, shared_pt
 	phys->normalLubricationForce = Vector3r::Zero();
 	phys->normalPotentialForce   = Vector3r::Zero();
 
+	if (phys->keps!=phys->kn and resolution>0) LOG_WARN("keps!=1 not implemented for resolution>0");
 	switch (resolution) {
 		case 0: normalForce_trapezoidal(phys, geom, undot, isNew); break;
 		case 1: normalForce_AdimExp(phys, geom, undot, isNew, false); break;
@@ -555,12 +557,12 @@ bool Law2_ScGeom_ImplicitLubricationPhys::go(shared_ptr<IGeom>& iGeom, shared_pt
 			resolution = 0;
 			break;
 	}
-
+	if (phys->u==0) LOG_WARN("NULL GAP ON "<<id1<<" "<<id2)
+	
 	Vector3r C1 = Vector3r::Zero();
 	Vector3r C2 = Vector3r::Zero();
 
-	if (resolution == 0 || resolution == 3)
-		computeShearForceAndTorques(phys, geom, s1, s2, C1, C2);
+	if (resolution == 0 || resolution == 3) computeShearForceAndTorques(phys, geom, s1, s2, C1, C2);
 	else
 		computeShearForceAndTorques_log(phys, geom, s1, s2, C1, C2);
 
@@ -579,16 +581,14 @@ void Law2_ScGeom_VirtualLubricationPhys::computeShearForceAndTorques(Lubrication
 {
 	Real a((geom->radius1 + geom->radius2) / 2.);
 	if (phys->eta <= 0. || phys->u > 0.) {
-		if (activateTangencialLubrication)
-			shearForce_firstOrder(phys, geom);
+		if (activateTangencialLubrication) shearForce_firstOrder(phys, geom);
 		else {
 			phys->shearForce            = Vector3r::Zero();
 			phys->shearContactForce     = Vector3r::Zero();
 			phys->shearLubricationForce = Vector3r::Zero();
 		}
 
-		if (phys->nun > 0.)
-			phys->cn = 3. / 2. * phys->nun / phys->u;
+		if (phys->nun > 0.) phys->cn = 3. / 2. * phys->nun / phys->u;
 
 		Vector3r Cr = Vector3r::Zero();
 		Vector3r Ct = Vector3r::Zero();
@@ -600,15 +600,14 @@ void Law2_ScGeom_VirtualLubricationPhys::computeShearForceAndTorques(Lubrication
 
 		if (a > phys->u) {
 			if (activateRollLubrication && phys->eta > 0.)
-				Cr = phys->nun * (3. / 2. * a + 63. / 500. * phys->u) * math::log(a / phys->u) * relRollVelocity;
-			if (activateTwistLubrication && phys->eta > 0.)
-				Ct = phys->nun * phys->u * math::log(a / phys->u) * relTwistVelocity;
+				Cr = phys->nun * (3. / 2. * a + 63. / 500. * phys->u) * (math::log(a) - math::log(phys->u)) * relRollVelocity;
+			if (activateTwistLubrication && phys->eta > 0.) Ct = phys->nun * phys->u * (math::log(a) - math::log(phys->u)) * relTwistVelocity;
 		}
 		// total torque
 		C1 = -(geom->radius1 - geom->penetrationDepth / 2.) * phys->shearForce.cross(geom->normal) + Cr + Ct;
 		C2 = -(geom->radius2 - geom->penetrationDepth / 2.) * phys->shearForce.cross(geom->normal) - Cr - Ct;
 	} else {
-		LOG_WARN("Gap is negative or null with lubrication: inconsistant results: skip shear force and torques calculation" << phys->u);
+		LOG_ERROR("Gap is negative or null with lubrication: inconsistant results: skip shear force and torques calculation" << phys->u);
 	}
 }
 
@@ -618,16 +617,14 @@ void Law2_ScGeom_VirtualLubricationPhys::computeShearForceAndTorques_log(Lubrica
 	Real a((geom->radius1 + geom->radius2) / 2.);
 	LOG_TRACE("This method use log(u/a) for shear and torque component calculation. Make sure phys->delta is set before calling this method.");
 
-	if (activateTangencialLubrication)
-		shearForce_firstOrder_log(phys, geom);
+	if (activateTangencialLubrication) shearForce_firstOrder_log(phys, geom);
 	else {
 		phys->shearForce            = Vector3r::Zero();
 		phys->shearContactForce     = Vector3r::Zero();
 		phys->shearLubricationForce = Vector3r::Zero();
 	}
 
-	if (phys->nun > 0.)
-		phys->cn = 3. / 2. * phys->nun / phys->u;
+	if (phys->nun > 0.) phys->cn = 3. / 2. * phys->nun / phys->u;
 
 	Vector3r Cr = Vector3r::Zero();
 	Vector3r Ct = Vector3r::Zero();
@@ -640,16 +637,13 @@ void Law2_ScGeom_VirtualLubricationPhys::computeShearForceAndTorques_log(Lubrica
 	if (phys->delta > 0.) {
 		if (activateRollLubrication && phys->eta > 0.)
 			Cr = -phys->nun * a * 3. / 2. * (21. / 250. * math::exp(phys->delta) + 1.) * phys->delta * relRollVelocity;
-		if (activateTwistLubrication && phys->eta > 0.)
-			Ct = -phys->nun * a * math::exp(phys->delta) * phys->delta * relTwistVelocity;
+		if (activateTwistLubrication && phys->eta > 0.) Ct = -phys->nun * a * math::exp(phys->delta) * phys->delta * relTwistVelocity;
 	}
 	// total torque
 	C1 = -(geom->radius1 - geom->penetrationDepth / 2.) * phys->shearForce.cross(geom->normal) + Cr + Ct;
 	C2 = -(geom->radius2 - geom->penetrationDepth / 2.) * phys->shearForce.cross(geom->normal) - Cr - Ct;
 }
 
-CREATE_LOGGER(Law2_ScGeom_ImplicitLubricationPhys);
-CREATE_LOGGER(Law2_ScGeom_VirtualLubricationPhys);
 
 void Law2_ScGeom_VirtualLubricationPhys::getStressForEachBody(
         vector<Matrix3r>& NCStresses, vector<Matrix3r>& SCStresses, vector<Matrix3r>& NLStresses, vector<Matrix3r>& SLStresses, vector<Matrix3r>& NPStresses)
@@ -671,8 +665,7 @@ void Law2_ScGeom_VirtualLubricationPhys::getStressForEachBody(
 
 	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
 	{
-		if (!I->isReal())
-			continue;
+		if (!I->isReal()) continue;
 		GenericSpheresContact* geom = YADE_CAST<GenericSpheresContact*>(I->geom.get());
 		LubricationPhys*       phys = YADE_CAST<LubricationPhys*>(I->phys.get());
 
@@ -782,9 +775,7 @@ void LubricationPDFEngine::action()
 				ScGeom*          geom = dynamic_cast<ScGeom*>(I->geom.get());
 				LubricationPhys* ph   = dynamic_cast<LubricationPhys*>(I->phys.get());
 
-				if (geom && ph) {
-					return ph->contact;
-				}
+				if (geom && ph) { return ph->contact; }
 				return false;
 			}));
 		}
