@@ -38,8 +38,7 @@ MicroMacroAnalyser::~MicroMacroAnalyser()
 void MicroMacroAnalyser::postLoad(MicroMacroAnalyser&)
 {
 	ofile.open(outputFile.c_str(), std::ios::app);
-	if (!boost::filesystem::exists(outputFile.c_str()))
-		ofile << "iteration eps1w eps2w eps3w eps11g eps22g eps33g eps12g eps13g eps23g" << endl;
+	if (!boost::filesystem::exists(outputFile.c_str())) ofile << "iteration eps1w eps2w eps3w eps11g eps22g eps33g eps12g eps13g eps23g" << endl;
 }
 
 void MicroMacroAnalyser::action()
@@ -54,17 +53,14 @@ void MicroMacroAnalyser::action()
 				triaxialCompressionEngine = YADE_PTR_CAST<TriaxialCompressionEngine>(*itFirst);
 			}
 		}
-		if (!triaxialCompressionEngine)
-			LOG_ERROR("stress controller engine not found");
+		if (!triaxialCompressionEngine) LOG_ERROR("stress controller engine not found");
 	}
-	if (triaxialCompressionEngine->strain[0] == 0)
-		return; // no deformation yet
+	if (triaxialCompressionEngine->strain[0] == 0) return; // no deformation yet
 	if (!initialized) {
 		setState(1, true, false);
 		//Check file here again, to make sure we write to the correct file when filename is modified after the scene is loaded
 		ofile.open(outputFile.c_str(), std::ios::app);
-		if (!boost::filesystem::exists(outputFile.c_str()))
-			ofile << "iteration eps1w eps2w eps3w eps11g eps22g eps33g eps12g eps13g eps23g" << endl;
+		if (!boost::filesystem::exists(outputFile.c_str())) ofile << "iteration eps1w eps2w eps3w eps11g eps22g eps33g eps12g eps13g eps23g" << endl;
 		initialized = true;
 	} else if (scene->iter % interval == 0) {
 		setState(2, true, compIncrt);
@@ -108,11 +104,11 @@ void MicroMacroAnalyser::setState(unsigned int state, bool save_states, bool com
 //Copy simulation data in the triaxialState structure
 CGT::TriaxialState& MicroMacroAnalyser::makeState(unsigned int state, const char* filename)
 {
-	Scene*                     scene  = Omega::instance().getScene().get();
-	shared_ptr<BodyContainer>& bodies = scene->bodies;
+	//  declaration of ‘scene’ shadows a member of ‘yade::MicroMacroAnalyser’ [-Werror=shadow]
+	Scene*                     scene2 = Omega::instance().getScene().get();
+	shared_ptr<BodyContainer>& bodies = scene2->bodies;
 	CGT::TriaxialState*        ts     = 0;
-	if (state == 1)
-		ts = analyser->TS0;
+	if (state == 1) ts = analyser->TS0;
 	else if (state == 2)
 		ts = analyser->TS1;
 	else
@@ -129,8 +125,7 @@ CGT::TriaxialState& MicroMacroAnalyser::makeState(unsigned int state, const char
 		const Body::id_t Idg = bi->getId();
 		TS.grains[Idg].id    = Idg;
 		if (!bi->isDynamic()) {
-			if (!nonSphereAsFictious)
-				continue;
+			if (!nonSphereAsFictious) continue;
 			TS.grains[Idg].isSphere = false;
 			fictiousVtx.push_back(Idg);
 		} else { //then it is a sphere (not a wall)
@@ -186,8 +181,8 @@ CGT::TriaxialState& MicroMacroAnalyser::makeState(unsigned int state, const char
 	} else
 		LOG_INFO(" the number of fictious vertices should be 0 or 6 usually");
 
-	InteractionContainer::iterator ii    = scene->interactions->begin();
-	InteractionContainer::iterator iiEnd = scene->interactions->end();
+	InteractionContainer::iterator ii    = scene2->interactions->begin();
+	InteractionContainer::iterator iiEnd = scene2->interactions->end();
 	for (; ii != iiEnd; ++ii) {
 		if ((*ii)->isReal()) {
 			CGT::TriaxialState::Contact* c = new CGT::TriaxialState::Contact;
@@ -224,34 +219,32 @@ CGT::TriaxialState& MicroMacroAnalyser::makeState(unsigned int state, const char
 	}
 	//Save various parameters if triaxialCompressionEngine is defined
 	if (!triaxialCompressionEngine) {
-		vector<shared_ptr<Engine>>::iterator itFirst = scene->engines.begin();
-		vector<shared_ptr<Engine>>::iterator itLast  = scene->engines.end();
+		vector<shared_ptr<Engine>>::iterator itFirst = scene2->engines.begin();
+		vector<shared_ptr<Engine>>::iterator itLast  = scene2->engines.end();
 		for (; itFirst != itLast; ++itFirst) {
 			if ((*itFirst)->getClassName() == "TriaxialCompressionEngine") {
 				LOG_DEBUG("stress controller engine found");
 				triaxialCompressionEngine = YADE_PTR_CAST<TriaxialCompressionEngine>(*itFirst);
 			}
 		}
-		if (!triaxialCompressionEngine)
-			LOG_INFO("stress controller engine not found");
+		if (!triaxialCompressionEngine) LOG_INFO("stress controller engine not found");
 	}
 
 	if (triaxialCompressionEngine) {
 		TS.wszzh   = triaxialCompressionEngine->stress[triaxialCompressionEngine->wall_top][1];
 		TS.wsxxd   = triaxialCompressionEngine->stress[triaxialCompressionEngine->wall_right][0];
 		TS.wsyyfa  = triaxialCompressionEngine->stress[triaxialCompressionEngine->wall_front][2];
-		TS.eps3    = triaxialCompressionEngine->strain[2];                     //find_parameter("eps3=", Statefile);
-		TS.eps1    = triaxialCompressionEngine->strain[0];                     //find_parameter("eps1=", Statefile);
-		TS.eps2    = triaxialCompressionEngine->strain[1];                     //find_parameter("eps2=", Statefile);
-		TS.haut    = triaxialCompressionEngine->height;                        //find_parameter("haut=", Statefile);
-		TS.larg    = triaxialCompressionEngine->width;                         //find_parameter("larg=", Statefile);
-		TS.prof    = triaxialCompressionEngine->depth;                         //find_parameter("prof=", Statefile);
-		TS.porom   = 0 /*analyser->computeMacroPorosity() crasher?*/;          //find_parameter("porom=", Statefile);
-		TS.ratio_f = triaxialCompressionEngine->ComputeUnbalancedForce(scene); //find_parameter("ratio_f=", Statefile);
+		TS.eps3    = triaxialCompressionEngine->strain[2];                      //find_parameter("eps3=", Statefile);
+		TS.eps1    = triaxialCompressionEngine->strain[0];                      //find_parameter("eps1=", Statefile);
+		TS.eps2    = triaxialCompressionEngine->strain[1];                      //find_parameter("eps2=", Statefile);
+		TS.haut    = triaxialCompressionEngine->height;                         //find_parameter("haut=", Statefile);
+		TS.larg    = triaxialCompressionEngine->width;                          //find_parameter("larg=", Statefile);
+		TS.prof    = triaxialCompressionEngine->depth;                          //find_parameter("prof=", Statefile);
+		TS.porom   = 0 /*analyser->computeMacroPorosity() crasher?*/;           //find_parameter("porom=", Statefile);
+		TS.ratio_f = triaxialCompressionEngine->ComputeUnbalancedForce(scene2); //find_parameter("ratio_f=", Statefile);
 	} else
 		TS.wszzh = TS.wsxxd = TS.wsyyfa = TS.eps3 = TS.eps1 = TS.eps2 = TS.haut = TS.larg = TS.prof = TS.porom = TS.ratio_f = 0;
-	if (filename != NULL)
-		TS.to_file(filename);
+	if (filename != NULL) TS.to_file(filename);
 	return TS;
 }
 
