@@ -8,8 +8,8 @@
 #pragma once
 
 #include <lib/base/Math.hpp>
+#include <core/Callbacks.hpp>
 #include <core/Interaction.hpp>
-#include <pkg/common/Callbacks.hpp>
 #include <pkg/common/FieldApplier.hpp>
 #include <pkg/dem/GlobalStiffnessTimeStepper.hpp>
 
@@ -50,34 +50,39 @@ class NewtonIntegrator : public FieldApplier {
 	Matrix3r dVelGrad;
 	Vector3r dSpin;
 
-public:
+        Vector3r computeAccelWithoutGravity(const Vector3r& force, const Real& mass, int blockedDOFs);
+        Vector3r addGravity(int blockedDOFs);
+
+
+public:   
 	bool densityScaling;     // internal for density scaling
 	Real updatingDispFactor; //(experimental) Displacement factor used to trigger bound update: the bound is updated only if updatingDispFactor*disp>sweepDist when >0, else all bounds are updated.
 	// function to save maximum velocity, for the verlet-distance optimization
 	void saveMaximaVelocity(const Body::id_t& id, State* state);
 	void saveMaximaDisplacement(const shared_ptr<Body>& b);
-	bool get_densityScaling();
+	bool get_densityScaling() const;
 	void set_densityScaling(bool dsc);
 
 #ifdef YADE_OPENMP
 	vector<Real> threadMaxVelocitySq;
 #endif
-	virtual void action();
+	void action() override;
 	// clang-format off
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR_PY(NewtonIntegrator,GlobalEngine,"Engine integrating newtonian motion equations.",
 		((Real,damping,0.2,,"damping coefficient for Cundall's non viscous damping (see :ref:`NumericalDamping` and [Chareyre2005]_)"))
 		((Vector3r,gravity,Vector3r::Zero(),,"Gravitational acceleration (effectively replaces GravityEngine)."))
 		((Real,maxVelocitySq,0,,"stores max. displacement, based on which we trigger collision detection. |yupdate|"))
 		((bool,exactAsphericalRot,true,,"Enable more exact body rotation integrator for :yref:`aspherical bodies<Body.aspherical>` *only*, using formulation from [Allen1989]_, pg. 89."))
-		((Matrix3r,prevVelGrad,Matrix3r::Zero(),,"Store previous velocity gradient (:yref:`Cell::velGrad`) to track acceleration. |yupdate|"))
+		((Matrix3r,prevVelGrad,Matrix3r::Zero(),,"Store previous velocity gradient (:yref:`Cell::velGrad`) to track average acceleration in periodic simulations. |yupdate|"))
 		#ifdef YADE_BODY_CALLBACK
 			((vector<shared_ptr<BodyCallback> >,callbacks,,,"List (std::vector in c++) of :yref:`BodyCallbacks<BodyCallback>` which will be called for each body as it is being processed."))
 		#endif
-		((Vector3r,prevCellSize,Vector3r(NaN,NaN,NaN),Attr::hidden,"cell size from previous step, used to detect change and find max velocity"))
+		((Vector3r,prevCellSize,Vector3r(NaN,NaN,NaN),Attr::hidden,":yref:`Cell` size from previous step, used to detect change and find max velocity during periodic simulations"))
 		((bool,warnNoForceReset,true,,"Warn when forces were not resetted in this step by :yref:`ForceResetter`; this mostly points to :yref:`ForceResetter` being forgotten incidentally and should be disabled only with a good reason."))
 		// energy tracking
 		((int,nonviscDampIx,-1,(Attr::hidden|Attr::noSave),"Index of the energy dissipated using the non-viscous damping (:yref:`damping<NewtonIntegrator.damping>`)."))
 		((bool,kinSplit,false,,"Whether to separately track translational and rotational kinetic energy."))
+                ((bool,dampGravity,true,,"By default, numerical damping applies to ALL forces, even gravity. If this option is set to false, then the gravity forces calculated based on NewtonIntegrator.gravity are excluded from the damping calculation. This option has no effect on gravity forces added by GravityEngine. "))
 		((int,kinEnergyIx,-1,(Attr::hidden|Attr::noSave),"Index for kinetic energy in scene->energies."))
 		((int,kinEnergyTransIx,-1,(Attr::hidden|Attr::noSave),"Index for translational kinetic energy in scene->energies."))
 		((int,kinEnergyRotIx,-1,(Attr::hidden|Attr::noSave),"Index for rotational kinetic energy in scene->energies."))
