@@ -11,9 +11,6 @@
 namespace yade { // Cannot have #include directive inside.
 
 YADE_PLUGIN((ScGeom)(ScGeom6D)(ChCylGeom6D));
-ScGeom::~ScGeom() {};
-ScGeom6D::~ScGeom6D() {};
-ChCylGeom6D::~ChCylGeom6D() {};
 
 Vector3r& ScGeom::rotate(Vector3r& shearForce) const
 {
@@ -33,9 +30,7 @@ Vector3r& ScGeom::rotateNonSpherical(Vector3r& shearForce) const
 	//shearForce -= shearForce.cross(twist_axis);
 	//NOTE : make sure it is in the tangent plane? It's never been done before. Is it not adding rounding errors at the same time in fact?...
 	//shearForce -= normal.dot(shearForce)*normal;
-	if (math::isnan(shearForce.norm())) {
-		std::cout << "orthonormal_axis: " << orthonormal_axis << ", normal: " << normal << endl;
-	}
+	if (math::isnan(shearForce.norm())) { std::cout << "orthonormal_axis: " << orthonormal_axis << ", normal: " << normal << endl; }
 	return shearForce;
 }
 
@@ -68,7 +63,7 @@ void ScGeom::precompute(
 
 
 Vector3r
-ScGeom::getIncidentVel(const State* rbp1, const State* rbp2, Real /*dt*/, const Vector3r& shift2, const Vector3r& shiftVel, bool avoidGranularRatcheting)
+ScGeom::getIncidentVel(const State* rbp1, const State* rbp2, Real /*dt*/, const Vector3r& shift2, const Vector3r& shiftVel, bool avoidGranularRatcheting) const
 {
 	if (avoidGranularRatcheting) {
 		/* B.C. Comment :
@@ -98,16 +93,15 @@ ScGeom::getIncidentVel(const State* rbp1, const State* rbp2, Real /*dt*/, const
 	}
 }
 
-Vector3r ScGeom::getIncidentVel(const State* rbp1, const State* rbp2, Real dt, bool avoidGranularRatcheting)
+Vector3r ScGeom::getIncidentVel(const State* rbp1, const State* rbp2, Real dt, bool avoidGranularRatcheting) const
 {
 	//Just pass null shift to the periodic version
 	return getIncidentVel(rbp1, rbp2, dt, Vector3r::Zero(), Vector3r::Zero(), avoidGranularRatcheting);
 }
 
-Vector3r ScGeom::getIncidentVel_py(shared_ptr<Interaction> i, bool avoidGranularRatcheting)
+Vector3r ScGeom::getIncidentVel_py(shared_ptr<Interaction> i, bool avoidGranularRatcheting) const
 {
-	if (i->geom.get() != this)
-		throw invalid_argument("ScGeom object is not the same as Interaction.geom.");
+	if (i->geom.get() != this) throw invalid_argument("ScGeom object is not the same as Interaction.geom.");
 	Scene* scene = Omega::instance().getScene().get();
 	return getIncidentVel(
 	        Body::byId(i->getId1(), scene)->state.get(),
@@ -118,16 +112,15 @@ Vector3r ScGeom::getIncidentVel_py(shared_ptr<Interaction> i, bool avoidGranular
 	        avoidGranularRatcheting);
 }
 
-Vector3r ScGeom::getRelAngVel(const State* rbp1, const State* rbp2, Real /*dt*/)
+Vector3r ScGeom::getRelAngVel(const State* rbp1, const State* rbp2, Real /*dt*/) const
 {
 	Vector3r relAngVel = (rbp2->angVel - rbp1->angVel);
 	return relAngVel;
 }
 
-Vector3r ScGeom::getRelAngVel_py(shared_ptr<Interaction> i)
+Vector3r ScGeom::getRelAngVel_py(shared_ptr<Interaction> i) const
 {
-	if (i->geom.get() != this)
-		throw invalid_argument("ScGeom object is not the same as Interaction.geom.");
+	if (i->geom.get() != this) throw invalid_argument("ScGeom object is not the same as Interaction.geom.");
 	Scene* scene = Omega::instance().getScene().get();
 	return getRelAngVel(Body::byId(i->getId1(), scene)->state.get(), Body::byId(i->getId2(), scene)->state.get(), scene->dt);
 }
@@ -140,8 +133,7 @@ void ScGeom6D::precomputeRotations(const State& rbp1, const State& rbp2, bool is
 	} else {
 		Quaternionr delta((rbp1.ori * (initialOrientation1.conjugate())) * (initialOrientation2 * (rbp2.ori.conjugate())));
 		delta.normalize();
-		if (creep)
-			delta = delta * twistCreep;
+		if (creep) delta = delta * twistCreep;
 		AngleAxisr aa(delta); // axis of rotation - this is the Moment direction UNIT vector; // angle represents the power of resistant ELASTIC moment
 		                      //Eigen::AngleAxisr(q) returns nan's when q close to identity, next tline fixes the pb.
 // add -DYADE_SCGEOM_DEBUG to CXXFLAGS to enable this piece or just do
@@ -160,11 +152,9 @@ void ScGeom6D::precomputeRotations(const State& rbp1, const State& rbp2, bool is
 			cerr << delta << " " << bb.angle() << endl;
 		}
 #else
-		if (math::isnan(aa.angle()))
-			aa.angle() = 0;
+		if (math::isnan(aa.angle())) aa.angle() = 0;
 #endif
-		if (aa.angle() > Mathr::PI)
-			aa.angle() -= Mathr::TWO_PI; // angle is between 0 and 2*pi, but should be between -pi and pi
+		if (aa.angle() > Mathr::PI) aa.angle() -= Mathr::TWO_PI; // angle is between 0 and 2*pi, but should be between -pi and pi
 		twist   = (aa.angle() * aa.axis().dot(normal));
 		bending = Vector3r(aa.angle() * aa.axis() - twist * normal);
 	}
