@@ -11,8 +11,8 @@
 #include "TesselationWrapper.hpp"
 #include <lib/high-precision/Constants.hpp>
 #include <lib/triangulation/Timer.h>
-#include <pkg/dem/Shop.hpp>
-#include <pkg/dem/SpherePack.hpp>
+#include <preprocessing/dem/Shop.hpp>
+#include <preprocessing/dem/SpherePack.hpp>
 
 // https://codeyarns.com/2014/03/11/how-to-selectively-ignore-a-gcc-warning/
 #pragma GCC diagnostic push
@@ -71,8 +71,7 @@ struct RTraits_for_spatial_sort : public CGT::SimpleTriangulationTypes::RTriangu
 // template <class Triangulation>
 void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, TesselationWrapper& TW, bool reset = true)
 {
-	if (reset)
-		TW.clear();
+	if (reset) TW.clear();
 	typedef SimpleTesselation::RTriangulation              RTriangulation;
 	SimpleTesselation&                                     Tes = *(TW.Tes);
 	RTriangulation&                                        T   = Tes.Triangulation();
@@ -123,8 +122,7 @@ void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, Tesse
 		int                         li, lj;
 		c                               = T.locate(*(p->first), lt, li, lj, hint);
 		RTriangulation::Vertex_handle v = T.insert(*(p->first), lt, c, li, lj);
-		if (v == RTriangulation::Vertex_handle())
-			hint = c;
+		if (v == RTriangulation::Vertex_handle()) hint = c;
 		else {
 			v->info().setId((unsigned int)p->second);
 			//Vh->info().isFictious = false;//false is the default
@@ -137,12 +135,11 @@ void build_triangulation_with_ids(const shared_ptr<BodyContainer>& bodies, Tesse
 	//cerr << " loaded : " << Ng<<", triangulated : "<<TW.n_spheres<<", mean radius = " << TW.mean_radius<<endl;
 }
 
-double thickness = 0;
+Real thickness = 0;
 
 TesselationWrapper::~TesselationWrapper()
 {
-	if (Tes)
-		delete Tes;
+	if (Tes) delete Tes;
 }
 
 void TesselationWrapper::clear(void)
@@ -173,17 +170,18 @@ void TesselationWrapper::clear2(void) //for testing purpose
 
 void TesselationWrapper::insertSceneSpheres(bool reset)
 {
-	Scene* scene = Omega::instance().getScene().get();
+	// declaration of ‘scene’ shadows a member of ‘yade::TesselationWrapper’ [-Werror=shadow]
+	Scene* scene2 = Omega::instance().getScene().get();
 	// 	Real_timer clock;
 	//         clock.start();
-	const shared_ptr<BodyContainer>& bodies = scene->bodies;
+	const shared_ptr<BodyContainer>& bodies = scene2->bodies;
 	build_triangulation_with_ids(bodies, *this, reset);
 	// 	clock.top("Triangulation");
 }
 
 Real TesselationWrapper::Volume(unsigned int id) { return ((unsigned int)Tes->Max_id() >= id) ? Tes->Volume(id) : -1; }
 
-bool TesselationWrapper::insert(double x, double y, double z, double rad, unsigned int id)
+bool TesselationWrapper::insert(Real x, Real y, Real z, Real rad, unsigned int id)
 {
 	checkMinMax(x, y, z, rad);
 	mean_radius += rad;
@@ -191,18 +189,17 @@ bool TesselationWrapper::insert(double x, double y, double z, double rad, unsign
 	return (Tes->insert(x, y, z, rad, id) != NULL);
 }
 
-void TesselationWrapper::checkMinMax(double x, double y, double z, double rad)
+void TesselationWrapper::checkMinMax(Real x, Real y, Real z, Real rad)
 {
 	Pmin = CGT::Point(min(Pmin.x(), x - rad), min(Pmin.y(), y - rad), min(Pmin.z(), z - rad));
 	Pmax = CGT::Point(max(Pmax.x(), x + rad), max(Pmax.y(), y + rad), max(Pmax.z(), z + rad));
 }
 
 
-bool TesselationWrapper::move(double x, double y, double z, double rad, unsigned int id)
+bool TesselationWrapper::move(Real x, Real y, Real z, Real rad, unsigned int id)
 {
 	checkMinMax(x, y, z, rad);
-	if (Tes->move(x, y, z, rad, id) != NULL)
-		return true;
+	if (Tes->move(x, y, z, rad, id) != NULL) return true;
 	else {
 		std::cerr << "Tes->move(x,y,z,rad,id)==NULL" << std::endl;
 		return false;
@@ -211,8 +208,7 @@ bool TesselationWrapper::move(double x, double y, double z, double rad, unsigned
 
 void TesselationWrapper::computeTesselation(void)
 {
-	if (not(Tes->vertexHandles.size() > 0))
-		insertSceneSpheres();
+	if (not(Tes->vertexHandles.size() > 0)) insertSceneSpheres();
 	if (!rad_divided) {
 		mean_radius /= n_spheres;
 		rad_divided = true;
@@ -220,27 +216,23 @@ void TesselationWrapper::computeTesselation(void)
 	Tes->compute();
 }
 
-void TesselationWrapper::computeTesselation(double pminx, double pmaxx, double pminy, double pmaxy, double pminz, double pmaxz)
+void TesselationWrapper::computeTesselation(Real pminx, Real pmaxx, Real pminy, Real pmaxy, Real pminz, Real pmaxz)
 {
-	if (not(Tes->vertexHandles.size() > 0))
-		insertSceneSpheres();
+	if (not(Tes->vertexHandles.size() > 0)) insertSceneSpheres();
 	addBoundingPlanes(pminx, pmaxx, pminy, pmaxy, pminz, pmaxz);
 	computeTesselation();
 }
 
 void TesselationWrapper::computeVolumes(void)
 {
-	if (not(Tes->vertexHandles.size() > 0))
-		insertSceneSpheres();
-	if (!bounded)
-		addBoundingPlanes();
+	if (not(Tes->vertexHandles.size() > 0)) insertSceneSpheres();
+	if (!bounded) addBoundingPlanes();
 	computeTesselation();
 	Tes->computeVolumes();
 }
 unsigned int TesselationWrapper::NumberOfFacets(bool initIters)
 {
-	if (initIters)
-		InitIter();
+	if (initIters) InitIter();
 	return Tes->Triangulation().number_of_finite_edges();
 }
 
@@ -253,8 +245,7 @@ void TesselationWrapper::InitIter(void)
 
 bool TesselationWrapper::nextFacet(std::pair<unsigned int, unsigned int>& facet)
 {
-	if (facet_end == facet_it)
-		return false;
+	if (facet_end == facet_it) return false;
 	facet.first  = facet_it->first->vertex(facet_it->second)->info().id();
 	facet.second = facet_it->first->vertex((facet_it)->third)->info().id();
 	++facet_it;
@@ -333,8 +324,7 @@ void TesselationWrapper::defToVtkFromPositions(string inputFile1, string inputFi
 	sp1.fromFile(inputFile1);
 	sp2.fromFile(inputFile2);
 	size_t imax = sp1.pack.size();
-	if (imax != sp2.pack.size())
-		LOG_ERROR("The files have different numbers of spheres");
+	if (imax != sp2.pack.size()) LOG_ERROR("The files have different numbers of spheres");
 	shared_ptr<Body> body;
 	scene->bodies->clear();
 	for (size_t i = 0; i < imax; i++) {
@@ -357,7 +347,7 @@ void TesselationWrapper::defToVtkFromPositions(string inputFile1, string inputFi
 
 void TesselationWrapper::defToVtk(string outputFile) { mma.analyser->DefToFile(outputFile.c_str()); }
 
-boost::python::dict TesselationWrapper::getVolPoroDef(bool deformation)
+boost::python::dict TesselationWrapper::calcVolPoroDef(bool deformation)
 {
 	delete Tes;
 	CGT::TriaxialState* ts;
@@ -391,20 +381,17 @@ boost::python::dict TesselationWrapper::getVolPoroDef(bool deformation)
 		Real             sphereVol = 4.188790 * math::pow((V_it->point().weight()), 1.5); // 4/3*PI*R³ = 4.188...*R³
 		vol[id]                    = V_it->info().v();
 		poro[id]                   = (V_it->info().v() - sphereVol) / V_it->info().v();
-		if (deformation)
-			MATRIX3R_TO_NUMPY(mma.analyser->ParticleDeformation[id], def[id]);
+		if (deformation) MATRIX3R_TO_NUMPY(mma.analyser->ParticleDeformation[id], def[id]);
 		//cerr << V_it->info().v()<<" "<<ParticleDeformation[id]<<endl;
 	}
 	boost::python::dict ret;
 	ret["vol"]  = vol;
 	ret["poro"] = poro;
-	if (deformation)
-		ret["def"] = def;
+	if (deformation) ret["def"] = def;
 	return ret;
 }
 
-#ifdef ALPHASHAPE
-boost::python::list TesselationWrapper::getAlphaFaces(double alpha)
+boost::python::list TesselationWrapper::getAlphaFaces(Real alpha) const
 {
 	vector<AlphaFace> faces;
 	Tes->setAlphaFaces(faces, alpha);
@@ -414,29 +401,68 @@ boost::python::list TesselationWrapper::getAlphaFaces(double alpha)
 	return ret;
 }
 
-boost::python::list TesselationWrapper::getAlphaCaps(double alpha, double shrinkedAlpha, bool fixedAlpha)
+boost::python::list TesselationWrapper::getAlphaCaps(Real alpha, Real shrinkedAlpha, bool fixedAlpha) const
 {
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
 	boost::python::list ret;
 	for (auto f = caps.begin(); f != caps.end(); f++)
-		ret.append(boost::python::make_tuple(f->id, makeVector3r(f->normal)));
+		ret.append(boost::python::make_tuple(f->id, makeVector3r(f->normal), makeVector3r(f->centroid)));
 	//    cerr<<"number of caps="<<caps.size()<<endl;
 	return ret;
 }
 
-void TesselationWrapper::applyAlphaForces(Matrix3r stress, double alpha, double shrinkedAlpha, bool fixedAlpha)
+void TesselationWrapper::applyAlphaForces(Matrix3r stress, Real alpha, Real shrinkedAlpha, bool fixedAlpha)
 {
-	Scene* scene = Omega::instance().getScene().get();
-	if (Tes->Triangulation().number_of_vertices() <= 0)
-		build_triangulation_with_ids(scene->bodies, *this, true); //if not already triangulated do it now
+	// Scene* scene = Omega::instance().getScene().get();
+	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
 	vector<AlphaCap> caps;
 	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	for (const auto& b : *scene->bodies)
+		scene->forces.setPermForce(b->id, Vector3r::Zero());
 	for (auto f = caps.begin(); f != caps.end(); f++)
 		scene->forces.setPermForce(f->id, stress * makeVector3r(f->normal));
 }
 
-boost::python::list TesselationWrapper::getAlphaGraph(double alpha, double shrinkedAlpha, bool fixedAlpha)
+void TesselationWrapper::applyAlphaVel(Matrix3r velGrad, Real alpha, Real shrinkedAlpha, bool fixedAlpha)
+{
+	// Scene* scene = Omega::instance().getScene().get();
+	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
+	vector<AlphaCap> caps;
+	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	for (const auto& b : *scene->bodies)
+		b->state->blockedDOFs = State::DOF_NONE;
+	const auto aabb     = Shop::aabbExtrema();
+	Vector3r   bbCenter = 0.5 * (aabb.first + aabb.second);
+	for (auto f = caps.begin(); f != caps.end(); f++) {
+		Body* b               = Body::byId(f->id, scene).get();
+		b->state->blockedDOFs = State::DOF_ALL;
+		b->state->vel         = velGrad * (makeVector3r(f->centroid) - bbCenter);
+		b->state->angVel      = Vector3r::Zero();
+	}
+}
+
+Matrix3r TesselationWrapper::calcAlphaStress(Real alpha, Real shrinkedAlpha, bool fixedAlpha)
+{
+	// Scene* scene = Omega::instance().getScene().get();
+	build_triangulation_with_ids(scene->bodies, *this, true); //triangulation needed
+	vector<AlphaCap> caps;
+	Tes->setExtendedAlphaCaps(caps, alpha, shrinkedAlpha, fixedAlpha);
+	Matrix3r cauchyLWS(Matrix3r::Zero());
+	scene->forces.sync(); // needed to make resultants predictable
+	alphaCapsVol = 0.;
+	for (auto f = caps.begin(); f != caps.end(); f++) {
+		Vector3r areaV     = makeVector3r(f->normal);
+		Vector3r resultant = scene->forces.getPermForce(f->id) - scene->forces.getForce(f->id);
+		Vector3r centroid  = makeVector3r(f->centroid);
+		cauchyLWS += resultant * (centroid.transpose());
+		alphaCapsVol += areaV.norm() / 3. * centroid.dot(areaV.normalized());
+	}
+	cauchyLWS /= alphaCapsVol;
+	return cauchyLWS;
+}
+
+boost::python::list TesselationWrapper::getAlphaGraph(Real alpha, Real shrinkedAlpha, bool fixedAlpha) const
 {
 	vector<Vector3r>    segments = Tes->getExtendedAlphaGraph(alpha, shrinkedAlpha, fixedAlpha);
 	boost::python::list ret;
@@ -445,7 +471,7 @@ boost::python::list TesselationWrapper::getAlphaGraph(double alpha, double shrin
 	return ret;
 }
 
-boost::python::list TesselationWrapper::getAlphaVertices(double alpha)
+boost::python::list TesselationWrapper::getAlphaVertices(Real alpha) const
 {
 	vector<int>         vertices = Tes->getAlphaVertices(alpha);
 	boost::python::list ret;
@@ -453,7 +479,6 @@ boost::python::list TesselationWrapper::getAlphaVertices(double alpha)
 		ret.append(*f);
 	return ret;
 }
-#endif //ALPHASHAPE
 
 } // namespace yade
 
