@@ -45,14 +45,10 @@ public:
 		// Comparison operator for table sorting.
 		bool operator<(const nodepair& param) const
 		{
-			if (node1.get() < param.node1.get())
-				return true;
-			if (node1.get() > param.node1.get())
-				return false;
-			if (node2.get() < param.node2.get())
-				return true;
-			if (node2.get() > param.node2.get())
-				return false;
+			if (node1.get() < param.node1.get()) return true;
+			if (node1.get() > param.node1.get()) return false;
+			if (node2.get() < param.node2.get()) return true;
+			if (node2.get() > param.node2.get()) return false;
 			LOG_ERROR("Incomplete 'if' sequence");
 			return false;
 		}
