@@ -8,6 +8,7 @@
 
 #pragma once
 #include <lib/base/Math.hpp>
+#include <core/Aabb.hpp>
 #include <core/Dispatcher.hpp>
 #include <core/Functor.hpp>
 #include <core/IGeom.hpp>
@@ -16,7 +17,6 @@
 #include <core/Scene.hpp>
 #include <core/Shape.hpp>
 #include <core/State.hpp>
-#include <pkg/common/Aabb.hpp>
 #include <pkg/fem/CohesiveMat.hpp>
 #include <pkg/fem/FEInternalForceDispatchers.hpp>
 #include <pkg/fem/Lin4NodeTetra_Lin4NodeTetra_InteractionElement.hpp>
@@ -25,7 +25,7 @@ namespace yade { // Cannot have #include directive inside.
 
 class If2_2xLin4NodeTetra_LinCohesiveStiffPropDampElastMat : public InternalForceFunctor {
 public:
-	virtual void go(const shared_ptr<Shape>&, const shared_ptr<Material>&, const shared_ptr<Body>&);
+	void go(const shared_ptr<Shape>&, const shared_ptr<Material>&, const shared_ptr<Body>&) override;
 	virtual ~If2_2xLin4NodeTetra_LinCohesiveStiffPropDampElastMat();
 	FUNCTOR2D(Lin4NodeTetra_Lin4NodeTetra_InteractionElement, LinCohesiveStiffPropDampElastMat);
 
