@@ -9,50 +9,25 @@
 
 //#ifndef FLOW_GUARD
 //#define FLOW_GUARD
-
+#pragma once
+#ifdef FLOW_ENGINE
+#ifdef LINSOLV
 #ifdef PARTIALSAT
 #include "FlowEngine_PartialSatClayEngineT.hpp"
+#include <lib/triangulation/FlowBoundingSphere.hpp>
+#include <lib/triangulation/Network.hpp>
+#include <lib/triangulation/Tesselation.h>
 #include <core/Body.hpp>
+#include <core/Dispatching.hpp>
 #include <core/Omega.hpp>
 #include <core/PartialEngine.hpp>
 #include <core/Scene.hpp>
 #include <core/State.hpp>
-#include <pkg/common/Dispatching.hpp>
+#include <pkg/common/MatchMaker.hpp>
 #include <pkg/dem/ScGeom.hpp>
-#include <Eigen/SparseLU>
-
-#ifdef YADE_VTK
-
-//#include<vtkSmartPointer.h>
-#include <lib/compatibility/VTKCompatibility.hpp>
-#include <vtkCellArray.h>
-#include <vtkCellData.h>
-#include <vtkDoubleArray.h>
-#include <vtkLine.h>
-#include <vtkPointData.h>
-#include <vtkPoints.h>
-#include <vtkQuad.h>
-#include <vtkSmartPointer.h>
-#include <vtkXMLPolyDataWriter.h>
-#include <vtkXMLUnstructuredGridWriter.h>
-//#include<vtkDoubleArray.h>
-//#include<vtkUnstructuredGrid.h>
-#include <vtkPolyData.h>
-
-#endif
-
-#ifdef FLOW_ENGINE
-//#include<pkg/pfv/FlowEngine.hpp>
-//#include "FlowEngine_FlowEngineT.hpp"
-#include <lib/triangulation/FlowBoundingSphere.hpp>
-#include <lib/triangulation/Network.hpp>
-#include <lib/triangulation/Tesselation.h>
 #include <pkg/dem/TesselationWrapper.hpp>
-#endif
-
-#ifdef LINSOLV
+#include <Eigen/SparseLU>
 #include <cholmod.h>
-#endif
 
 namespace yade { // Cannot have #include directive inside.
 
@@ -82,23 +57,23 @@ public:
 
 	PartialSatCellInfo(void)
 	{
-		entered           = false;
-		initialPorosity   = 0.25;
+		entered = false;
+		initialPorosity = 0.25;
 		initialSaturation = 0.01;
-		oldPressure       = 0;
-		crackArea         = 0;
-		saturation        = 0.01;
-		porosity          = 0.25;
-		dsdp              = 0;
-		vSolids           = 0;
-		crack             = false;
-		crackNum          = 0;
-		isExposed         = false; // flag for determining if a pore is exposed to atmosphere, which controls the pressure force calculations
-		Po                = 1.5;
-		lambdao           = 0.2;
-		clumped           = false;
-		blocked           = false;
-		initiallyCracked  = false;
+		oldPressure = 0;
+		crackArea = 0;
+		saturation = 0.01;
+		porosity = 0.25;
+		dsdp = 0;
+		vSolids = 0;
+		crack = false;
+		crackNum = 0;
+		isExposed = false; // flag for determining if a pore is exposed to atmosphere, which controls the pressure force calculations
+		Po = 1.5;
+		lambdao = 0.2;
+		clumped = false;
+		blocked = false;
+		initiallyCracked = false;
 		opened.resize(4, 0);
 		entry.resize(4, 0);
 		visited.resize(4, 0);
@@ -114,15 +89,16 @@ public:
 
 typedef CGT::_Tesselation<CGT::TriangulationTypes<PartialSatVertexInfo, PartialSatCellInfo>> PartialSatTesselation;
 #ifdef LINSOLV
-#define PartialSatBoundingSphere CGT::PartialSatLinSolv<PartialSatTesselation>
-//class PartialSatBoundingSphere; // : public CGT::FlowBoundingSphereLinSolv<PartialSatTesselation> {};
+// #define PartialSatBoundingSphere CGT::PartialSatLinSolv<PartialSatTesselation>
+class PartialSatBoundingSphere : public CGT::PartialSatLinSolv<PartialSatTesselation> {
+};
 #endif
 
 typedef TemplateFlowEngine_PartialSatClayEngineT<PartialSatCellInfo, PartialSatVertexInfo, PartialSatTesselation, PartialSatBoundingSphere>
         PartialSatClayEngineT;
 
 REGISTER_SERIALIZABLE(PartialSatClayEngineT);
-YADE_PLUGIN((PartialSatClayEngineT));
+
 class PartialSatClayEngine : public PartialSatClayEngineT {
 public:
 	//typedef TemplateFlowEngine_FlowEngineT<FlowCellInfo_FlowEngineT,FlowVertexInfo_FlowEngineT> FlowEngineT;
@@ -191,47 +167,47 @@ public:
 	        bool                                   gasPermFlag,
 	        FlowSolver&                            flow);
 	void circulateFacets(RTriangulation::Finite_edges_iterator& edge, Real aperture, const Real openingPressure, bool gasPermFlag, FlowSolver& flow);
-	//void saveFractureNetworkVTK(string fileName);
-	#ifdef YADE_VTK
-	void       savePermeabilityNetworkVTK(string fileName);
-	void 	   saveUnsatVtk(const char* folder, bool withBoundaries);
-	#endif
-	void       blockCellsAbovePoroThreshold(FlowSolver& flow);
-	void       blockIsolatedCells(FlowSolver& flow);
-	void       simulateConfinement();
-	void       removeForceOnVertices(RTriangulation::Facet_circulator& facet, RTriangulation::Finite_edges_iterator& ed_it);
-	void       circulateFacetstoRemoveForces(RTriangulation::Finite_edges_iterator& edge);
-	void       removeForcesOnBrokenBonds();
-	void       timeStepControl();
-	void       computeVertexSphericalArea();
-	void       resetParticleSuctions();
-	Real getEnteredRatio();
+//void saveFractureNetworkVTK(string fileName);
+#ifdef YADE_VTK
+	void savePermeabilityNetworkVTK(string fileName);
+	void saveUnsatVtk(const char* folder, bool withBoundaries);
+#endif
+	void blockCellsAbovePoroThreshold(FlowSolver& flow);
+	void blockIsolatedCells(FlowSolver& flow);
+	void simulateConfinement();
+	void removeForceOnVertices(RTriangulation::Facet_circulator& facet, RTriangulation::Finite_edges_iterator& ed_it);
+	void circulateFacetstoRemoveForces(RTriangulation::Finite_edges_iterator& edge);
+	void removeForcesOnBrokenBonds();
+	void timeStepControl();
+	void computeVertexSphericalArea();
+	void resetParticleSuctions();
+	Real getEnteredRatio() const;
 
 	//	void setPositionsBuffer(bool current);
-	Real     leakOffRate                 = 0;
-	Real     averageAperture             = 0;
-	Real     sumOfApertures              = 0;
+	Real     leakOffRate = 0;
+	Real     averageAperture = 0;
+	Real     sumOfApertures = 0;
 	Real     averageFracturePermeability = 0;
-	Real     maxAperture                 = 0;
-	Real     crackArea                   = 0;
-	Real     crackVolume                 = 0;
-	Real     waterVolume                 = 0;
-	int      numCracks                   = 0;
-	Real     totalFractureArea           = 0;
-	Real     solverDT                    = 0;
-	bool     emulatingAction             = false;
-	Real     maxDSDPj                    = 0;
+	Real     maxAperture = 0;
+	Real     crackArea = 0;
+	Real     crackVolume = 0;
+	Real     waterVolume = 0;
+	int      numCracks = 0;
+	Real     totalFractureArea = 0;
+	Real     solverDT = 0;
+	bool     emulatingAction = false;
+	Real     maxDSDPj = 0;
 	Vector3r crack_fabric_vector;
 	Real     crack_fabric_area;
 
 	virtual void initializeVolumes(FlowSolver& flow);
 	virtual void updateVolumes(FlowSolver& flow);
 	virtual void buildTriangulation(Real pZero, Solver& flow, bool oneTes = false);
-	virtual void initSolver(FlowSolver& flow);
-	virtual void action();
-	virtual void emulateAction()
+	void         initSolver(FlowSolver& flow) override;
+	void         action() override;
+	void         emulateAction() override
 	{
-		scene           = Omega::instance().getScene().get();
+		scene = Omega::instance().getScene().get();
 		emulatingAction = true;
 		action();
 		emulatingAction = false;
@@ -245,7 +221,7 @@ public:
 	Real getWaterVolume() const { return waterVolume; }
 	Real getNumCracks() const { return numCracks; }
 	Real getAverageAperture() const { return averageAperture; }
-	void       printPorosity(string file) { printPorosityToFile(file); }
+	void printPorosity(string file) { printPorosityToFile(file); }
 	Real getCellSaturation(Vector3r pos) const { return solver->getCellSaturation(pos[0], pos[1], pos[2]); }
 	//Real getCellVelocity(Vector3r pos){return solver->getCellVelocity(pos[0], pos[1], pos[2]);}
 	std::vector<Real> getCellVelocity(Vector3r pos) const { return solver->getCellVelocity(pos[0], pos[1], pos[2]); }
@@ -257,7 +233,7 @@ public:
 	bool              getCellGasPImposed(unsigned int id) const { return gas_solver->T[gas_solver->currentTes].cellHandles[id]->info().Pcondition; }
 	bool              getCellCracked(Vector3r pos) const { return solver->getCellCracked(pos[0], pos[1], pos[2]); }
 	Real              getAverageSaturation() const { return solver->getAverageSaturation(); }
-	Real              getEnteredThroatRatio() { return getEnteredRatio(); }
+	Real              getEnteredThroatRatio() const { return getEnteredRatio(); }
 	Real              getAverageSuction() const { return solver->getAverageSuction(); }
 	Real              getTotalSpecimenVolume() { return getTotalVolume(); }
 	Vector3r          getCrackFabricVector() const { return crack_fabric_vector / crack_fabric_area; }
@@ -399,14 +375,89 @@ public:
 	.def("savePermeabilityNetworkVTK",&PartialSatClayEngine::savePermeabilityNetworkVTK,(boost::python::arg("fileName")="./VTK"),"Save permeability network as connections between cell centers")
 	#endif
 	.def("insertMicroPores",&PartialSatClayEngine::insertMicroPores,(boost::python::arg("fracMicroPores")),"run to inscribe spheres in a desired fraction of existing pores.")
-	.def("reloadSolver",&PartialSatClayEngine::reloadSolver,(boost::python::arg("solver")=solver),"use after reloading a partialSat simulation and before running next step")
+	.def("reloadSolver",&PartialSatClayEngine::reloadSolver,"use after reloading a partialSat simulation and before running next step")
 	//.def("resetOriginalParticleValues",&PartialSatClayEngine::resetOriginalParticleValues,"reset the initial valume and radii values for particles.")
 	.def("getTotalSpecimenVolume",&PartialSatClayEngine::getTotalSpecimenVolume,"get the total specimen volume")
 	)
+	// clang-format on
 	DECLARE_LOGGER;
 };
 REGISTER_SERIALIZABLE(PartialSatClayEngine);
-YADE_PLUGIN((PartialSatClayEngine));
-// clang-format on
+
+
+class PartialSatState : public State {
+	// clang-format off
+	YADE_CLASS_BASE_DOC_ATTRS_CTOR(PartialSatState,State,"Hertz mindlin state information about each body. Only active if partially saturated clay model is active.",
+
+		((Real,suctionSum,0,,"sum of suctions associated with incident cells"))
+		((Real,suction,0,,"suction computed for particle (sum(sat of inc. cells)/num inc. cells)"))
+		((Real,radiiChange,0,,"total change of particle radius due to swelling"))
+		((Real,radiiOriginal,0,,"original particle radius prior to swelling"))
+		((int,incidentCells,0,,"number of incident cells"))
+		((int,lastIncidentCells,0,,"number of incident cells"))
+		((Real,volumeOriginal,0,,"original particle volume stored for strain increments"))
+
+		,
+		createIndex();
+	);
+	// clang-format on
+	REGISTER_CLASS_INDEX(PartialSatState, State);
+};
+REGISTER_SERIALIZABLE(PartialSatState);
+
+class PartialSatMat : public FrictMat {
+public:
+	shared_ptr<State> newAssocState() const override { return shared_ptr<State>(new PartialSatState); }
+	bool              stateTypeOk(State* s) const override { return (bool)dynamic_cast<PartialSatState*>(s); }
+
+	// clang-format off
+	YADE_CLASS_BASE_DOC_ATTRS_CTOR(PartialSatMat,FrictMat,"Material used for :yref:`PartialSatClayEngine`. Necessary for the custom PartialSatState.",
+		((int,num,0,,"Particle number"))
+		,
+		createIndex();
+	);
+	// clang-format on
+	REGISTER_CLASS_INDEX(PartialSatMat, FrictMat);
+};
+REGISTER_SERIALIZABLE(PartialSatMat);
+
+class Ip2_PartialSatMat_PartialSatMat_MindlinPhys : public IPhysFunctor {
+public:
+	void go(const shared_ptr<Material>& b1, const shared_ptr<Material>& b2, const shared_ptr<Interaction>& interaction) override;
+	FUNCTOR2D(PartialSatMat, PartialSatMat);
+	// clang-format off
+	YADE_CLASS_BASE_DOC_ATTRS(
+			Ip2_PartialSatMat_PartialSatMat_MindlinPhys,IPhysFunctor,"PartialSat variant of HertzMindlin \n\n \
+Calculate some physical parameters needed to obtain \
+the normal and shear stiffnesses according to the Hertz-Mindlin formulation (as implemented in PFC).\n\n\
+Viscous parameters can be specified either using coefficients of restitution ($e_n$, $e_s$) or viscous \
+damping ratio ($\\beta_n$, $\\beta_s$). The following rules apply:\n#. If the $\\beta_n$ ($\\beta_s$) \
+ratio is given, it is assigned to :yref:`MindlinPhys.betan` (:yref:`MindlinPhys.betas`) directly.\n#. \
+If $e_n$ is given, :yref:`MindlinPhys.betan` is computed using $\\beta_n=-(\\log e_n)/\\sqrt{\\pi^2+(\\log e_n)^2}$. \
+The same applies to $e_s$, :yref:`MindlinPhys.betas`.\n#. It is an error (exception) to specify both $e_n$ \
+and $\\beta_n$ ($e_s$ and $\\beta_s$).\n#. If neither $e_n$ nor $\\beta_n$ is given, zero value \
+for :yref:`MindlinPhys.betan` is used; there will be no viscous effects.\n#.If neither $e_s$ nor $\\beta_s$ \
+is given, the value of :yref:`MindlinPhys.betan` is used for :yref:`MindlinPhys.betas` as well.\n\nThe \
+$e_n$, $\\beta_n$, $e_s$, $\\beta_s$ are :yref:`MatchMaker` objects; they can be constructed from float \
+values to always return constant value.\n\nSee :ysrc:`scripts/test/shots.py` for an example of specifying \
+$e_n$ based on combination of parameters.",
+			((Real,gamma,0.0,,"Surface energy parameter [J/m^2] per each unit contact surface, to derive DMT formulation from HM"))
+			((Real,eta,0.0,,"Coefficient to determine the plastic bending moment"))
+			((Real,krot,0.0,,"Rotational stiffness for moment contact law"))
+			((Real,ktwist,0.0,,"Torsional stiffness for moment contact law"))
+			((shared_ptr<MatchMaker>,en,,,"Normal coefficient of restitution $e_n$."))
+			((shared_ptr<MatchMaker>,es,,,"Shear coefficient of restitution $e_s$."))
+			((shared_ptr<MatchMaker>,betan,,,"Normal viscous damping ratio $\\beta_n$."))
+			((shared_ptr<MatchMaker>,betas,,,"Shear viscous damping ratio $\\beta_s$."))
+			((shared_ptr<MatchMaker>,frictAngle,,,"Instance of :yref:`MatchMaker` determining how to compute the friction angle of an interaction. If ``None``, minimum value is used."))
+	);
+	// clang-format on
+	DECLARE_LOGGER;
+};
+REGISTER_SERIALIZABLE(Ip2_PartialSatMat_PartialSatMat_MindlinPhys);
+
+
 } //namespaceyade
 #endif
+#endif //LINSOLV
+#endif //FLOW_ENGINE
