@@ -84,52 +84,52 @@ public:
 
 	TwoPhaseCellInfo(void)
 	{
-		saturation2  = 0.0;
+		saturation2 = 0.0;
 		isFictiousId = 0;
-		isWRes       = true;
-		isNWRes      = false;
-		isTrapW      = false;
-		isTrapNW     = false;
-		saturation   = 1.0;
+		isWRes = true;
+		isNWRes = false;
+		isTrapW = false;
+		isTrapNW = false;
+		saturation = 1.0;
 		hasInterface = false;
-		trapCapP     = 0;
+		trapCapP = 0;
 		poreThroatRadius.resize(4, 0);
 		kNorm2.resize(4, 0);
 		poreBodyRadius = 0;
 		poreBodyVolume = 0;
-		windowsID      = 0;
+		windowsID = 0;
 		for (int k = 0; k < 4; k++)
 			for (int l = 0; l < 4; l++)
 				solidLine[k][l] = 0;
 
 		//dynamic TwoPhaseFlow
-		airBC               = false;
-		waterBC             = false;
-		numberFacets        = 4;
-		mergedVolume        = 0;
-		mergednr            = 0;
-		mergedID            = 0;
+		airBC = false;
+		waterBC = false;
+		numberFacets = 4;
+		mergedVolume = 0;
+		mergednr = 0;
+		mergedID = 0;
 		apparentSolidVolume = 0.0;
-		dvSwelling          = 0.0;
+		dvSwelling = 0.0;
 		entryPressure.resize(4, 0);
 		entrySaturation.resize(4, 0);
 		poreIdConnectivity.resize(4, -1);
 		particleSurfaceArea.resize(4, 0);
 		thresholdSaturation = 0.0;
-		flux                = 0.0; //NOTE can potentially be removed, currently not used but might be handy in future work
-		accumulativeDV      = 0.0;
-		thresholdPressure   = 0.0;
-		airWaterArea        = 0.0;
-		accumulativeDV      = 0.0;
-		minSaturation       = 0.0;
-		poreId              = -1;
-		isWResInternal      = false;
-		dvTPF               = 0.0; //FIXME dvTPF is currently only used to impose pressure as dv() cannot be imposed from FlowEngine currently
-		isNWResDef          = false;
-		conductivityWRes    = 0.0;
-		invadedFrom         = 0;
-		label               = -1;
-		porosity            = 0.;
+		flux = 0.0; //NOTE can potentially be removed, currently not used but might be handy in future work
+		accumulativeDV = 0.0;
+		thresholdPressure = 0.0;
+		airWaterArea = 0.0;
+		accumulativeDV = 0.0;
+		minSaturation = 0.0;
+		poreId = -1;
+		isWResInternal = false;
+		dvTPF = 0.0; //FIXME dvTPF is currently only used to impose pressure as dv() cannot be imposed from FlowEngine currently
+		isNWResDef = false;
+		conductivityWRes = 0.0;
+		invadedFrom = 0;
+		label = -1;
+		porosity = 0.;
 	}
 };
 
@@ -169,10 +169,9 @@ public:
 	        : PhaseCluster()
 	{
 		tes = &t;
-		LC  = NULL;
-		ex  = NULL;
-		if (not tes)
-			LOG_WARN("invalid initialization");
+		LC = NULL;
+		ex = NULL;
+		if (not tes) LOG_WARN("invalid initialization");
 	}
 	// 		PhaseCluster () {tes=NULL; LOG_WARN("avoid default constructor, 'tes' not initialized");}
 	Tesselation*       tes; //point back to the full data structure
@@ -189,10 +188,8 @@ public:
 	void solvePressure();
 	void resetSolver()
 	{
-		if (LC)
-			cholmod_l_free_factor(&LC, &comC);
-		if (ex)
-			cholmod_l_free_dense(&ex, &comC);
+		if (LC) cholmod_l_free_factor(&LC, &comC);
+		if (ex) cholmod_l_free_dense(&ex, &comC);
 		factorized = false;
 	}
 #endif
@@ -216,42 +213,41 @@ public:
 		// 			for (auto i=otherCluster.interfaces.begin();i!=otherCluster.interfaces.end();i++) i->first.firstlabel=label;
 		pores.insert(pores.end(), otherCluster.pores.begin(), otherCluster.pores.end());
 		for (auto itf = otherCluster.interfaces.begin(); itf != otherCluster.interfaces.end(); itf++)
-			if (itf->first.second != start->info().id)
-				interfaces.push_back(*itf);
+			if (itf->first.second != start->info().id) interfaces.push_back(*itf);
 		otherCluster.reset();
 	}
 
-	vector<int> getPores()
+	vector<int> getPores() const
 	{
 		vector<int> res;
-		for (vector<CellHandle>::iterator it = pores.begin(); it != pores.end(); it++)
+		for (vector<CellHandle>::const_iterator it = pores.cbegin(); it != pores.cend(); it++)
 			res.push_back((*it)->info().id);
 		return res;
 	}
 
-	boost::python::list getInterfaces(int cellId = -1)
+	boost::python::list getInterfaces(int cellId = -1) const
 	{
 		boost::python::list ints;
-		for (vector<Interface>::iterator it = interfaces.begin(); it != interfaces.end(); it++)
+		for (vector<Interface>::const_iterator it = interfaces.cbegin(); it != interfaces.cend(); it++)
 			if (cellId == -1 or unsigned(cellId) == it->first.first)
 				ints.append(boost::python::make_tuple(it->first.first, it->first.second, it->second, it - interfaces.begin()));
 		return ints;
 	}
-	Real getFlux(unsigned nf)
+	Real getFlux(unsigned nf) const
 	{
 		const CellHandle& innerCell = interfaces[nf].innerCell;
 		return innerCell->info().kNorm()[interfaces[nf].outerIndex]
 		        * (innerCell->info().p() + interfaces[nf].capillaryP - innerCell->neighbor(interfaces[nf].outerIndex)->info().p());
 	}
-	Real getCapVol(unsigned nf) { return interfaces[nf].volume; }
-	Real getConductivity(unsigned nf)
+	Real getCapVol(unsigned nf) const { return interfaces[nf].volume; }
+	Real getConductivity(unsigned nf) const
 	{
 		const CellHandle& innerCell = interfaces[nf].innerCell;
 		return innerCell->info().kNorm()[interfaces[nf].outerIndex];
 	}
 
 	void setCapPressure(unsigned nf, Real pcap) { interfaces[nf].capillaryP = pcap; }
-	Real getCapPressure(unsigned nf) { return interfaces[nf].capillaryP; }
+	Real getCapPressure(unsigned nf) const { return interfaces[nf].capillaryP; }
 	void setCapVol(unsigned nf, Real vcap) { interfaces[nf].volume = vcap; }
 	Real updateCapVol(unsigned nf, Real dt)
 	{
@@ -305,7 +301,7 @@ public:
 
 	//We can overload every functions of the base engine to make it behave differently
 	//if we overload action() like this, this engine is doing nothing in a standard timestep, it can still have useful functions
-	virtual void action() {};
+	void action() override {};
 
 	//If a new function is specific to the derived engine, put it here, else go to the base TemplateFlowEngine if it is useful for everyone
 	void computePoreBodyVolume();
@@ -338,9 +334,9 @@ public:
 	void invasion(); //functions can be shared by two modes
 	void invasionSingleCell(CellHandle cell);
 	void updatePressure();
-	Real getMinDrainagePc();
-	Real getMaxImbibitionPc();
-	Real getSaturation(bool isSideBoundaryIncluded = false);
+	Real getMinDrainagePc() const;
+	Real getMaxImbibitionPc() const;
+	Real getSaturation(bool isSideBoundaryIncluded = false) const;
 
 	void invasion1(); //with-trap
 	void updateReservoirs1();
@@ -375,25 +371,25 @@ public:
 	unsigned    markRecursively(const CellHandle& cell, int newLabel); // mark and count accessible cells with same label as 'cell' and connected to it
 	vector<int> pyClusterInvadePore(int cellId)
 	{
-		int label = solver->T[solver->currentTes].cellHandles[cellId]->info().label;
-		if (label < 1) {
-			LOG_WARN("the pore is not in a cluster, label=" << label);
+		int label2 = solver->T[solver->currentTes].cellHandles[cellId]->info().label;
+		if (label2 < 1) {
+			LOG_WARN("the pore is not in a cluster, label=" << label2);
 			return vector<int>();
 		}
-		return clusterInvadePore(clusters[label].get(), solver->tesselation().cellHandles[cellId]);
+		return clusterInvadePore(clusters[label2].get(), solver->tesselation().cellHandles[cellId]);
 	}
 	vector<int> pyClusterInvadePoreFast(int cellId)
 	{
-		int label = solver->T[solver->currentTes].cellHandles[cellId]->info().label;
-		if (label < 1) {
-			LOG_WARN("the pore is not in a cluster, label=" << label);
+		int label2 = solver->T[solver->currentTes].cellHandles[cellId]->info().label;
+		if (label2 < 1) {
+			LOG_WARN("the pore is not in a cluster, label=" << label2);
 			return vector<int>();
 		}
-		return clusterInvadePoreFast(clusters[label].get(), solver->T[solver->currentTes].cellHandles[cellId]);
+		return clusterInvadePoreFast(clusters[label2].get(), solver->T[solver->currentTes].cellHandles[cellId]);
 	}
 	boost::python::list pyClusters();
 	bool                connectedAroundEdge(const RTriangulation& Tri, CellHandle& cell, unsigned facet1, unsigned facet2);
-	// 	int getMaxCellLabel();
+	// 	int getMaxCellLabel() const;
 
 	//compute forces
 	void computeFacetPoreForcesWithCache(bool onlyCache = false);
@@ -404,8 +400,7 @@ public:
 			for (FiniteVerticesIterator v = solver->tesselation().Triangulation().finite_vertices_begin();
 			     v != solver->tesselation().Triangulation().finite_vertices_end();
 			     ++v) {
-				if (permanently)
-					scene->forces.setPermForce(v->info().id(), makeVector3r(v->info().forces));
+				if (permanently) scene->forces.setPermForce(v->info().id(), makeVector3r(v->info().forces));
 				else
 					scene->forces.addForce(v->info().id(), makeVector3r(v->info().forces));
 			}
@@ -432,17 +427,17 @@ public:
 	bool detectBridge(RTriangulation::Finite_edges_iterator& edge);
 
 	//Library TwoPhaseFlow
-	Real getKappa(int numberFacets);
-	Real getChi(int numberFacets);
-	Real getLambda(int numberFacets);
-	Real getN(int numberFacets);
-	Real getDihedralAngle(int numberFacets);
+	Real getKappa(int numberFacets) const;
+	Real getChi(int numberFacets) const;
+	Real getLambda(int numberFacets) const;
+	Real getN(int numberFacets) const;
+	Real getDihedralAngle(int numberFacets) const;
 
 	//Merging Library
 	void mergeCells();
 	void countFacets();
 	void computeMergedVolumes();
-	void getMergedCellStats();
+	void getMergedCellStats() const;
 	void calculateResidualSaturation();
 	void adjustUnresolvedPoreThroatsAfterMerging();
 	void actionMergingAlgorithm();
@@ -457,10 +452,10 @@ public:
 	void setListOfPores();
 	void getQuantities();
 	Real porePressureFromPcS(CellHandle cell, Real saturation);
-	Real getSolidVolumeInCell(CellHandle cell);
+	Real getSolidVolumeInCell(CellHandle cell) const;
 
-	Real getConstantC4(CellHandle cell);
-	Real getConstantC3(CellHandle cell);
+	Real getConstantC4(CellHandle cell) const;
+	Real getConstantC3(CellHandle cell) const;
 	Real dsdp(CellHandle cell, Real pw);
 	Real poreSaturationFromPcS(CellHandle cell, Real pw);
 
@@ -497,35 +492,35 @@ public:
 	std::vector<ETriplet>                                                                   tripletList;
 	Eigen::SparseLU<Eigen::SparseMatrix<Real, Eigen::ColMajor>, Eigen::COLAMDOrdering<int>> eSolver;
 
-	int getCell2(Real posX, Real posY, Real posZ)
+	int getCell2(Real posX, Real posY, Real posZ) const
 	{ //Should be fixed properly
-		RTriangulation& tri  = solver->T[solver->currentTes].Triangulation();
+		RTriangulation& tri = solver->T[solver->currentTes].Triangulation();
 		CellHandle      cell = tri.locate(CGT::Sphere(posX, posY, posZ));
 		return cell->info().id;
 	}
 
 	boost::python::list cellporeThroatConductivity(unsigned int id)
 	{ // Temporary function to allow for simulations in Python, can be easily accessed in c++
-		boost::python::list ids;
+		boost::python::list ids2;
 		if (id >= solver->T[solver->currentTes].cellHandles.size()) {
 			LOG_ERROR("id out of range, max value is " << solver->T[solver->currentTes].cellHandles.size());
-			return ids;
+			return ids2;
 		}
 		for (unsigned int i = 0; i < 4; i++)
-			ids.append(solver->T[solver->currentTes].cellHandles[id]->info().kNorm()[i]);
-		return ids;
+			ids2.append(solver->T[solver->currentTes].cellHandles[id]->info().kNorm()[i]);
+		return ids2;
 	}
 
 	boost::python::list solidSurfaceAreaPerParticle(unsigned int id)
 	{ // Temporary function to allow for simulations in Python, can be easily accessed in c++
-		boost::python::list ids;
+		boost::python::list ids2;
 		if (id >= solver->T[solver->currentTes].cellHandles.size()) {
 			LOG_ERROR("id out of range, max value is " << solver->T[solver->currentTes].cellHandles.size());
-			return ids;
+			return ids2;
 		}
 		for (unsigned int i = 0; i < 4; i++)
-			ids.append(solver->T[solver->currentTes].cellHandles[id]->info().particleSurfaceArea[i]);
-		return ids;
+			ids2.append(solver->T[solver->currentTes].cellHandles[id]->info().particleSurfaceArea[i]);
+		return ids2;
 	}
 
 	//post-processing
@@ -534,46 +529,45 @@ public:
 
 	boost::python::list cellporeThroatRadius(unsigned int id)
 	{
-		boost::python::list ids;
+		boost::python::list ids2;
 		if (id >= solver->T[solver->currentTes].cellHandles.size()) {
 			LOG_ERROR("id out of range, max value is " << solver->T[solver->currentTes].cellHandles.size());
-			return ids;
+			return ids2;
 		}
 		for (unsigned int i = 0; i < 4; i++)
-			ids.append(solver->T[solver->currentTes].cellHandles[id]->info().poreThroatRadius[i]);
-		return ids;
+			ids2.append(solver->T[solver->currentTes].cellHandles[id]->info().poreThroatRadius[i]);
+		return ids2;
 	}
 
-	boost::python::list getNeighbors(unsigned int id, bool withInfCell)
+	boost::python::list getNeighbors(unsigned int id, bool withInfCell) const
 	{
-		boost::python::list   ids;
+		boost::python::list   ids2;
 		const RTriangulation& Tri = solver->tesselation().Triangulation();
 		if (id >= solver->tesselation().cellHandles.size()) {
 			LOG_ERROR("id out of range, max value is " << solver->T[solver->currentTes].cellHandles.size());
-			return ids;
+			return ids2;
 		}
 		for (unsigned int i = 0; i < 4; i++) {
 			const CellHandle& neighbourCell = solver->tesselation().cellHandles[id]->neighbor(i);
-			if (withInfCell == true)
-				ids.append(neighbourCell->info().id);
+			if (withInfCell == true) ids2.append(neighbourCell->info().id);
 			else if (!Tri.is_infinite(neighbourCell))
-				ids.append(neighbourCell->info().id);
+				ids2.append(neighbourCell->info().id);
 		}
-		return ids;
+		return ids2;
 	}
 
 	//TODO
 	//Dynamic code
 	boost::python::list cellEntrySaturation(unsigned int id)
 	{ // Temporary function to allow for simulations in Python, can be easily accessed in c++
-		boost::python::list ids;
+		boost::python::list ids2;
 		if (id >= solver->T[solver->currentTes].cellHandles.size()) {
 			LOG_ERROR("id out of range, max value is " << solver->T[solver->currentTes].cellHandles.size());
-			return ids;
+			return ids2;
 		}
 		for (unsigned int i = 0; i < 4; i++)
-			ids.append(solver->T[solver->currentTes].cellHandles[id]->info().entrySaturation[i]);
-		return ids;
+			ids2.append(solver->T[solver->currentTes].cellHandles[id]->info().entrySaturation[i]);
+		return ids2;
 	}
 
 	//FIXME, needs to trigger initSolver() Somewhere, else changing flow.debug or other similar things after first calculation has no effect
@@ -582,15 +576,14 @@ public:
 	void computeOnePhaseFlow()
 	{
 		scene = Omega::instance().getScene().get();
-		if (!solver)
-			cerr << "no solver!" << endl;
+		if (!solver) cerr << "no solver!" << endl;
 		solver->gaussSeidel(scene->dt);
 		initSolver(*solver);
 	}
 	///manipulate/get/set on pore geometry
-	bool isCellNeighbor(unsigned int cell1, unsigned int cell2);
+	bool isCellNeighbor(unsigned int cell1, unsigned int cell2) const;
 	void setPoreThroatRadius(unsigned int cell1, unsigned int cell2, Real radius);
-	Real getPoreThroatRadius(unsigned int cell1, unsigned int cell2);
+	Real getPoreThroatRadius(unsigned int cell1, unsigned int cell2) const;
 
 	CELL_SCALAR_GETTER(bool, .isWRes, cellIsWRes)
 	CELL_SCALAR_GETTER(bool, .isNWRes, cellIsNWRes)
