@@ -5,6 +5,11 @@
 #include <boost/python/tuple.hpp>
 #include <string>
 
+namespace forCtags {
+struct libVersions {
+}; // for ctags
+}
+
 namespace py = boost::python;
 
 CREATE_CPP_LOCAL_LOGGER("_libVersions.cpp")
@@ -17,14 +22,10 @@ py::tuple extractNumbers(std::string verStr, std::string what)
 	int               found;
 	while (!ss.eof()) {
 		ss >> temp;
-		if (std::stringstream(temp) >> found) {
-			verNum.push_back(found);
-		}
+		if (std::stringstream(temp) >> found) { verNum.push_back(found); }
 		temp = "";
 	}
-	if (verNum.size() > 3) {
-		LOG_WARN(what << ": more than 3 numbers extracted from " << verStr);
-	}
+	if (verNum.size() > 3) { LOG_WARN(what << ": more than 3 numbers extracted from " << verStr); }
 	switch (verNum.size()) {
 		case 0: return py::make_tuple(0, 0, 0);
 		case 1: return py::make_tuple(verNum[0], 0, 0);
@@ -179,8 +180,12 @@ py::list sqliteVer()
 
 // 12. VTK
 #ifdef YADE_VTK
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
 #include <vtkVersion.h>
-py::list vtkVer()
+#pragma GCC diagnostic pop
+py::list               vtkVer()
 {
 	py::list ret;
 	ret.append(py::make_tuple(VTK_MAJOR_VERSION, VTK_MINOR_VERSION, VTK_BUILD_VERSION));
@@ -267,7 +272,12 @@ py::list metisVer() { return {}; }
 
 // 17. mpi
 #ifdef YADE_MPI
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wcast-function-type"
 #include <mpi.h>
+#pragma GCC diagnostic pop
 // https://www.open-mpi.org/software/ompi/versions/
 py::list mpiVer()
 {
@@ -304,9 +314,14 @@ py::list mpiVer() { return {}; }
 
 // 18. clp
 #ifdef YADE_POTENTIAL_BLOCKS
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wshadow"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
 #include <ClpConfig.h>
 #include <CoinUtilsConfig.h>
-py::list clpVer()
+#pragma GCC diagnostic pop
+py::list               clpVer()
 {
 	py::list ret;
 	ret.append(py::make_tuple(CLP_VERSION_MAJOR, CLP_VERSION_MINOR, CLP_VERSION_RELEASE));
@@ -339,8 +354,18 @@ py::list mpfrVer()
 	ret.append(boost::lexical_cast<std::string>(MPFR_VERSION_STRING));
 	return ret;
 }
+#include <mpc.h>
+py::list mpcVer()
+{
+	py::list ret;
+	ret.append(py::make_tuple(MPC_VERSION_MAJOR, MPC_VERSION_MINOR, MPC_VERSION_PATCHLEVEL));
+	ret.append(boost::lexical_cast<std::string>(MPC_VERSION_STRING));
+	return ret;
+}
+
 #else
 py::list mpfrVer() { return {}; }
+py::list mpcVer() { return {}; }
 #endif
 
 py::dict getAllVersionsCpp()
@@ -365,6 +390,7 @@ py::dict getAllVersionsCpp()
 	ret["clp"]         = clpVer();
 	ret["coinutils"]   = coinutilsVer();
 	ret["mpfr"]        = mpfrVer();
+	ret["mpc"]         = mpcVer();
 	return ret;
 }
 
