@@ -1,4 +1,8 @@
 #include <lib/high-precision/Constants.hpp>
+#include <core/InteractionLoop.hpp>
+#ifdef YADE_LS_DEM
+#include <pkg/levelSet/ShopLS.hpp>
+#endif // YADE_LS_DEM
 #include <py/_utils.hpp>
 // https://codeyarns.com/2014/03/11/how-to-selectively-ignore-a-gcc-warning/
 #pragma GCC diagnostic push
@@ -23,12 +27,9 @@ py::tuple negPosExtremeIds(int axis, Real distFactor)
 	py::list   minIds, maxIds;
 	for (const auto& b : *Omega::instance().getScene()->bodies) {
 		shared_ptr<Sphere> s = YADE_PTR_DYN_CAST<Sphere>(b->shape);
-		if (!s)
-			continue;
-		if (b->state->pos[axis] - s->radius * distFactor <= minCoord)
-			minIds.append(b->getId());
-		if (b->state->pos[axis] + s->radius * distFactor >= maxCoord)
-			maxIds.append(b->getId());
+		if (!s) continue;
+		if (b->state->pos[axis] - s->radius * distFactor <= minCoord) minIds.append(b->getId());
+		if (b->state->pos[axis] + s->radius * distFactor >= maxCoord) maxIds.append(b->getId());
 	}
 	return py::make_tuple(minIds, maxIds);
 }
@@ -42,10 +43,8 @@ py::tuple coordsAndDisplacements(int axis, py::tuple Aabb)
 		bbMax = py::extract<Vector3r>(Aabb[1])();
 	}
 	py::list retCoord, retDispl;
-	FOREACH(const shared_ptr<Body>& b, *Omega::instance().getScene()->bodies)
-	{
-		if (useBB && !Shop::isInBB(b->state->pos, bbMin, bbMax))
-			continue;
+	for (const auto& b : *Omega::instance().getScene()->bodies) {
+		if (useBB && !Shop::isInBB(b->state->pos, bbMin, bbMax)) continue;
 		retCoord.append(b->state->pos[axis]);
 		retDispl.append(b->state->pos[axis] - b->state->refPos[axis]);
 	}
@@ -59,9 +58,7 @@ void setRefSe3()
 		b->state->refPos = b->state->pos;
 		b->state->refOri = b->state->ori;
 	}
-	if (scene->isPeriodic) {
-		scene->cell->refHSize = scene->cell->hSize;
-	}
+	if (scene->isPeriodic) { scene->cell->refHSize = scene->cell->hSize; }
 }
 
 Real PWaveTimeStep() { return Shop::PWaveTimeStep(); };
@@ -69,8 +66,7 @@ Real RayleighWaveTimeStep() { return Shop::RayleighWaveTimeStep(); };
 
 py::tuple interactionAnglesHistogram(int axis, int mask, size_t bins, py::tuple aabb, bool sphSph, Real minProjLen)
 {
-	if (axis < 0 || axis > 2)
-		throw invalid_argument("Axis must be from {0,1,2}=x,y,z.");
+	if (axis < 0 || axis > 2) throw invalid_argument("Axis must be from {0,1,2}=x,y,z.");
 	Vector3r bbMin(Vector3r::Zero()), bbMax(Vector3r::Zero());
 	bool     useBB = py::len(aabb) > 0;
 	if (useBB) {
@@ -81,28 +77,20 @@ py::tuple interactionAnglesHistogram(int axis, int mask, size_t bins, py::tuple
 	int               axis2 = (axis + 1) % 3, axis3 = (axis + 2) % 3;
 	vector<Real>      cummProj(bins, 0.);
 	shared_ptr<Scene> rb = Omega::instance().getScene();
-	FOREACH(const shared_ptr<Interaction>& i, *rb->interactions)
-	{
-		if (!i->isReal())
-			continue;
+	for (const auto& i : *rb->interactions) {
+		if (!i->isReal()) continue;
 		const shared_ptr<Body>&b1 = Body::byId(i->getId1(), rb), b2 = Body::byId(i->getId2(), rb);
-		if (!b1->maskOk(mask) || !b2->maskOk(mask))
-			continue;
-		if (useBB && !Shop::isInBB(b1->state->pos, bbMin, bbMax) && !Shop::isInBB(b2->state->pos, bbMin, bbMax))
-			continue;
-		if (sphSph && (!dynamic_cast<Sphere*>(b1->shape.get()) || !dynamic_cast<Sphere*>(b2->shape.get())))
-			continue;
+		if (!b1->maskOk(mask) || !b2->maskOk(mask)) continue;
+		if (useBB && !Shop::isInBB(b1->state->pos, bbMin, bbMax) && !Shop::isInBB(b2->state->pos, bbMin, bbMax)) continue;
+		if (sphSph && (!dynamic_cast<Sphere*>(b1->shape.get()) || !dynamic_cast<Sphere*>(b2->shape.get()))) continue;
 		GenericSpheresContact* geom = dynamic_cast<GenericSpheresContact*>(i->geom.get());
-		if (!geom)
-			continue;
+		if (!geom) continue;
 		Vector3r n(geom->normal);
 		n[axis]   = 0.;
 		Real nLen = n.norm();
-		if (nLen < minProjLen)
-			continue; // this interaction is (almost) exactly parallel to our axis; skip that one
+		if (nLen < minProjLen) continue; // this interaction is (almost) exactly parallel to our axis; skip that one
 		Real theta = acos(n[axis2] / nLen) * (n[axis3] > 0 ? 1 : -1);
-		if (theta < 0)
-			theta += Mathr::PI;
+		if (theta < 0) theta += Mathr::PI;
 		int binNo = int(math::round(theta / binStep));
 		cummProj[binNo] += nLen;
 	}
@@ -126,37 +114,30 @@ py::tuple bodyNumInteractionsHistogram(py::tuple aabb)
 	vector<int>              bodyNumIntr;
 	bodyNumIntr.resize(rb->bodies->size(), 0);
 	int maxIntr = 0;
-	FOREACH(const shared_ptr<Interaction>& i, *rb->interactions)
-	{
-		if (!i->isReal())
-			continue;
+	for (const auto& i : *rb->interactions) {
+		if (!i->isReal()) continue;
 		const Body::id_t       id1 = i->getId1(), id2 = i->getId2();
 		const shared_ptr<Body>&b1 = Body::byId(id1, rb), b2 = Body::byId(id2, rb);
 		if ((useBB && Shop::isInBB(b1->state->pos, bbMin, bbMax)) || !useBB) {
-			if (b1->isClumpMember())
-				bodyNumIntr[b1->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
+			if (b1->isClumpMember()) bodyNumIntr[b1->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
 			else
 				bodyNumIntr[id1] += 1;
 		}
 		if ((useBB && Shop::isInBB(b2->state->pos, bbMin, bbMax)) || !useBB) {
-			if (b2->isClumpMember())
-				bodyNumIntr[b2->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
+			if (b2->isClumpMember()) bodyNumIntr[b2->clumpId] += 1; //count bodyNumIntr for the clump, not for the member
 			else
 				bodyNumIntr[id2] += 1;
 		}
 		maxIntr = max(max(maxIntr, bodyNumIntr[b1->getId()]), bodyNumIntr[b2->getId()]);
-		if (b1->isClumpMember())
-			maxIntr = max(maxIntr, bodyNumIntr[b1->clumpId]);
-		if (b2->isClumpMember())
-			maxIntr = max(maxIntr, bodyNumIntr[b2->clumpId]);
+		if (b1->isClumpMember()) maxIntr = max(maxIntr, bodyNumIntr[b1->clumpId]);
+		if (b2->isClumpMember()) maxIntr = max(maxIntr, bodyNumIntr[b2->clumpId]);
 	}
 	vector<int> bins;
 	bins.resize(maxIntr + 1, 0);
 	for (size_t id = 0; id < bodyNumIntr.size(); id++) {
 		const shared_ptr<Body>& b = Body::byId(id, rb);
 		if (b) {
-			if (bodyNumIntr[id] > 0)
-				bins[bodyNumIntr[id]] += 1;
+			if (bodyNumIntr[id] > 0) bins[bodyNumIntr[id]] += 1;
 			// 0 is handled specially: add body to the 0 bin only if it is inside the bb requested (if applicable)
 			// otherwise don't do anything, since it is outside the volume of interest
 			else if (((useBB && Shop::isInBB(b->state->pos, bbMin, bbMax)) || !useBB) && !(b->isClumpMember()))
@@ -165,8 +146,7 @@ py::tuple bodyNumInteractionsHistogram(py::tuple aabb)
 	}
 	py::list count, num;
 	for (size_t n = 0; n < bins.size(); n++) {
-		if (bins[n] == 0)
-			continue;
+		if (bins[n] == 0) continue;
 		num.append(n);
 		count.append(bins[n]);
 	}
@@ -189,8 +169,7 @@ py::dict getViscoelasticFromSpheresInteraction(Real tc, Real en, Real es)
 void highlightNone()
 {
 	for (const auto& b : *Omega::instance().getScene()->bodies) {
-		if (!b->shape)
-			continue;
+		if (!b->shape) continue;
 		b->shape->highlight = false;
 	}
 }
@@ -248,11 +227,9 @@ Real sumFacetNormalForces(vector<Body::id_t> ids, int axis)
 	shared_ptr<Scene> rb = Omega::instance().getScene();
 	rb->forces.sync();
 	Real ret = 0;
-	FOREACH(const Body::id_t id, ids)
-	{
+	for (const Body::id_t& id : ids) {
 		Facet* f = YADE_CAST<Facet*>(Body::byId(id, rb)->shape.get());
-		if (axis < 0)
-			ret += rb->forces.getForce(id).dot(f->normal);
+		if (axis < 0) ret += rb->forces.getForce(id).dot(f->normal);
 		else {
 			Vector3r ff = rb->forces.getForce(id);
 			ff[axis]    = 0;
@@ -272,8 +249,7 @@ void wireSome(string filter)
 		mode = noSpheres;
 	}
 	for (const auto& b : *Omega::instance().getScene()->bodies) {
-		if (!b->shape)
-			return;
+		if (!b->shape) return;
 		bool wire;
 		switch (mode) {
 			case none: wire = false; break;
@@ -314,17 +290,14 @@ bool pointInsidePolygon(py::tuple xy, py::object vertices)
 	int            rows, cols;
 	PyArrayObject* vert   = (PyArrayObject*)vertices.ptr();
 	int            result = PyArray_As2D((PyObject**)&vert /* is replaced */, &vertData, &rows, &cols, PyArray_DOUBLE);
-	if (result != 0)
-		throw invalid_argument("Unable to cast vertices to 2d array");
-	if (cols != 2 || rows < 3)
-		throw invalid_argument("Vertices must have 2 columns (x and y) and at least 3 rows.");
+	if (result != 0) throw invalid_argument("Unable to cast vertices to 2d array");
+	if (cols != 2 || rows < 3) throw invalid_argument("Vertices must have 2 columns (x and y) and at least 3 rows.");
 	int  i /*current node*/, j /*previous node*/;
 	bool inside = false;
 	for (i = 0, j = rows - 1; i < rows; j = i++) {
 		double vx_i = *(double*)(vert->data + i * vert->strides[0]), vy_i = *(double*)(vert->data + i * vert->strides[0] + vert->strides[1]),
 		       vx_j = *(double*)(vert->data + j * vert->strides[0]), vy_j = *(double*)(vert->data + j * vert->strides[0] + vert->strides[1]);
-		if (((vy_i > testy) != (vy_j > testy)) && (testx < (vx_j - vx_i) * (testy - vy_i) / (vy_j - vy_i) + vx_i))
-			inside = !inside;
+		if (((vy_i > testy) != (vy_j > testy)) && (testx < (vx_j - vx_i) * (testy - vy_i) / (vy_j - vy_i) + vx_i)) inside = !inside;
 	}
 	Py_DECREF(vert);
 	return inside;
@@ -340,20 +313,17 @@ bool pointInsidePolygon(py::tuple xy, py::object vertices)
 Real approxSectionArea(Real coord, int axis)
 {
 	std::list<Vector2r> cloud;
-	if (axis < 0 || axis > 2)
-		throw invalid_argument("Axis must be ∈ {0,1,2}");
+	if (axis < 0 || axis > 2) throw invalid_argument("Axis must be ∈ {0,1,2}");
 	const int  ax1 = (axis + 1) % 3, ax2 = (axis + 2) % 3;
 	const Real sqrt3 = sqrt(3);
 	Vector2r   mm, mx;
 	int        i = 0;
 	for (const auto& b : *Omega::instance().getScene()->bodies) {
 		Sphere* s = dynamic_cast<Sphere*>(b->shape.get());
-		if (!s)
-			continue;
+		if (!s) continue;
 		const Vector3r& pos(b->state->pos);
 		const Real      r(s->radius);
-		if ((pos[axis] > coord && (pos[axis] - r) > coord) || (pos[axis] < coord && (pos[axis] + r) < coord))
-			continue;
+		if ((pos[axis] > coord && (pos[axis] - r) > coord) || (pos[axis] < coord && (pos[axis] + r) < coord)) continue;
 		Vector2r c(pos[ax1], pos[ax2]);
 		cloud.push_back(c + Vector2r(r, 0.));
 		cloud.push_back(c + Vector2r(-r, 0.));
@@ -361,14 +331,11 @@ Real approxSectionArea(Real coord, int axis)
 		cloud.push_back(c + Vector2r(r / 2., -sqrt3 * r));
 		cloud.push_back(c + Vector2r(-r / 2., sqrt3 * r));
 		cloud.push_back(c + Vector2r(-r / 2., -sqrt3 * r));
-		if (i++ == 0) {
-			mm = c, mx = c;
-		}
+		if (i++ == 0) { mm = c, mx = c; }
 		mm = Vector2r(min(c[0] - r, mm[0]), min(c[1] - r, mm[1]));
 		mx = Vector2r(max(c[0] + r, mx[0]), max(c[1] + r, mx[1]));
 	}
-	if (cloud.size() == 0)
-		return 0;
+	if (cloud.size() == 0) return 0;
 	ConvexHull2d     ch2d(cloud);
 	vector<Vector2r> hull = ch2d();
 	return simplePolygonArea2d(hull);
@@ -385,19 +352,15 @@ Vector3r forcesOnPlane(const Vector3r& planePt, const Vector3r& normal)
 {
 	Vector3r ret(Vector3r::Zero());
 	Scene*   scene = Omega::instance().getScene().get();
-	FOREACH(const shared_ptr<Interaction>& I, *scene->interactions)
-	{
-		if (!I->isReal())
-			continue;
+	for (const auto& I : *scene->interactions) {
+		if (!I->isReal()) continue;
 		NormShearPhys* nsi = dynamic_cast<NormShearPhys*>(I->phys.get());
-		if (!nsi)
-			continue;
+		if (!nsi) continue;
 		Vector3r pos1, pos2;
 		pos1      = Body::byId(I->getId1(), scene)->state->pos;
 		pos2      = Body::byId(I->getId2(), scene)->state->pos;
 		Real dot1 = (pos1 - planePt).dot(normal), dot2 = (pos2 - planePt).dot(normal);
-		if (dot1 * dot2 > 0)
-			continue; // both (centers of) bodies are on the same side of the plane=> this interaction has to be disregarded
+		if (dot1 * dot2 > 0) continue; // both (centers of) bodies are on the same side of the plane=> this interaction has to be disregarded
 		// if pt1 is on the negative plane side, d3dg->normal.Dot(normal)>0, the force is well oriented;
 		// otherwise, reverse its contribution. So that we return finally
 		// Sum [ ( normal(plane) dot normal(interaction= from 1 to 2) ) "nsi->force" ]
@@ -426,7 +389,7 @@ py::tuple spiralProject(const Vector3r& pt, Real dH_dTheta, int axis, Real perio
 
 shared_ptr<Interaction> Shop__createExplicitInteraction(Body::id_t id1, Body::id_t id2, bool virtualI)
 {
-	return Shop::createExplicitInteraction(id1, id2, /*force*/ true, virtualI);
+	return InteractionLoop::createExplicitInteraction(id1, id2, /*force*/ true, virtualI);
 }
 
 Real      Shop__unbalancedForce(bool useMaxForce /*false by default*/) { return Shop::unbalancedForce(useMaxForce); }
@@ -446,8 +409,7 @@ Real       Shop__getSpheresVolume(int mask) { return Shop::getSpheresVolume(Omeg
 Real       Shop__getSpheresMass(int mask) { return Shop::getSpheresMass(Omega::instance().getScene(), mask); }
 py::object Shop__kineticEnergy(bool findMaxId)
 {
-	if (!findMaxId)
-		return py::object(Shop::kineticEnergy());
+	if (!findMaxId) return py::object(Shop::kineticEnergy());
 	Body::id_t maxId;
 	Real       E = Shop::kineticEnergy(NULL, &maxId);
 	return py::make_tuple(E, maxId);
@@ -457,17 +419,13 @@ Real maxOverlapRatio()
 {
 	Scene* scene = Omega::instance().getScene().get();
 	Real   ret   = -1;
-	FOREACH(const shared_ptr<Interaction> I, *scene->interactions)
-	{
-		if (!I->isReal())
-			continue;
+	for (const auto& I : *scene->interactions) {
+		if (!I->isReal()) continue;
 		Sphere *s1(dynamic_cast<Sphere*>(Body::byId(I->getId1(), scene)->shape.get())),
 		        *s2(dynamic_cast<Sphere*>(Body::byId(I->getId2(), scene)->shape.get()));
-		if ((!s1) || (!s2))
-			continue;
+		if ((!s1) || (!s2)) continue;
 		ScGeom* geom = dynamic_cast<ScGeom*>(I->geom.get());
-		if (!geom)
-			continue;
+		if (!geom) continue;
 		Real rEq = 2 * s1->radius * s2->radius / (s1->radius + s2->radius);
 		ret      = max(ret, geom->penetrationDepth / rEq);
 	}
@@ -497,8 +455,7 @@ Real shiftBodies(py::list ids, const Vector3r& shift)
 	size_t            len = py::len(ids);
 	for (size_t i = 0; i < len; i++) {
 		const Body* b = (*rb->bodies)[py::extract<int>(ids[i])].get();
-		if (!b)
-			continue;
+		if (!b) continue;
 		b->state->pos += shift;
 	}
 	return 1;
@@ -526,11 +483,8 @@ py::list intrsOfEachBody()
 		ret.append(py::list());
 	}
 	// loop over all interactions and fill the list ret
-	FOREACH(const shared_ptr<Interaction>& i, *rb->interactions)
-	{
-		if (!i->isReal()) {
-			continue;
-		}
+	for (const auto& i : *rb->interactions) {
+		if (!i->isReal()) { continue; }
 		temp = py::extract<py::list>(ret[i->getId1()]);
 		temp.append(i);
 		temp = py::extract<py::list>(ret[i->getId2()]);
@@ -549,10 +503,8 @@ py::list numIntrsOfEachBody()
 		ret.append(0);
 	}
 	// loop over all interactions and fill the list ret
-	FOREACH(const shared_ptr<Interaction>& i, *rb->interactions)
-	{
-		if (!i->isReal())
-			continue;
+	for (const auto& i : *rb->interactions) {
+		if (!i->isReal()) continue;
 		ret[i->getId1()] += 1;
 		ret[i->getId2()] += 1;
 	}
@@ -973,7 +925,83 @@ try {
 	        setBodyColor,
 	        (py::args("id"), py::args("color")),
 	        "Set a body color from its id and a new Vector3r.\n\n:param int id: the body id.\n:param Vector3 color: the desired updated color.");
+#ifdef YADE_LS_DEM
+	// clang-format off
+	py::def("cart2spher",
+		ShopLS::cart2spher,
+		(py::arg("vec")),
+		"Converts cartesian coordinates to spherical ones.\n\n:param Vector3 vec: the $(x,y,z)$ cartesian coordinates\n:return: a $(r,\\theta,\\phi)$ Vector3 of spherical coordinates, with $\\theta = (\\vec{e_z},\\vec{e_r}) \\in [0;\\pi]$ and $\\phi \\in [0;2 \\pi]$ measured in $(x,y)$ plane from $x$-axis");
+	py::def("spher2cart",
+		ShopLS::spher2cart,
+		(py::arg("vec")),
+		"Converts spherical coordinates to cartesian ones.\n\n:param Vector3 vec: the $(r,\\theta,\\phi)$ spherical coordinates, see cart2spher function for conventions\n:return: a $(x,y,z)$ Vector3 of cartesian coordinates");
+	py::def("lsSimpleShape",
+		ShopLS::lsSimpleShape,
+		(py::arg("shape"),py::arg("aabb"),py::arg("step")=0.1,py::arg("epsilons")=Vector2r(Vector2r::Zero()),py::arg("clump")=boost::make_shared<Clump>()), // Vector*r(Vector*r::Zero()) is actually necessary for to-Python conversion to work (and YADE to start)
+		R"""(Creates a LevelSet shape among pre-defined ones. Not intended to be used directly, see levelSetBody() instead.
 
+:param int shape: a shape index among supported choices
+:param AlignedBox3 aabb: the axis-aligned surrounding box of the body
+:param Real step: the LevelSet grid step size
+:param Vector2 epsilons: the epsilon exponents in case *shape* = 3 (superellipsoid)
+:param Clump clump: the Clump instance to mimick in case *shape* = 4
+:return: a list (of list of list) corresponding to LevelSet.distField.)""");
+ // NB: the rest of the code makes a mixed use of py::arg and py::args, Boost doc does not really help for this https://www.boost.org/doc/libs/1_67_0/libs/python/doc/html/reference/function_invocation_and_creation.html#function_invocation_and_creation.boost_python_args_hpp, see /usr/include/boost/python/args.hpp if you wish...
+//	NB for the two following nGP: see overloading comments in ShopLS.hpp.
+	py::def("nGP",
+		ShopLS::nGPr,
+		(py::arg("min"),py::arg("max"),py::arg("step")),
+		"Defines how many gridpoints are necessary to go from *min* to (at least) *max*, by *step* increments, eg when constructing a :yref:`RegularGrid`\n\n:param Real min: lowest grid extremity as (min,min,min) in case you just give a number, or as (min[0],min[1],min[2]) in case you give a tuple/list/Vector3\n\n:param Real max: highest gridpoint as (max,max,max) in case you give a number, or as (max[0],max[1],max[2]) in case you give a tuple/list/Vector3. The actual highest point of the grid may be beyond max by something like *step*.\n:param Real step: the distance between two consecutive grid points (the same along each axis).\n\n:return: either an integer, or a Vector3 of, depending on usage"); // html doc output is bound to be less good than elsewhere (for the "Parameters" block), because of the same name below..
+	py::def("nGP",
+		ShopLS::nGPv,
+		(py::arg("min"),py::arg("max"),py::arg("step")),
+		"Type-overloaded version of the above, to allow for both types of max/min attributes.");
+	py::def("distApproxSE",
+		ShopLS::distApproxSE,
+		(py::arg("pt"),py::arg("radii"),py::arg("epsilons")),
+		R"""(An approximate distance value to a superellipsoid surface defined (in local axes) as $f(x,y,z) = ( |x/r_x|^{2/\epsilon_e} + |y/r_y|^{2/\epsilon_e} )^{\epsilon_e/\epsilon_n} + |z/r_z|^{2/\epsilon_n} = 1$.
+
+:param Vector3 pt: the $(x,y,z)$ of interest
+:param Vector3 radii: the $(r_x,r_y,r_z)$
+:param Vector2 epsilons: the $(\epsilon_e,\epsilon_n)$ exponents
+:return: a 0-approximation distance value.)""");
+	py::def("distIniClump",
+		ShopLS::distIniClump,
+		(py::arg("clump"),py::arg("grid")),
+		R"""(An appropriate discrete field to serve as a Fast Marching Method input in :yref:`FastMarchingMethod.phiIni` in order to compute distance to a clump.
+
+:param Clump clump: considered clump instance
+:param RegularGrid grid: the :yref:`RegularGrid` instance to consider
+:return: an appropriate 3D discrete field for :yref:`FastMarchingMethod.phiIni`.)""");
+	py::def("distIniSE",
+		ShopLS::distIniSE,
+		(py::arg("radii"),py::arg("epsilons"),py::arg("grid")),
+		R"""(An appropriate discrete field to serve as a Fast Marching Method input in :yref:`FastMarchingMethod.phiIni` in order to compute distance to a superellipsoid.
+
+:param Vector3 radii: the $(r_x,r_y,r_z)$
+:param Vector2 epsilons: the $(\epsilon_e,\epsilon_n)$ exponents
+:param RegularGrid grid: the :yref:`RegularGrid` instance to consider
+:return: an appropriate 3D discrete field for :yref:`FastMarchingMethod.phiIni`.)""");
+	py::def("distApproxRose",
+		ShopLS::distApproxRose,
+		(py::arg("pt")),
+		R"""(An approximate distance value to a rose-like flaky surface defined in spherical coordinates as $r = 3+1.5 \\sin(5 \\theta) \\sin(4\\phi)$ (see :yref:`cart2spher` function for spherical <-> cartesian convention).
+
+:param Vector3 pt: the pt of interest given in $(x,y,z)$ cartesian coordinates.
+:return: a 0-approximation distance value.)""");
+	py::def("phiIniCppPy",ShopLS::phiIniCppPy,(py::arg("grid")), // jduriez personal note: see fmm8 for comparison with phiIniPy
+		R"""(A possibly handy function to construct a :yref:`FastMarchingMethod.phiIni` after applying on *grid* an inside-outside Python function. The latter necessarily names ioFn and takes three floating numbers (cartesian coordinates) as arguments. Code source of the present function is both C++ and Python, and execution should be faster and heavier in memory than the pure Python version utils.phiIniPy, both being under the second and few MB for grids with ~ $10^4$ gridpoints.
+
+:param RegularGrid grid: the yref:`RegularGrid` instance to operate on with a preexisting ioFn Python function
+:return: an appropriate 3D discrete field for :yref:`FastMarchingMethod.phiIni`)""");
+	py::def("insideClump",ShopLS::insideClump,(py::arg("pt"),py::arg("clump")),
+		R"""(Tells whether some point is inside or outside a clump
+
+:param Vector3 pt: the point of interest expressed in local coordinates
+:param Clump clump: the clump instance to consider
+:return bool: True when strictly inside, False otherwise)""");
+	// clang-format on
+#endif //YADE_LS_DEM
 } catch (...) {
 	LOG_FATAL("Importing this module caused an exception and this module is in an inconsistent state now.");
 	PyErr_Print();
