@@ -10,11 +10,16 @@
 #include <pkg/common/Sphere.hpp>
 #include <pkg/dem/DemXDofGeom.hpp>
 #include <pkg/dem/ScGeom.hpp>
-#include <pkg/dem/Shop.hpp>
+#include <preprocessing/dem/Shop.hpp>
 #include <pkg/dem/Tetra.hpp>
 #include <pkg/dem/ViscoelasticPM.hpp>
 #ifdef YADE_MPI
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wpragmas"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wcast-function-type"
 #include <mpi.h>
+#pragma GCC diagnostic pop
 #endif
 
 
