@@ -16,6 +16,8 @@
 
 #include <lib/base/Logging.hpp>
 #include <lib/high-precision/Constants.hpp>
+#include <lib/high-precision/MathComplexFunctions.hpp>
+#include <lib/high-precision/MathSpecialFunctions.hpp>
 #include <lib/high-precision/Real.hpp>
 #include <lib/high-precision/RealHPConfig.hpp>
 #include <lib/high-precision/RealIO.hpp>
@@ -162,7 +164,7 @@ template <int N> void multVec(::yade::math::UnderlyingRealHP<RealHP<N>>* array,
 namespace yade {
 template <int N> void testConstants()
 {
-	LOG_NOFILTER("Checking ConstantsHP<" << N << ">");
+	LOG_NOFILTER("ConstantsHP<" << N << ">::PI = " << math::toStringHP(math::ConstantsHP<N>::PI));
 	BOOST_ASSERT(math::ConstantsHP<N>::PI == boost::math::constants::pi<RealHP<N>>());
 	BOOST_ASSERT(math::ConstantsHP<N>::TWO_PI == boost::math::constants::two_pi<RealHP<N>>());
 	BOOST_ASSERT(math::ConstantsHP<N>::HALF_PI == boost::math::constants::half_pi<RealHP<N>>());
@@ -181,12 +183,13 @@ template <int N> void testConstants()
 void                  testLoopRealHP();
 template <int N> void testArray()
 {
-	LOG_NOFILTER(
-	        "sizeof RealHP<" << N << ">" << std::setw(2) << " "
-	                         << " in bytes: " << sizeof(RealHP<N>));
-	LOG_NOFILTER("sizeof float       in bytes: " << sizeof(float));
-	LOG_NOFILTER("sizeof double      in bytes: " << sizeof(double));
-	LOG_NOFILTER("sizeof long double in bytes: " << sizeof(long double));
+	// clang-format off
+	LOG_NOFILTER("sizeof RealHP<" << N << ">" << std::setw(2) << " "
+	                            << " in bytes: " << std::setw(4) << sizeof(RealHP<N>  ) << " bits: " << std::setw(4) << std::numeric_limits<RealHP<N>  >::digits << " digits: " << std::numeric_limits<RealHP<N>  >::digits10 );
+	LOG_NOFILTER("sizeof float       in bytes: " << std::setw(4) << sizeof(float      ) << " bits: " << std::setw(4) << std::numeric_limits<float      >::digits << " digits: " << std::numeric_limits<float      >::digits10 );
+	LOG_NOFILTER("sizeof double      in bytes: " << std::setw(4) << sizeof(double     ) << " bits: " << std::setw(4) << std::numeric_limits<double     >::digits << " digits: " << std::numeric_limits<double     >::digits10 );
+	LOG_NOFILTER("sizeof long double in bytes: " << std::setw(4) << sizeof(long double) << " bits: " << std::setw(4) << std::numeric_limits<long double>::digits << " digits: " << std::numeric_limits<long double>::digits10 );
+	// clang-format on
 	std::vector<RealHP<N>> vec {};
 	int                    i = 1000;
 	while (i-- > 0)
@@ -201,8 +204,6 @@ template <int N> void testArray()
 			exit(1);
 		}
 	}
-	LOG_NOFILTER("calling testLoopRealHP()");
-	testLoopRealHP();
 }
 }
 
@@ -271,7 +272,7 @@ template <int N> struct IfConstexprForSlowFunctions<N, true> {
 
 template <int, bool> struct IfConstexprForEigen;
 
-#ifndef __clang__ // problem with clang 9.0.1-12. It tries to instatinate an explicitly illegal/disabled code. Produces errors that some types don't exist. But they shouldn't exist.
+//#ifndef __clang__ // problem with clang 9.0.1-12. It tries to instatinate an explicitly illegal/disabled code. Produces errors that some types don't exist. But they shouldn't exist.
 template <int N> struct IfConstexprForEigen<N, true> {
 	static void work(const py::scope& scopeHP, const long& defprec)
 	{
@@ -318,7 +319,7 @@ template <int N> struct IfConstexprForEigen<N, true> {
 		        R"""(:return: ``Real`` the smallest number greater than zero. Wraps `std::numeric_limits<Real>::min() <https://en.cppreference.com/w/cpp/types/numeric_limits/min>`__)""");
 	}
 };
-#endif
+//#endif
 
 template <int N> struct IfConstexprForEigen<N, false> {
 	static void work(const py::scope& scopeHP, const long& defprec)
@@ -377,9 +378,7 @@ template <int N, bool registerConverters> struct RegisterRealHPMath {
 
 		// Very important line: Verifies that Real type satisfies all the requirements of RealTypeConcept
 		BOOST_CONCEPT_ASSERT((boost::math::concepts::RealTypeConcept<RealHP<N>>));
-		if (::yade::math::isHP<RealHP<N>> == false) {
-			throw std::runtime_error("::yade::math::isHP<RealHP<N1>> == false, please file a bug report.");
-		};
+		if (::yade::math::isHP<RealHP<N>> == false) { throw std::runtime_error("::yade::math::isHP<RealHP<N1>> == false, please file a bug report."); };
 		if (::yade::math::isHP<ComplexHP<N>> == false) {
 			throw std::runtime_error("::yade::math::isHP<ComplexHP<N1>> == false, please file a bug report.");
 		};
@@ -405,10 +404,60 @@ template <int N, bool registerConverters> struct RegisterRealHPMath {
 		                &Var<N, registerConverters>::setComplex,
 		                "one ``Complex`` variable to test reading from and writing to it.");
 
+		/********************************************************************************************/
+		/**********************                complex functions               **********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+
+		/********************************************************************************************/
+		/**********************          complex conj, abs, real, imag         **********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+
+		py::def("conj",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::conj),
+		        (py::arg("x")),
+		        R"""(:return: the complex conjugation a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::conj(…)`` or `std::conj(…) <https://en.cppreference.com/w/cpp/numeric/complex/conj>`__ function.)""");
+		py::def("real",
+		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::real),
+		        (py::arg("x")),
+		        R"""(:return: the real part of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::real(…)`` or `std::real(…) <https://en.cppreference.com/w/cpp/numeric/complex/real2>`__ function.)""");
+		py::def("imag",
+		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::imag),
+		        (py::arg("x")),
+		        R"""(:return: the imag part of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::imag(…)`` or `std::imag(…) <https://en.cppreference.com/w/cpp/numeric/complex/imag2>`__ function.)""");
+		py::def("abs",
+		        // note …<ComplexHP<N>> at the end, to help compiler in the template overload resolution.
+		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::abs<ComplexHP<N>>),
+		        (py::arg("x")),
+		        R"""(:return: the ``Real`` absolute value of the ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::abs(…)`` or `std::abs(…) <https://en.cppreference.com/w/cpp/numeric/complex/abs>`__ function.)""");
+
+		/********************************************************************************************/
+		/**********************          Complex arg, norm, proj, polar         *********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+		py::def("arg",
+		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::arg),
+		        (py::arg("x")),
+		        R"""(:return: ``Real`` the arg (Phase angle of complex in radians) of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::arg(…)`` or `std::arg(…) <https://en.cppreference.com/w/cpp/numeric/complex/arg>`__ function.)""");
+		py::def("squaredNorm", // # Warning: C++ std::norm is squared length. In python/mpmath norm is C++ abs == length.
+		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::norm),
+		        (py::arg("x")),
+		        R"""(:return: ``Real`` the norm (squared magnitude) of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::norm(…)`` or `std::norm(…) <https://en.cppreference.com/w/cpp/numeric/complex/norm>`__ function.)""");
+		py::def("proj",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::proj),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the proj (projection of the complex number onto the Riemann sphere) of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::proj(…)`` or `std::proj(…) <https://en.cppreference.com/w/cpp/numeric/complex/proj>`__ function.)""");
+		py::def("polar",
+		        static_cast<ComplexHP<N> (*)(const RealHP<N>&, const RealHP<N>&)>(&::yade::math::polar),
+		        (py::arg("x"), "y"),
+		        R"""(:return: ``Complex`` the polar (Complex from polar components) of the ``Real`` rho (length), ``Real`` theta (angle) arguments in radians. Depending on compilation options wraps ``::boost::multiprecision::polar(…)`` or `std::polar(…) <https://en.cppreference.com/w/cpp/numeric/complex/polar>`__ function.)""");
+
 		/********************************************************************************************/
 		/**********************        complex trigonometric functions         **********************/
 		/********************************************************************************************/
 		// complex functions must be registered first, so that python will properly discover overloads
+
 		py::def("sin",
 		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::sin),
 		        (py::arg("x")),
@@ -434,6 +483,88 @@ template <int N, bool registerConverters> struct RegisterRealHPMath {
 		        (py::arg("x")),
 		        R"""(:return: ``Complex`` the hyperbolic tangent of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::tanh(…)`` or `std::tanh(…) <https://en.cppreference.com/w/cpp/numeric/complex/tanh>`__ function.)""");
 
+		/********************************************************************************************/
+		/**********************     Complex inverse trigonometric functions    **********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+
+		py::def("asin",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::asin),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-sine of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::asin(…)`` or `std::asin(…) <https://en.cppreference.com/w/cpp/numeric/complex/asin>`__ function.)""");
+		py::def("asinh",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::asinh),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-hyperbolic sine of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::asinh(…)`` or `std::asinh(…) <https://en.cppreference.com/w/cpp/numeric/complex/asinh>`__ function.)""");
+		py::def("acos",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::acos),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-cosine of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::acos(…)`` or `std::acos(…) <https://en.cppreference.com/w/cpp/numeric/complex/acos>`__ function.)""");
+		py::def("acosh",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::acosh),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-hyperbolic cosine of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::acosh(…)`` or `std::acosh(…) <https://en.cppreference.com/w/cpp/numeric/complex/acosh>`__ function.)""");
+		py::def("atan",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::atan),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-tangent of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::atan(…)`` or `std::atan(…) <https://en.cppreference.com/w/cpp/numeric/complex/atan>`__ function.)""");
+		py::def("atanh",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::atanh),
+		        (py::arg("x")),
+		        R"""(:return: ``Complex`` the arc-hyperbolic tangent of the ``Complex`` argument in radians. Depending on compilation options wraps ``::boost::multiprecision::atanh(…)`` or `std::atanh(…) <https://en.cppreference.com/w/cpp/numeric/complex/atanh>`__ function.)""");
+
+		/********************************************************************************************/
+		/**********************   logarithm, exponential and power functions   **********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+
+		py::def("exp",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::exp),
+		        (py::arg("x")),
+		        R"""(:return: the base `e` exponential of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::exp(…)`` or `std::exp(…) <https://en.cppreference.com/w/cpp/numeric/complex/exp>`__ function.)""");
+		py::def("log",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::log),
+		        (py::arg("x")),
+		        R"""(:return: the ``Complex`` natural (base `e`) logarithm of a complex value z with a branch cut along the negative real axis. Depending on compilation options wraps ``::boost::multiprecision::log(…)`` or `std::log(…) <https://en.cppreference.com/w/cpp/numeric/complex/log>`__ function.)""");
+		py::def("log10",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::log10),
+		        (py::arg("x")),
+		        R"""(:return: the ``Complex``  (base `10`) logarithm of a complex value z with a branch cut along the negative real axis. Depending on compilation options wraps ``::boost::multiprecision::log10(…)`` or `std::log10(…) <https://en.cppreference.com/w/cpp/numeric/complex/log10>`__ function.)""");
+		py::def("pow",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&,const ComplexHP<N>&)>(&::yade::math::pow),
+		        (py::arg("x"), "pow"),
+		        R"""(:return: the ``Complex`` complex arg1 raised to the ``Complex`` power arg2. Depending on compilation options wraps ``::boost::multiprecision::pow(…)`` or `std::pow(…) <https://en.cppreference.com/w/cpp/numeric/complex/pow>`__ function.)""");
+		py::def("sqrt",
+		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::sqrt),
+		        (py::arg("x")),
+		        R"""(:return: the ``Complex`` square root of ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::sqrt(…)`` or `std::sqrt(…) <https://en.cppreference.com/w/cpp/numeric/complex/sqrt>`__ function.)""");
+
+		/********************************************************************************************/
+		/**********************  Special Functions: bessel, factorial, etc ……  **********************/
+		/********************************************************************************************/
+		// complex functions must be registered first, so that python will properly discover overloads
+
+		// next are special real functions
+		py::def("cylBesselJ",
+		        static_cast<RealHP<N> (*)(int, const RealHP<N>&)>(&::yade::math::cylBesselJ),
+		        (py::arg("k"), "x"),
+		        R"""(:return: ``Real`` the Bessel Functions of the First Kind of the order ``k`` and the ``Real`` argument. See: <https://www.boost.org/doc/libs/1_77_0/libs/math/doc/html/math_toolkit/bessel/bessel_first.html>`__)""");
+		py::def("factorial",
+		        static_cast<RealHP<N> (*)(unsigned int)>(&::yade::math::factorial),
+		        (py::arg("x")),
+		        R"""(:return: ``Real`` the factorial of the ``Real`` argument. See: <https://www.boost.org/doc/libs/1_77_0/libs/math/doc/html/math_toolkit/factorials/sf_factorial.html>`__)""");
+		py::def("laguerre",
+		        static_cast<RealHP<N> (*)(unsigned int, unsigned int, const RealHP<N>&)>(&::yade::math::laguerre),
+		        (py::arg("n"), "m", "x"),
+		        R"""(:return: ``Real`` the Laguerre polynomial of the orders ``n``, ``m`` and the ``Real`` argument. See: <https://www.boost.org/doc/libs/1_77_0/libs/math/doc/html/math_toolkit/sf_poly/laguerre.html>`__)""");
+		py::def("sphericalHarmonic",
+		        static_cast<ComplexHP<N> (*)(unsigned int, signed int, const RealHP<N>&, const RealHP<N>&)>(&::yade::math::sphericalHarmonic),
+		        (py::arg("l"), "m", "theta", "phi"),
+		        R"""(:return: ``Real`` the spherical harmonic polynomial of the orders ``l`` (unsigned int), ``m`` (signed int) and the ``Real`` arguments ``theta`` and ``phi``. See: <https://www.boost.org/doc/libs/1_77_0/libs/math/doc/html/math_toolkit/sf_poly/sph_harm.html>`__)""");
+
+		/********************************************************************************************/
+		/**********************                 real functions                 **********************/
+		/********************************************************************************************/
 
 		/********************************************************************************************/
 		/**********************            trigonometric functions             **********************/
@@ -498,20 +629,6 @@ template <int N, bool registerConverters> struct RegisterRealHPMath {
 		        R"""(:return: ``Real`` the arc tangent of y/x using the signs of the arguments ``x`` and ``y`` to determine the correct quadrant. Depending on compilation options wraps ``::boost::multiprecision::atan2(…)`` or `std::atan2(…) <https://en.cppreference.com/w/cpp/numeric/math/atan2>`__ function.)""");
 
 
-		/********************************************************************************************/
-		/**********************        complex logarithm and exponential        *********************/
-		/********************************************************************************************/
-		// complex functions must be registered first, so that python will properly discover overloads
-		py::def("exp",
-		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::exp),
-		        (py::arg("x")),
-		        R"""(:return: the base `e` exponential of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::exp(…)`` or `std::exp(…) <https://en.cppreference.com/w/cpp/numeric/complex/exp>`__ function.)""");
-		py::def("log",
-		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::log),
-		        (py::arg("x")),
-		        R"""(:return: the ``Complex`` natural (base `e`) logarithm of a complex value z with a branch cut along the negative real axis. Depending on compilation options wraps ``::boost::multiprecision::log(…)`` or `std::log(…) <https://en.cppreference.com/w/cpp/numeric/complex/log>`__ function.)""");
-
-
 		/********************************************************************************************/
 		/**********************   logarithm, exponential and power functions   **********************/
 		/********************************************************************************************/
@@ -576,30 +693,6 @@ template <int N, bool registerConverters> struct RegisterRealHPMath {
 		        (py::arg("x"), "y"),
 		        R"""(:return: ``Real`` the square root of the sum of the squares of ``x`` and ``y``, without undue overflow or underflow at intermediate stages of the computation. Depending on compilation options wraps ``::boost::multiprecision::hypot(…)`` or `std::hypot(…) <https://en.cppreference.com/w/cpp/numeric/math/hypot>`__ function.)""");
 
-
-		/********************************************************************************************/
-		/**********************         complex conj, abs, real, imag          *********************/
-		/********************************************************************************************/
-		// complex functions must be registered first, so that python will properly discover overloads
-		py::def("conj",
-		        static_cast<ComplexHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::conj),
-		        (py::arg("x")),
-		        R"""(:return: the complex conjugation a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::conj(…)`` or `std::conj(…) <https://en.cppreference.com/w/cpp/numeric/complex/conj>`__ function.)""");
-		py::def("abs",
-		        // note …<ComplexHP<N>> at the end, to help compiler in the template overload resolution.
-		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::abs<ComplexHP<N>>),
-		        (py::arg("x")),
-		        R"""(:return: the ``Real`` absolute value of the ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::abs(…)`` or `std::abs(…) <https://en.cppreference.com/w/cpp/numeric/complex/abs>`__ function.)""");
-		py::def("real",
-		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::real),
-		        (py::arg("x")),
-		        R"""(:return: the real part of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::real(…)`` or `std::real(…) <https://en.cppreference.com/w/cpp/numeric/complex/real2>`__ function.)""");
-		py::def("imag",
-		        static_cast<RealHP<N> (*)(const ComplexHP<N>&)>(&::yade::math::imag),
-		        (py::arg("x")),
-		        R"""(:return: the imag part of a ``Complex`` argument. Depending on compilation options wraps ``::boost::multiprecision::imag(…)`` or `std::imag(…) <https://en.cppreference.com/w/cpp/numeric/complex/imag2>`__ function.)""");
-
-
 		/********************************************************************************************/
 		/**********************    min, max, abs, sign, floor, ceil, etc...    **********************/
 		/********************************************************************************************/
@@ -908,13 +1001,15 @@ BOOST_PYTHON_MODULE(_math)
 try {
 	YADE_SET_DOCSTRING_OPTS;
 
-	if ((::yade::math::RealHPConfig::getDigits10(1) >= 18) or (::yade::math::levelOrZero<double> == 0)) {
-		std_pair_to_python_converter<double, double>();
-	}
+	if ((::yade::math::RealHPConfig::getDigits10(1) >= 18) or (::yade::math::levelOrZero<double> == 0)) { std_pair_to_python_converter<double, double>(); }
 	// this loop registers all python functions from range defined in YADE_EIGENCGAL_HP, file lib/high-precision/RealHPEigenCgal.hpp
 	// Some functions for large N are extremely slow during python 'import yade.math', so they are not registered, see struct IfConstexprForSlowFunctions
 	::yade::math::detail::registerLoopForHPn<::yade::math::RealHPConfig::SupportedByMinieigen, RegisterRealHPMath>();
 
+	py::def("testLoopRealHP",
+	        ::yade::testLoopRealHP,
+	        R"""(This function tests lib/high-precision/Constants.hpp, but the C++ side: all precisions, even those inaccessible from python)""");
+
 	expose_storage_ordering();
 	exposeRealHPDiagnostics();
 
@@ -951,22 +1046,21 @@ template <int N1> struct TestRealHP2 {
 			auto       c2 = a - b;
 			auto       c3 = a * b;
 			auto       c4 = a / b;
-			if (c1 != RealHP<N>(1.25)) // NOTE: might want later to replace these if with BOOST_ASSERT
+			if (c1 != RealHP<N>(1.25))    // NOTE: might want later to replace these if with BOOST_ASSERT
 				throw std::runtime_error(("TestRealHP error: Fatal r1" + info).c_str());
-			if (c2 != RealHP<N>(-3.75))
-				throw std::runtime_error(("TestRealHP error: Fatal r2" + info).c_str());
-			if (c3 != RealHP<N>(-3.125))
-				throw std::runtime_error(("TestRealHP error: Fatal r3" + info).c_str());
-			if (c4 != RealHP<N>(-0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal r4" + info).c_str());
+			if (c2 != RealHP<N>(-3.75)) throw std::runtime_error(("TestRealHP error: Fatal r2" + info).c_str());
+			if (c3 != RealHP<N>(-3.125)) throw std::runtime_error(("TestRealHP error: Fatal r3" + info).c_str());
+			if (c4 != RealHP<N>(-0.5)) throw std::runtime_error(("TestRealHP error: Fatal r4" + info).c_str());
 			auto       d1 = a;
 			auto       d2 = b;
 			RealHP<N2> d3 = RealHP<N2>(a);
 			RealHP<N1> d4 = RealHP<N1>(b);
 			auto       d5 = d1 + d2 + d3 + d4;
-			if (d5 != RealHP<N>(2.5))
-				throw std::runtime_error(("TestRealHP error: Fatal r5" + info).c_str());
+			if (d5 != RealHP<N>(2.5)) throw std::runtime_error(("TestRealHP error: Fatal r5" + info).c_str());
 		}
+
+#ifndef YADE_COMPLEX_MP
+// see comment in lib/high-precision/RealHP.hpp line 94 about MakeComplexStd, MakeComplexMpc and problems of MPFR mpc_complex with UpconversionOfBasicOperatorsHP.hpp
 		{
 			ComplexHP<N1> a  = ComplexHP<N1>(-1.25, 0.5);
 			ComplexHP<N2> b  = ComplexHP<N2>(1.0, 1.0);
@@ -974,22 +1068,17 @@ template <int N1> struct TestRealHP2 {
 			auto          c2 = a - b;
 			auto          c3 = a * b;
 			auto          c4 = a / b;
-			if (c1 != ComplexHP<N>(-0.25, 1.5))
-				throw std::runtime_error(("TestRealHP error: Fatal c1" + info).c_str());
-			if (c2 != ComplexHP<N>(-2.25, -0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal c2" + info).c_str());
-			if (c3 != ComplexHP<N>(-1.75, -0.75))
-				throw std::runtime_error(("TestRealHP error: Fatal c3" + info).c_str());
-			if (c4 != ComplexHP<N>(-0.375, 0.875))
-				throw std::runtime_error(("TestRealHP error: Fatal c4" + info).c_str());
+			if (c1 != ComplexHP<N>(-0.25, 1.5)) throw std::runtime_error(("TestRealHP error: Fatal c1" + info).c_str());
+			if (c2 != ComplexHP<N>(-2.25, -0.5)) throw std::runtime_error(("TestRealHP error: Fatal c2" + info).c_str());
+			if (c3 != ComplexHP<N>(-1.75, -0.75)) throw std::runtime_error(("TestRealHP error: Fatal c3" + info).c_str());
+			if (c4 != ComplexHP<N>(-0.375, 0.875)) throw std::runtime_error(("TestRealHP error: Fatal c4" + info).c_str());
 			auto d1 = a;
 			auto d2 = b;
 			// down-converting requires extra casting
 			ComplexHP<N2> d3 = ComplexHP<N2>(RealHP<N2>(a.real()), RealHP<N2>(a.imag()));
 			ComplexHP<N1> d4 = ComplexHP<N1>(RealHP<N1>(b.real()), RealHP<N1>(b.imag()));
 			auto          d5 = d1 + d2 + d3 + d4;
-			if (d5 != ComplexHP<N>(-0.5, 3.0))
-				throw std::runtime_error(("TestRealHP error: Fatal c5" + info).c_str());
+			if (d5 != ComplexHP<N>(-0.5, 3.0)) throw std::runtime_error(("TestRealHP error: Fatal c5" + info).c_str());
 		}
 		{
 			ComplexHP<N1> a  = ComplexHP<N1>(-1.25, 0.5);
@@ -1002,20 +1091,13 @@ template <int N1> struct TestRealHP2 {
 			auto          c6 = b - a;
 			auto          c7 = b * a;
 			auto          c8 = b / a;
-			if (c1 != ComplexHP<N>(-0.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr1" + info).c_str());
-			if (c2 != ComplexHP<N>(-2.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr2" + info).c_str());
-			if (c3 != ComplexHP<N>(-1.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr3" + info).c_str());
-			if (c4 != ComplexHP<N>(-1.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr4" + info).c_str());
-			if (c5 != ComplexHP<N>(-0.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr5" + info).c_str());
-			if (c6 != ComplexHP<N>(2.25, -0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr6" + info).c_str());
-			if (c7 != ComplexHP<N>(-1.25, 0.5))
-				throw std::runtime_error(("TestRealHP error: Fatal cr7" + info).c_str());
+			if (c1 != ComplexHP<N>(-0.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr1" + info).c_str());
+			if (c2 != ComplexHP<N>(-2.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr2" + info).c_str());
+			if (c3 != ComplexHP<N>(-1.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr3" + info).c_str());
+			if (c4 != ComplexHP<N>(-1.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr4" + info).c_str());
+			if (c5 != ComplexHP<N>(-0.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr5" + info).c_str());
+			if (c6 != ComplexHP<N>(2.25, -0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr6" + info).c_str());
+			if (c7 != ComplexHP<N>(-1.25, 0.5)) throw std::runtime_error(("TestRealHP error: Fatal cr7" + info).c_str());
 			if (::yade::math::abs(c8 - ComplexHP<N>(-0.68965517241379310345, -0.27586206896551724138)) > 0.1)
 				throw std::runtime_error(("TestRealHP error: Fatal cr8" + info).c_str());
 			auto d1 = a;
@@ -1024,11 +1106,9 @@ template <int N1> struct TestRealHP2 {
 			ComplexHP<N2> d3 = ComplexHP<N2>(RealHP<N2>(a.real()), RealHP<N2>(a.imag()));
 			RealHP<N1>    d4 = RealHP<N1>(b);
 			auto          d5 = d1 + d2 + d4 + d3;
-			if (d5 != ComplexHP<N>(-0.5, 1.0))
-				throw std::runtime_error(("TestRealHP error: Fatal cr9" + info).c_str());
+			if (d5 != ComplexHP<N>(-0.5, 1.0)) throw std::runtime_error(("TestRealHP error: Fatal cr9" + info).c_str());
 			auto d6 = d1 + d2 + d3 + d4;
-			if (d6 != ComplexHP<N>(-0.5, 1.0))
-				throw std::runtime_error(("TestRealHP error: Fatal cr10" + info).c_str());
+			if (d6 != ComplexHP<N>(-0.5, 1.0)) throw std::runtime_error(("TestRealHP error: Fatal cr10" + info).c_str());
 
 			static_assert(std::is_same<ComplexHP<N>, decltype(c1)>::value, "Assert error c1");
 			static_assert(std::is_same<ComplexHP<N>, decltype(c2)>::value, "Assert error c2");
@@ -1045,6 +1125,7 @@ template <int N1> struct TestRealHP2 {
 			static_assert(std::is_same<ComplexHP<N>, decltype(d5)>::value, "Assert error d5");
 			static_assert(std::is_same<ComplexHP<N>, decltype(d6)>::value, "Assert error d6");
 		}
+#endif
 	}
 };
 
