@@ -49,15 +49,15 @@ public:
 private:
 	template <class PyClass> static std::string name(PyClass& cl) { return py::extract<std::string>(cl.attr("__name__"))(); }
 	// for dynamic matrices/vectors
-	template <typename MatrixBaseT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass&, typename boost::enable_if_c<MatrixBaseT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename MatrixBaseT2, class PyClass, typename boost::enable_if_c<MatrixBaseT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass&)
 	{
 		//std::cerr<<"MatrixBaseVisitor: dynamic MatrixBaseT for "<<name(cl)<<std::endl;
 		;
 	}
 	// for static matrices/vectors
-	template <typename MatrixBaseT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass& cl, typename boost::disable_if_c<MatrixBaseT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename MatrixBaseT2, class PyClass, typename boost::disable_if_c<MatrixBaseT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass& cl)
 	{
 		//std::cerr<<"MatrixBaseVisitor: fixed MatrixBaseT for "<<name(cl)<<std::endl;
 		cl.add_static_property("Ones", &MatrixBaseVisitor::Ones)
@@ -66,10 +66,10 @@ private:
 		        .staticmethod("Random")
 		        .add_static_property("Identity", &MatrixBaseVisitor::Identity);
 	}
-	template <typename Scalar, class PyClass> static void visit_if_float(PyClass&, typename boost::enable_if<boost::is_integral<Scalar>>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::enable_if<boost::is_integral<Scalar>, int>::type = 0> static void visit_if_float(PyClass&)
 	{ /* do nothing */
 	}
-	template <typename Scalar, class PyClass> static void visit_if_float(PyClass& cl, typename boost::disable_if<boost::is_integral<Scalar>>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::disable_if<boost::is_integral<Scalar>, int>::type = 0> static void visit_if_float(PyClass& cl)
 	{
 		// operations with other scalars (Scalar is the floating type, long is the python integer type)
 		// __trudiv__ is for py3k
@@ -104,8 +104,7 @@ private:
 
 	static bool __eq__(const MatrixBaseT& a, const MatrixBaseT& b)
 	{
-		if (a.rows() != b.rows() || a.cols() != b.cols())
-			return false;
+		if (a.rows() != b.rows() || a.cols() != b.cols()) return false;
 		return a.cwiseEqual(b).all();
 	}
 	static bool isApprox(const MatrixBaseT& a, const MatrixBaseT& b, const RealScalar& prec) { return a.isApprox(b, prec); }
@@ -142,73 +141,67 @@ private:
 		return a;
 	};
 
-	template <typename Scalar2>
-	static typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__mul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __mul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a * scalar;
 	}
-	template <typename Scalar2>
-	static typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__mul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __mul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a * static_cast<Scalar>(scalar);
 	}
-	template <typename Scalar2>
-	static typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type __imul__scalar(MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __imul__scalar(MatrixBaseT& a, const Scalar2& scalar)
 	{
 		a *= scalar;
 		return a;
 	}
-	template <typename Scalar2>
-	static typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type __imul__scalar(MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __imul__scalar(MatrixBaseT& a, const Scalar2& scalar)
 	{
 		a *= static_cast<Scalar>(scalar);
 		return a;
 	}
-	template <typename Scalar2>
-	static typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__rmul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __rmul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a * scalar;
 	}
-	template <typename Scalar2>
-	static typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__rmul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __rmul__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a * static_cast<Scalar>(scalar);
 	}
-	template <typename Scalar2>
-	static typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__div__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __div__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a / scalar;
 	}
-	template <typename Scalar2>
-	static typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type
-	__div__scalar(const MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __div__scalar(const MatrixBaseT& a, const Scalar2& scalar)
 	{
 		return a / static_cast<Scalar>(scalar);
 	}
-	template <typename Scalar2>
-	static typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type __idiv__scalar(MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::enable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __idiv__scalar(MatrixBaseT& a, const Scalar2& scalar)
 	{
 		a /= scalar;
 		return a;
 	}
-	template <typename Scalar2>
-	static typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, MatrixBaseT>::type __idiv__scalar(MatrixBaseT& a, const Scalar2& scalar)
+	template <typename Scalar2, typename boost::disable_if<std::is_convertible<Scalar2, const Scalar&>, int>::type = 0>
+	static MatrixBaseT __idiv__scalar(MatrixBaseT& a, const Scalar2& scalar)
 	{
 		a /= static_cast<Scalar>(scalar);
 		return a;
 	}
 
-	template <typename Scalar, class PyClass>
-	static void visit_reductions_noncomplex(PyClass&, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static void visit_reductions_noncomplex(PyClass&)
 	{ /* do nothing*/
 	}
-	template <typename Scalar, class PyClass>
-	static void visit_reductions_noncomplex(PyClass& cl, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static void visit_reductions_noncomplex(PyClass& cl)
 	{
 		// must be wrapped since there are overloads:
 		//   maxCoeff(), maxCoeff(IndexType*), maxCoeff(IndexType*,IndexType*)
@@ -220,14 +213,14 @@ private:
 
 	// we want to keep -0 (rather than replacing it by 0), but that does not work for complex numbers
 	// hence two versions
-	template <typename Scalar>
-	static bool prune_element(const Scalar& num, RealScalar absTol, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static bool prune_element(const Scalar& num, RealScalar absTol)
 	{
 		using namespace std;
 		return abs(num) <= absTol || num != -0;
 	}
-	template <typename Scalar>
-	static bool prune_element(const Scalar& num, RealScalar absTol, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static bool prune_element(const Scalar& num, RealScalar absTol)
 	{
 		using namespace std;
 		return abs(num) <= absTol;
@@ -238,8 +231,7 @@ private:
 		MatrixBaseT ret(MatrixBaseT::Zero(a.rows(), a.cols()));
 		for (Index c = 0; c < a.cols(); c++) {
 			for (Index r = 0; r < a.rows(); r++) {
-				if (!prune_element(a(c, r), absTol))
-					ret(c, r) = a(c, r);
+				if (!prune_element(a(c, r), absTol)) ret(c, r) = a(c, r);
 			}
 		}
 		return ret;
@@ -276,8 +268,8 @@ public:
 
 private:
 	// for dynamic vectors
-	template <typename VectorT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass& cl)
 	{
 		//std::cerr<<"VectorVisitor: dynamic vector for "<<name()<<std::endl;
 		cl.def("__len__", &VectorVisitor::dyn__len__)
@@ -295,8 +287,8 @@ private:
 		        .staticmethod("Random");
 	}
 	// for fixed-size vectors
-	template <typename VectorT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass& cl, typename boost::disable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::disable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass& cl)
 	{
 		//std::cerr<<"VectorVisitor: fixed vector for "<<name()<<std::endl;
 		cl.def("__len__", &VectorVisitor::__len__).staticmethod("__len__").def("Unit", &VectorVisitor::Unit).staticmethod("Unit");
@@ -305,8 +297,8 @@ private:
 	// handle specific sizes of vectors separately
 
 	// 2-vector
-	template <typename VectorT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 2>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 2, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def(py::init<typename VectorT2::Scalar, typename VectorT2::Scalar>((py::arg("x"), py::arg("y"))))
 		        .add_static_property("UnitX", &VectorVisitor::Vec2_UnitX)
@@ -316,8 +308,8 @@ private:
 	static CompatVec2 Vec2_UnitY() { return CompatVec2::UnitY(); }
 
 	// 3-vector
-	template <typename VectorT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 3>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 3, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def(py::init<typename VectorT2::Scalar, typename VectorT2::Scalar, typename VectorT2::Scalar>(
 		               (py::arg("x") = Scalar(0), py::arg("y") = Scalar(0), py::arg("z") = Scalar(0))))
@@ -346,16 +338,16 @@ private:
 	static CompatVec2 Vec3_zy(const CompatVec3& v) { return CompatVec2(v[2], v[1]); }
 
 	// 4-vector
-	template <typename VectorT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 4>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 4, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def(py::init<typename VectorT2::Scalar, typename VectorT2::Scalar, typename VectorT2::Scalar, typename VectorT2::Scalar>(
 		        (py::arg("v0"), py::arg("v1"), py::arg("v2"), py::arg("v3"))));
 	}
 
 	// 6-vector
-	template <typename VectorT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 6>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == 6, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def("__init__",
 		       py::make_constructor(
@@ -384,8 +376,8 @@ private:
 	static CompatVec3 Vec6_tail(const CompatVec6& v) { return v.template tail<3>(); }
 
 	// ctor for dynamic vectors
-	template <typename VectorT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename VectorT2, class PyClass, typename boost::enable_if_c<VectorT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def("__init__", py::make_constructor(&VecX_fromList, py::default_call_policies(), (py::arg("vv"))));
 	}
@@ -514,8 +506,8 @@ public:
 
 private:
 	// for dynamic matrices
-	template <typename MatrixT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass& cl, typename boost::enable_if_c<MatrixT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename MatrixT2, class PyClass, typename boost::enable_if_c<MatrixT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass& cl)
 	{
 		cl.def("__len__", &MatrixVisitor::dyn__len__)
 		        .def("resize",
@@ -538,16 +530,16 @@ private:
 		        .staticmethod("Identity");
 	}
 	// for fixed-size matrices
-	template <typename MatrixT2, class PyClass>
-	static void visit_fixed_or_dynamic(PyClass& cl, typename boost::disable_if_c<MatrixT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename MatrixT2, class PyClass, typename boost::disable_if_c<MatrixT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_fixed_or_dynamic(PyClass& cl)
 	{
 		cl.def("__len__", &MatrixVisitor::__len__).staticmethod("__len__");
 	}
 
-	template <typename Scalar, class PyClass> static void visit_if_float(PyClass&, typename boost::enable_if<boost::is_integral<Scalar>>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::enable_if<boost::is_integral<Scalar>, int>::type = 0> static void visit_if_float(PyClass&)
 	{ /* do nothing */
 	}
-	template <typename Scalar, class PyClass> static void visit_if_float(PyClass& cl, typename boost::disable_if<boost::is_integral<Scalar>>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::disable_if<boost::is_integral<Scalar>, int>::type = 0> static void visit_if_float(PyClass& cl)
 	{
 		cl
 		        // matrix-matrix division?!
@@ -557,13 +549,13 @@ private:
 		visit_if_decompositions_meaningful<Scalar, PyClass>(cl);
 	}
 	// for complex numbers, do nothing
-	template <typename Scalar, class PyClass>
-	static void visit_if_decompositions_meaningful(PyClass&, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::enable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static void visit_if_decompositions_meaningful(PyClass&)
 	{ /* do nothing */
 	}
 	// for non-complex numbers, define decompositions
-	template <typename Scalar, class PyClass>
-	static void visit_if_decompositions_meaningful(PyClass& cl, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex>::type* = 0)
+	template <typename Scalar, class PyClass, typename boost::disable_if_c<Eigen::NumTraits<Scalar>::IsComplex, int>::type = 0>
+	static void visit_if_decompositions_meaningful(PyClass& cl)
 	{
 		cl.def("jacobiSVD", &MatrixVisitor::jacobiSVD, "Compute SVD decomposition of square matrix, retuns (U,S,V) such that self=U*S*V.transpose()")
 		        .def("svd", &MatrixVisitor::jacobiSVD, "Alias for :obj:`jacobiSVD`.")
@@ -581,8 +573,8 @@ private:
 
 	// handle specific matrix sizes
 	// 3x3
-	template <typename MatT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<MatT2::RowsAtCompileTime == 3>::type* = 0)
+	template <typename MatT2, class PyClass, typename boost::enable_if_c<MatT2::RowsAtCompileTime == 3, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def("__init__",
 		       py::make_constructor(
@@ -634,8 +626,8 @@ private:
 	}
 
 	// 6x6
-	template <typename MatT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<MatT2::RowsAtCompileTime == 6>::type* = 0)
+	template <typename MatT2, class PyClass, typename boost::enable_if_c<MatT2::RowsAtCompileTime == 6, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def("__init__",
 		       py::make_constructor(
@@ -692,8 +684,8 @@ private:
 	static CompatMat3 Mat6_lr(const CompatMat6& m) { return m.template bottomRightCorner<3, 3>(); }
 
 	// XxX
-	template <typename MatT2, class PyClass>
-	static void visit_special_sizes(PyClass& cl, typename boost::enable_if_c<MatT2::RowsAtCompileTime == Eigen::Dynamic>::type* = 0)
+	template <typename MatT2, class PyClass, typename boost::enable_if_c<MatT2::RowsAtCompileTime == Eigen::Dynamic, int>::type = 0>
+	static void visit_special_sizes(PyClass& cl)
 	{
 		cl.def("__init__",
 		       py::make_constructor(
@@ -730,8 +722,7 @@ private:
 		/* check vector dimensions */ CompatVecX rr[] = { r0, r1, r2, r3, r4, r5, r6, r7, r8, r9 };
 		int                                      cols = -1, rows = -1;
 		for (int i = 0; i < 10; i++) {
-			if (rows < 0 && rr[i].size() == 0)
-				rows = i;
+			if (rows < 0 && rr[i].size() == 0) rows = i;
 			if (rows >= 0 && rr[i].size() > 0)
 				throw std::invalid_argument("Matrix6r: non-empty rows not allowed after first empty row, which marks end of the matrix.");
 		}
@@ -745,8 +736,7 @@ private:
 		CompatMatX* m;
 		m = setCols ? new CompatMatX(cols, rows) : new CompatMatX(rows, cols);
 		for (int i = 0; i < rows; i++) {
-			if (setCols)
-				m->col(i) = rr[i];
+			if (setCols) m->col(i) = rr[i];
 			else
 				m->row(i) = rr[i];
 		}
@@ -756,13 +746,11 @@ private:
 	{
 		int rows = rr.size(), cols = rr.size() > 0 ? rr[0].size() : 0;
 		for (int i = 1; i < rows; i++)
-			if (rr[i].size() != cols)
-				throw std::invalid_argument(("MatrixX: all rows must have the same length."));
+			if (rr[i].size() != cols) throw std::invalid_argument(("MatrixX: all rows must have the same length."));
 		CompatMatX* m;
 		m = setCols ? new CompatMatX(cols, rows) : new CompatMatX(rows, cols);
 		for (int i = 0; i < rows; i++) {
-			if (setCols)
-				m->col(i) = rr[i];
+			if (setCols) m->col(i) = rr[i];
 			else
 				m->row(i) = rr[i];
 		}
@@ -835,8 +823,7 @@ private:
 
 	static void ensureSquare(const MatrixT& m)
 	{
-		if (m.rows() != m.cols())
-			throw std::runtime_error("Matrix is not square.");
+		if (m.rows() != m.cols()) throw std::runtime_error("Matrix is not square.");
 	}
 	static py::tuple jacobiSVD(const MatrixT& in)
 	{
@@ -872,8 +859,7 @@ private:
 		if (!dyn() && !wrap) {
 			VectorVisitor<CompatVectorT>::template Vector_data_stream<MatrixT>(m, oss, /*pad=*/0);
 		} else {
-			if (wrap)
-				oss << "\n";
+			if (wrap) oss << "\n";
 			for (Index r = 0; r < m.rows(); r++) {
 				oss << (wrap ? "\t" : "") << "(";
 				VectorVisitor<CompatVectorT>::template Vector_data_stream<CompatVectorT>(m.row(r), oss, /*pad=*/(wrap ? 7 : 0));
@@ -959,8 +945,7 @@ private:
 		Index idx[2];
 		Index mx[2] = { 2, Box::AmbientDimAtCompileTime };
 		IDX2_CHECKED_TUPLE_INTS(_idx, mx, idx);
-		if (idx[0] == 0)
-			return self.min()[idx[1]];
+		if (idx[0] == 0) return self.min()[idx[1]];
 		return self.max()[idx[1]];
 	}
 	static void set_item(Box& self, py::tuple _idx, Scalar value)
@@ -968,23 +953,20 @@ private:
 		Index idx[2];
 		Index mx[2] = { 2, Box::AmbientDimAtCompileTime };
 		IDX2_CHECKED_TUPLE_INTS(_idx, mx, idx);
-		if (idx[0] == 0)
-			self.min()[idx[1]] = value;
+		if (idx[0] == 0) self.min()[idx[1]] = value;
 		else
 			self.max()[idx[1]] = value;
 	}
 	static VectorType get_minmax(const Box& self, Index idx)
 	{
 		IDX_CHECK(idx, 2);
-		if (idx == 0)
-			return self.min();
+		if (idx == 0) return self.min();
 		return self.max();
 	}
 	static void set_minmax(Box& self, Index idx, const VectorType& value)
 	{
 		IDX_CHECK(idx, 2);
-		if (idx == 0)
-			self.min() = value;
+		if (idx == 0) self.min() = value;
 		else
 			self.max() = value;
 	}
@@ -1115,19 +1097,15 @@ private:
 	static Scalar __getitem__(const QuaternionT& self, Index idx)
 	{
 		IDX_CHECK(idx, 4);
-		if (idx == 0)
-			return self.x();
-		if (idx == 1)
-			return self.y();
-		if (idx == 2)
-			return self.z();
+		if (idx == 0) return self.x();
+		if (idx == 1) return self.y();
+		if (idx == 2) return self.z();
 		return self.w();
 	}
 	static void __setitem__(QuaternionT& self, Index idx, Scalar value)
 	{
 		IDX_CHECK(idx, 4);
-		if (idx == 0)
-			self.x() = value;
+		if (idx == 0) self.x() = value;
 		else if (idx == 1)
 			self.y() = value;
 		else if (idx == 2)
